@@ -75,7 +75,11 @@
   *   In analogy to notations commonly used in scientific papers, this
   *   is done by using the \p + operator. For instance two RF-pulses
   *   represented by two objects called \p alpha and \p beta can build
-  *   a new sequence object \verbatim alpha + beta \endverbatim which results in a sequence
+  *   a new sequence object
+  *\code{.cpp}
+alpha + beta
+\endcode
+  *   which results in a sequence
   *   object which will play out the first pulse and then the second pulse.
   *
   * \subsection design_gradgrouping Grouping of Gradient Objects 
@@ -83,14 +87,20 @@
   *   the \p / operator tries to build a new object that plays out the two operands
   *   in parallel if the timing is apropriate. For example two gradient pulses
   *   \p gp1 and \p gp2, one for the read and another for the phase channel, can be
-  *   played out in parallel by using the combination \verbatim gp1 / gp2 \endverbatim
+  *   played out in parallel by using the combination
+  *\code{.cpp}
+gp1 / gp2
+\endcode
   *
   * \subsection design_seqparallel Combining Sequence and Gradient objects
   *   Sequence and gradient objects can also be serialised by the \p + operator. To
   *   play out a gradient and a sequence object in parallel, the \p / operator can be
   *   used. For example let \p alpha be an excitation pulse and \p constgrad a constant
-  *   gradient, then the combination \verbatim alpha / constgrad \endverbatim would
-  *   give a slice selective pulse.   
+  *   gradient, then the combination
+  *\code{.cpp}
+alpha / constgrad
+\endcode
+  *   would give a slice selective pulse.
   *
   * \subsection design_seqcontainer Container for Sequence Objects 
   *   The sequence object SeqObjList can be used as a container for other
@@ -98,15 +108,16 @@
   *   consists of other sequence components.
   *   If a certain operation is applied to a SeqObjList object, the operation
   *   will also be applied to all elements of the sub-sequence. For example:
-  *   \verbatim
+  *\code{.cpp}
       SeqPuls           alpha;                   // excitation pulse
       SeqGradConstPulse constgrad;               // constant gradient
       SeqObjList   objlist = alpha + constgrad;  // alpha is played out after constgrad
-      \endverbatim
+\endcode
   *   Calling the member function
-  *   \verbatim
-      objlist.get_duration()
-      \endverbatim would then return the sum of the durations of \p alpha and \p constgrad.
+  *\code{.cpp}
+objlist.get_duration()
+\endcode
+would then return the sum of the durations of \p alpha and \p constgrad.
   *
   * \subsection design_seqgradcontainer Container for Gradient Objects
   *   The gradient object SeqGradChanList can be used as a container for other
@@ -126,9 +137,9 @@
   *   this class: Pure repitition loops and vector loops. Repitition
   *   loops simply repeat the specified part of the sequence without
   *   altering it. Let \p loop be of type SeqObjLoop, then heir syntax is:
-  *   \verbatim
-      loop ( kernel ) [ n ];
-      \endverbatim
+  *\code{.cpp}
+loop ( kernel ) [ n ];
+\endcode
   *   This statement will return a sequence object that repeats the sequence
   *   object \p kernel \p n times, where \p n is an integer number.
   *
@@ -137,9 +148,9 @@
   *   Sequence vectors are for example phase encoding gradients or pulses
   *   with a frequency list. All sequence vectors share the same base class
   *   SeqVector. Let \p loop be of type SeqObjLoop, then the syntax for vector loops is: 
-  *   \verbatim
-      loop ( kernel ) [ vector1 ] [ vector2 ] ...;
-      \endverbatim
+  *\code{.cpp}
+loop ( kernel ) [ vector1 ] [ vector2 ] ...;
+\endcode
   *   This statement will return a sequence object that repeats the sequence
   *   object \p kernel while incrementing the values of the attached sequence
   *   vectors  \p vector1, \p vector2, ...
@@ -179,7 +190,7 @@
   * If you want to write your own class that can be plugged into the ODIN framework,
   * please use the following form for your class 'SeqMyClass' that is derived from
   * 'SeqBaseClass':
-  *  \verbatim
+  *\code{.cpp}
 
 /////////////// *.h stuff: //////////////////////////////
 
@@ -234,7 +245,7 @@ SeqMyClass& SeqMyClass::operator = (const SeqMyClass& sct) {
 
 SeqMyClass::~SeqMyClass() {
 }
-   \endverbatim
+\endcode
   * Following this standard prevents the base classes from getting confused by not
   * correctly initialising or copying them.
   *
@@ -251,19 +262,19 @@ SeqMyClass::~SeqMyClass() {
   * To generate debugging and tracing output, please use the Log template class instead
   * of using streams.
   * Instances of that class offer a stream to log trace messages via the ODINLOG macro:
-  * \verbatim
+  *\code{.cpp}
 int MyClass::myfunction() {
   Log<Seq> odinlog("MyClass","myfunction");
 
   ODINLOG(odinlog,significantDebug) << "Hello World" << STD_endl;
 }
-    \endverbatim
+\endcode
   * Which will result in the following output:
-  * \verbatim
+  *\code{.cpp}
 Seq    |          MyClass.myfunction : START
 Seq    |          MyClass.myfunction : Hello World
 Seq    |          MyClass.myfunction : END
-    \endverbatim
+\endcode
   * It can generate debugging output at different levels of verbosity
   * and the output is redirected to the native logging channel (console, log file) of
   * the current platform. Furthermore, it can be completely removed from the executable
@@ -327,18 +338,18 @@ Seq    |          MyClass.myfunction : END
   * - carray / JDXcomplexArr: array of complex numbers (STD_complex objects)
   *
   * Some examples on how to use these arrays:
-  *   \verbatim
-      farray   fa1(3,3);    // creates a 2-dimensional 3x3 array
+  *\code{.cpp}
+farray   fa1(3,3);    // creates a 2-dimensional 3x3 array
 
-      fa1(0,1)=5.7;         // assigns 5.7 to the second element in the firs row
+fa1(0,1)=5.7;         // assigns 5.7 to the second element in the firs row
 
-      farray   fa2(3,3);    // creates another 2-dimensional 3x3 array
+farray   fa2(3,3);    // creates another 2-dimensional 3x3 array
 
-      fa1+fa2;              // returns the element-wise sum of the two arrays
+fa1+fa2;              // returns the element-wise sum of the two arrays
 
-      fa1.redim(1,2,3);     // resizes fa1 to a 3-dimensional 1x2x3 array
+fa1.redim(1,2,3);     // resizes fa1 to a 3-dimensional 1x2x3 array
 
-      \endverbatim
+\endcode
   * Please see the class documention for a complete reference.
   *
   */
@@ -366,21 +377,21 @@ Seq    |          MyClass.myfunction : END
   *
   *
   * A very simple examples on how to use this module:
-  *   \verbatim
+  *\code{.cpp}
 
-      JDXint mynumber(23,"mynumber");  // Create an integer parameter with initial value 23
+JDXint mynumber(23,"mynumber");  // Create an integer parameter with initial value 23
 
-      mynumber+=42;                    // JDXint can be used just as a native int for arithmetics
+mynumber+=42;                    // JDXint can be used just as a native int for arithmetics
 
-      JcampDxBlock block;              // A block (list) of parameters
+JcampDxBlock block;              // A block (list) of parameters
 
-      block.append(mynumber);          // Append the parameter to the block
+block.append(mynumber);          // Append the parameter to the block
 
-      block.write("block.jdx");        // Write block and its parameters to file 'block.jdx'
+block.write("block.jdx");        // Write block and its parameters to file 'block.jdx'
 
-      block.load("block.jdx");         // Load block and its parameters from file 'block.jdx'
+block.load("block.jdx");         // Load block and its parameters from file 'block.jdx'
 
-      \endverbatim
+\endcode
   * Please see the class documention for a complete reference.
   *
   *
