@@ -43,7 +43,7 @@ void usage(const STD_string& missing_arg="") {
   STD_cout << STD_endl;
   STD_cout << "Usage and options:" << STD_endl;
   STD_cout << "  Create a sample from external maps:" << STD_endl;
-  STD_cout << "    gensample -fr <FOVread> -fp <FOVphase> -fs <FOVslice> -s0 <spin-density> [-t1 <T1map>] [-t2 <T2map>] [-pm <ppmMap>] [-ir <inplane-reduction>] [-ss <single-slice number>] [-fr <comma-separated-list of frame-rates>]  -o <Sample-file>" << STD_endl;
+  STD_cout << "    gensample -fr <FOVread> -fp <FOVphase> -fs <FOVslice> -s0 <spin-density> [-t1 <T1map>] [-t2 <T2map>] [-pm <ppmMap>] [-ir <inplane-reduction>] [-ss <single-slice number>] [-ft <comma-separated-list of frame-rates for dymaic phantoms>]  -o <Sample-file>" << STD_endl;
   STD_cout << "  Create a point-spread function:" << STD_endl;
   STD_cout << "    gensample -psf -t1 <point T1> -t2 <point T2> [-dc <DiffusionCoeff>] -o <Sample-file>" << STD_endl;
   STD_cout << "  Create rectangle of uniform spin distribution about origin in all 3 spatial dimensions:" << STD_endl;
@@ -282,7 +282,7 @@ int main(int argc, char* argv[]) {
 
     ODINLOG(odinlog,infoLog) << "Setting spinDensity/DcoeffMap maps ..." << STD_endl;
     sample.set_spinDensity(sdmap);
-    sample.set_DcoeffMap(Dmap);
+    if(D>0.0) sample.set_DcoeffMap(Dmap);
 
     valid_mode=true;
   }
@@ -352,7 +352,7 @@ int main(int argc, char* argv[]) {
 
 
     int nframes_arg=0;
-    if(getCommandlineOption(argc,argv,"-fr",optval,ODIN_MAXCHAR)) {
+    if(getCommandlineOption(argc,argv,"-ft",optval,ODIN_MAXCHAR)) {
       svector toks=tokens(optval,',');
       nframes_arg=toks.size();
       ODINLOG(odinlog,infoLog) << "nframes_arg=" << nframes_arg << STD_endl;
