@@ -62,27 +62,28 @@
 void usage(const Protocol& prot) {
   FileReadOpts ropts;
   FileWriteOpts wopts;
-  FilterFactory filter;
+  FilterChain filter;
   STD_cout << "micalc:  Performs basic mathematics with data sets" << STD_endl;
   STD_cout << "         File formats are automatically identified by their file extension." << STD_endl;
+  STD_cout << "         For binary operations with two input files, the protocol of the first input file will be used for the output file." << STD_endl;
   STD_cout << "micalc can be used in one of the following modes:" << STD_endl;
   STD_cout << "  Binary operation with data sets and/or scalar numbers:" << STD_endl;
-  STD_cout << "       micalc [-if1 <input-file1> | -in1 <input-number1>] -op <operation(+,-,*,/,lcorr,kcorr)> [-if2 <input-file2> | -in2 <input-number1>] -of <output-file>" << STD_endl;
-  STD_cout << "  Accumulation of one data set:" << STD_endl;
-  STD_cout << "       micalc -if <input-file> -op <operation(+,*)>" << STD_endl;
+  STD_cout << "       micalc [-if1 <input-file1> | -in1 <input-number1>] -op <operation(+,-,*,/,min,max,lcorr,kcorr)> [-if2 <input-file2> | -in2 <input-number1>] -of <output-file>" << STD_endl;
+  STD_cout << "  Accumulation/reduction of one data set:" << STD_endl;
+  STD_cout << "       micalc -if <input-file> -op <operation(+,*,mean,median,stdev,min,max)>" << STD_endl;
   STD_cout << "  Transformation (magnitude, logarithm, negation, inversion, or acos) of one data set:" << STD_endl;
   STD_cout << "       micalc -if <input-file> -op <operation(abs,log,-,/,acos)> -of <output-file>" << STD_endl;
   STD_cout << "  Statistics of one data set:" << STD_endl;
-  STD_cout << "       micalc -if <input-file> [-mean <time-mean-file>] [-stdev <time-stdev-file>] [-fluct <relative-time-stdev-file>] [-tcourse <average time course of all voxels>] [-hist <histogram> -histmin <minval> -histmax <maxval> -histslots <numofslots> -rightstairs -histfract]" << STD_endl;
+  STD_cout << "       micalc -if <input-file> [-mean <time-mean-file>] [-stdev <time-stdev-file>] [-fluct <relative-time-stdev-file>] [-tcourse <average time course of all voxels>]"
+                      "[-hist <histogram> -histslots <numofslots> [-histmin <minval>] [-histmax <maxval>] [-rightstairs] [-histfract] [-loghist] [-histslotmap <file>]]" << STD_endl;
   STD_cout << "Extra options:" << STD_endl;
   STD_cout << "\t-mask <Binary mask file: voxels with zeroes are discarded>" << STD_endl;
-  STD_cout << "\t-weightmask <Multiply input file(s) with this file>" << STD_endl;
   STD_cout << "File read options:" << STD_endl;
   STD_cout << prot.get_cmdline_usage("\t");
   STD_cout << ropts.get_cmdline_usage("\t");
   STD_cout << "File write options:" << STD_endl;
   STD_cout << wopts.get_cmdline_usage("\t");
-  STD_cout << "Filters applied to input file(s):" << STD_endl;
+  STD_cout << "Filters applied to input file(s) and mask:" << STD_endl;
   STD_cout << filter.get_cmdline_usage("\t");
   STD_cout << "Other options:" << STD_endl;
   STD_cout << "\t" << LogBase::get_usage() << STD_endl;
@@ -92,7 +93,10 @@ void usage(const Protocol& prot) {
 }
 
 
-bool read_infile(const STD_string& filename, Data<float,4>& data, const FileReadOpts& ropts, Protocol& prot, const FilterChain& filterchain, const Data<float,4>& weightmaskdata) {
+////////////////////////////////////////////////////////////////////////////
+
+
+bool read_infile(const STD_string& filename, Data<float,4>& data, const FileReadOpts& ropts, Protocol& prot, const FilterChain& filterchain) {
   Log<OdinData> odinlog("micalc","read_infile");
 
   Range all=Range::all();
@@ -103,20 +107,15 @@ bool read_infile(const STD_string& filename, Data<float,4>& data, const FileRead
   if(!filterchain.apply(prot,datain)) return false;
   data.resize(datain.shape());
 
-  if(weightmaskdata.size()) {
-    if( weightmaskdata.extent(0) && same_shape(data, weightmaskdata, TinyVector<int,4>(0,1,1,1) ) ) {
-      for(int irep=0; irep<data.extent(0); irep++) data(irep,all,all,all)=weightmaskdata(0,all,all,all)*datain(irep,all,all,all);
-    } else {
-      ODINLOG(odinlog,errorLog) << "Shape mismatch:  datashape/weightmaskshape=" << data.shape() << "/" << weightmaskdata.shape() << STD_endl;
-      return false;
-    }
-  } else {
-    data=datain; // In case storage order is non-default
-  }
+  data=datain; // In case storage order is non-default
+
   return true;
 }
 
 
+////////////////////////////////////////////////////////////////////////////
+
+
 int main(int argc, char* argv[]) {
   LogBase::set_log_levels(argc,argv);
 
@@ -141,7 +140,6 @@ int main(int argc, char* argv[]) {
   STD_string infile2;
   STD_string outfile;
   STD_string maskfile;
-  STD_string weightmaskfile;
 
   float innumber1=0.0;
   float innumber2=0.0;
@@ -171,7 +169,6 @@ int main(int argc, char* argv[]) {
   if(getCommandlineOption(argc,argv,"-of",optval,ODIN_MAXCHAR)) {outfile=optval; offlag=true;}
 
   if(getCommandlineOption(argc,argv,"-mask",optval,ODIN_MAXCHAR)) {maskfile=optval;}
-  if(getCommandlineOption(argc,argv,"-weightmask",optval,ODIN_MAXCHAR)) {weightmaskfile=optval;}
 
   STD_string histfile;
   if(getCommandlineOption(argc,argv,"-hist",optval,ODIN_MAXCHAR)) histfile=optval;
@@ -183,6 +180,7 @@ int main(int argc, char* argv[]) {
   STD_string histslots;
   STD_string histmin;
   STD_string histmax;
+  STD_string histslotmapfile;
   if(getCommandlineOption(argc,argv,"-mean",optval,ODIN_MAXCHAR))  meanfile=optval;
   if(getCommandlineOption(argc,argv,"-fluct",optval,ODIN_MAXCHAR)) fluctfile=optval;
   if(getCommandlineOption(argc,argv,"-stdev",optval,ODIN_MAXCHAR)) stdevfile=optval;
@@ -192,6 +190,8 @@ int main(int argc, char* argv[]) {
   if(getCommandlineOption(argc,argv,"-histmax",optval,ODIN_MAXCHAR)) histmax=optval;
   bool rightstairs=isCommandlineOption(argc,argv,"-rightstairs");
   bool histfract=isCommandlineOption(argc,argv,"-histfract");
+  bool loghist=isCommandlineOption(argc,argv,"-loghist");
+  if(getCommandlineOption(argc,argv,"-histslotmap",optval,ODIN_MAXCHAR)) histslotmapfile=optval;
 
 
 
@@ -222,17 +222,13 @@ int main(int argc, char* argv[]) {
   Data<float,4> data1;
   Data<float,4> data2;
 
-  Data<float,4> weightmaskdata;
-  if(weightmaskfile!="") {
-    if(weightmaskdata.autoread(weightmaskfile,ropts)<0) return -1;
-  }
-
   if(infile1!="") {
-    if(!read_infile(infile1, data1, ropts, prot, filterchain, weightmaskdata)) return -1;
+    if(!read_infile(infile1, data1, ropts, prot, filterchain)) return -1;
   }
 
   if(binaryop && infile2!="") {
-    if(!read_infile(infile2, data2, ropts, prot, filterchain, weightmaskdata)) return -1;
+    Protocol protcopy(prot); // dispensable, protocol of first file will be used
+    if(!read_infile(infile2, data2, ropts, protcopy, filterchain)) return -1;
   }
 
   TinyVector<int,4> outshape;
@@ -268,16 +264,18 @@ int main(int argc, char* argv[]) {
 
   Data<float,4>* maskptr=0;
   Data<float,4> maskdata;
-  Data<float,4> inmaskdata;
   if(maskfile!="") {
-    if(inmaskdata.autoread(maskfile,ropts)<0) return -1;
+    Data<float,4> inmaskdata;
+    Protocol maskprot;
+    if(!read_infile(maskfile, inmaskdata, ropts, maskprot, filterchain)) return -1;
+//    if(inmaskdata.autoread(maskfile,ropts)<0) return -1;
     if( inmaskdata.extent(0) && same_shape(data1, inmaskdata, TinyVector<int,4>(0,1,1,1) ) ) {
       maskdata.resize(data1.shape());
       maskdata=0.0;
       for(int i=0; i<data1.numElements(); i++) {
         TinyVector<int,4> index=data1.create_index(i);
         TinyVector<int,4> maskindex=index; maskindex(0)=0;
-        if(inmaskdata(maskindex)>0.0) maskdata(index)=1.0;
+        if(inmaskdata(maskindex)!=0.0) maskdata(index)=1.0;
       }
       maskptr=&maskdata;
     } else {
@@ -298,14 +296,14 @@ int main(int argc, char* argv[]) {
 
     if(operation=="lcorr" || operation=="kcorr") {
       int npts=data1.size();
-      if(maskptr) npts=int(sum(*maskptr)+0.5);
+      if(maskptr) npts=int(sum(maskdata)+0.5);
       Array<float,1> vec1(npts);
       Array<float,1> vec2(npts);
       int vecindex=0;
       for(int i=0; i<data1.numElements(); i++) {
         TinyVector<int,4> index=data1.create_index(i);
         bool include=true;
-        if( maskptr && (*maskptr)(index)<=0.0 ) include=false;
+        if( maskptr && maskdata(index)==0.0 ) include=false;
         if(include) {
           vec1(vecindex)=data1(index);
           vec2(vecindex)=data2(index);
@@ -324,6 +322,18 @@ int main(int argc, char* argv[]) {
       if(operation=="-") {validop=true; result=data1-data2;}
       if(operation=="*") {validop=true; result=data1*data2;}
       if(operation=="/") {validop=true; result=secureDivision(data1,data2);}
+      if(operation=="min" || operation=="max") {
+        Data<float,4> minval(outshape);
+        Data<float,4> maxval(outshape);
+        for(int i=0; i<data1.numElements(); i++) {
+          TinyVector<int,4> index=data1.create_index(i);
+          minval(index)=STD_min(data1(index), data2(index));
+          maxval(index)=STD_max(data1(index), data2(index));
+        }
+        if(operation=="min") result=minval;
+        else                 result=maxval;
+        validop=true;
+      }
       if(!validop) {
         ODINLOG(odinlog,errorLog) << "invalid binary operation: " << operation << STD_endl;
         return -1;
@@ -341,6 +351,11 @@ int main(int argc, char* argv[]) {
     bool validop=false;
     if(operation=="+") {validop=true; accuresult=sum(data1);}
     if(operation=="*") {validop=true; accuresult=product(data1);}
+    if(operation=="mean") {validop=true; accuresult=statistics(data1).mean;}
+    if(operation=="median") {validop=true; accuresult=median(data1);}
+    if(operation=="stdev") {validop=true; accuresult=statistics(data1).stdev;}
+    if(operation=="min") {validop=true; accuresult=min(data1);}
+    if(operation=="max") {validop=true; accuresult=max(data1);}
     if(!validop) {
       ODINLOG(odinlog,errorLog) << "invalid accumulation operator: " << operation << STD_endl;
       return -1;
@@ -375,22 +390,24 @@ int main(int argc, char* argv[]) {
       int nvals=data1.numElements();
       if(maskptr) {
         nvals=0;
-        for(int i=0; i<maskptr->numElements(); i++) {
-          TinyVector<int,4> index=maskptr->create_index(i);
-          if( (*maskptr)(index)>0.0 ) {
+        for(int i=0; i<maskdata.numElements(); i++) {
+          TinyVector<int,4> index=maskdata.create_index(i);
+          if( maskdata(index)>0.0 ) {
             nvals++;
           }
         }
       }
 
-      if(histslots=="") {usage(prot); return -1;}
 
+      if(histslots=="") {usage(prot); return -1;}
       int nslots=atoi(histslots.c_str());
 
-      if(histmin=="") {usage(prot); return -1;}
-      float minval=atof(histmin.c_str());
-      if(histmax=="") {usage(prot); return -1;}
-      float maxval=atof(histmax.c_str());
+
+      statisticResult stats=statistics(data1,maskptr);
+      float minval=stats.min;
+      if(histmin!="") minval=atof(histmin.c_str());
+      float maxval=stats.max;
+      if(histmax!="") maxval=atof(histmax.c_str());
       ODINLOG(odinlog,infoLog) << "calculating histogram with nslots/minval/maxval=" << nslots <<  "/" << minval << "/" << maxval << STD_endl;
 
       if(minval>=maxval) {
@@ -403,7 +420,18 @@ int main(int argc, char* argv[]) {
 
       Data<float,1> xvals(nslots);
       Data<float,1> yvals(nslots); yvals=0.0;
-      if(minval>0.0 && maxval>0.0) { // Use log histogram
+
+
+      Data<float,4> histslotmap(data1.shape()); histslotmap=0.0;
+
+
+//      if(minval>0.0 && maxval>0.0) { // Use log histogram
+      if(loghist) { // Use log histogram
+
+        if( minval<=0.0 || maxval<=0.0 ) {
+          ODINLOG(odinlog,errorLog) << "positive minval/maxval required for log histogram, current minval/maxval=" << minval << "/" << maxval << STD_endl;
+          return -1;
+        }
 
         float minpow=log10(minval);
         float maxpow=log10(maxval);
@@ -415,16 +443,19 @@ int main(int argc, char* argv[]) {
 
         for(int i=0; i<data1.numElements(); i++) {
           TinyVector<int,4> index=data1.create_index(i);
-          if( !(maskptr && (*maskptr)(index)==0.0) ) {
+          if( !(maskptr && maskdata(index)==0.0) ) {
             float pow=log10(data1(index));
             int slot=int(secureDivision(pow-minpow,powrange)*nslots);
             ODINLOG(odinlog,normalDebug) << "pow/slot=" << pow << "/" << slot << STD_endl; 
-            if(slot>=0 && slot<nslots) yvals(slot)++;
+            if(slot>=0 && slot<nslots) {
+              yvals(slot)++;
+              histslotmap(index)=slot+stairoffset;
+            }
           }
         }
 
 
-      } else {
+      } else { // no log histogram
 
         float range=maxval-minval;
         float step=secureDivision(range,nslots);
@@ -434,11 +465,14 @@ int main(int argc, char* argv[]) {
 
         for(int i=0; i<data1.numElements(); i++) {
           TinyVector<int,4> index=data1.create_index(i);
-          if( !(maskptr && (*maskptr)(index)==0.0) ) {
+          if( !(maskptr && maskdata(index)==0.0) ) {
             float val=data1(index);
             int slot=int(secureDivision(val-minval,range)*nslots);
             ODINLOG(odinlog,normalDebug) << "val/slot=" << val << "/" << slot << STD_endl; 
-            if(slot>=0 && slot<nslots) yvals(slot)++;
+            if(slot>=0 && slot<nslots) {
+              yvals(slot)++;
+              histslotmap(index)=slot+stairoffset;
+            }
           }
         }
       }
@@ -446,6 +480,8 @@ int main(int argc, char* argv[]) {
       if(histfract) yvals/=sum(yvals); // Each slot reflects the fraction of total points
       yvals.write_asc_file(histfile, xvals);
 
+      if(histslotmapfile!="") if(histslotmap.autowrite(histslotmapfile,wopts,&prot)<0) return -1;
+
     }
 
 
@@ -461,7 +497,7 @@ int main(int argc, char* argv[]) {
       for(int i=0; i<meanresult.numElements(); i++) {
         TinyVector<int,4> index=meanresult.create_index(i);
         if(!index(0)) { // only once for all repetitions
-          if( !(maskptr && (*maskptr)(index)==0.0) ) {
+          if( !(maskptr && maskdata(index)==0.0) ) {
             statisticResult stats=statistics(data1(all,index(1),index(2),index(3)));
             meanresult(index)= stats.mean;
             fluctresult(index)=secureDivision(stats.stdev,stats.mean);
@@ -472,11 +508,8 @@ int main(int argc, char* argv[]) {
           }
         }
       }
-      if(weightmaskdata.size()) {
-        tcourseresult/=sum(weightmaskdata(0,all,all,all));
-      } else {
-        tcourseresult/=float(tcoursepts);
-      }
+      tcourseresult/=float(tcoursepts);
+
       if(meanfile!="")  if(meanresult.autowrite(meanfile,wopts,&prot)<0) return -1;
       if(fluctfile!="") if(fluctresult.autowrite(fluctfile,wopts,&prot)<0) return -1;
       if(stdevfile!="") if(stdevresult.autowrite(stdevfile,wopts,&prot)<0) return -1;
