@@ -2,8 +2,8 @@
                           geoedit.h  -  description
                              -------------------
     begin                : Mon Apr 15 18:40:55 CEST 2002
-    copyright            : (C) 2002 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
