@@ -233,19 +233,20 @@ bool MiViewFmri::init(const FileReadOpts& ropts, const Protocol& prot, const Fil
         onepixel=data->fmri(all,iz,iy,ix);
         float p=0.0;
         float z=0.0;
-        float sigchange=0.0;
+//        float sigchange=0.0;
         if(mean(onepixel)>sigthreshold) {
           correlationResult corr=correlation(data->designdata, onepixel);
           if(corr.r>0.0) { // take only positivie correlation
             p=corr.p;
             z=corr.z;
-            sigchange=fmri_eval(onepixel, data->designdata).rel_diff;
+//            sigchange=fmri_eval(onepixel, data->designdata).rel_diff;
           }
           data->brainvoxels++;
         }
         data->pmap(0,iz,iy,ix)=p;
         data->zmap(0,iz,iy,ix)=z;
-        data->smap(0,iz,iy,ix)=sigchange;
+//        data->smap(0,iz,iy,ix)=sigchange;
+        data->smap(0,iz,iy,ix)=fmri_eval(onepixel, data->designdata).rel_diff;
       }
     }
   }
@@ -404,12 +405,15 @@ void MiViewFmri::update() {
 
   ODINLOG(odinlog,normalDebug) << "dumpsmap=" << dumpsmap << STD_endl;
   if(dumpsmap!="") {
+/*
     Data<float,4> mask(get_overlay_map());
     Data<float,4> smap_mask(data->smap.shape());
 
     smap_mask=where(Array<float,4>(mask)>0.0, Array<float,4>(data->smap), float(0.0));
 
     smap_mask.autowrite(dumpsmap,FileWriteOpts(),&(data->protcopy));
+*/
+    data->smap.autowrite(dumpsmap,FileWriteOpts(),&(data->protcopy));
   }
 
 }
