@@ -88,6 +88,9 @@ MiViewOpts::MiViewOpts() {
   maplegendexport.set_cmdline_option("maplegend").set_description("Export map legend as bitmap to this file");
   append_member(maplegendexport,"maplegendexport");
 
+  legendexport.set_cmdline_option("legend").set_description("Export legend as bitmap to this file");
+  append_member(legendexport,"legendexport");
+
   noscale=false;
   noscale.set_cmdline_option("noscale").set_description("Disable scale in 2D/3D display");
   append_member(noscale,"noscale");
@@ -115,7 +118,7 @@ void MiViewView::usage() {
   Protocol prot;
   MiViewOpts mopts;
   FileReadOpts ropts;
-  FilterFactory filter;
+  FilterChain filter;
   MiViewFmri fmri;
   set_defaults(prot);
 
@@ -246,7 +249,8 @@ MiViewView::MiViewView(QWidget *parent) : QWidget(parent) {
   displaydata.set_label("Data Plot");
   displaywidget=new JDXwidget(displaydata, 1, this);
 
-  exportLegend(mopts.maplegendexport); // Do this after displaywidget is initialized, bur before dump. String will be checked in exportLegend()
+  export_legend(mopts.legendexport); // Do this after displaywidget is initialized, bur before dump. String will be checked in export_map_legend()
+  export_map_legend(mopts.maplegendexport); // Do this after displaywidget is initialized, bur before dump. String will be checked in export_map_legend()
 
   if(mopts.dump!="") {
     ODINLOG(odinlog,infoLog) << "Dumping images with prefix " << mopts.dump << STD_endl;
@@ -361,19 +365,34 @@ void MiViewView::writeTimecourse() {
 }
 
 
-void MiViewView::exportLegend(const STD_string& filename) {
-  Log<MiViewComp> odinlog("MiViewView","exportLegend");
+void MiViewView::export_legend(const STD_string& filename) {
+  Log<MiViewComp> odinlog("MiViewView","export_legend");
   if(filename=="") return;
   STD_string format=check_and_get_format(filename,get_possible_image_fileformats());
   if(format!="") {
     ODINLOG(odinlog,infoLog) << "Writing legend of format " << format <<  " to file " << filename << STD_endl;
+    displaywidget->write_legend(filename.c_str(), format.c_str());
+  }
+}
+
+
+void MiViewView::export_map_legend(const STD_string& filename) {
+  Log<MiViewComp> odinlog("MiViewView","export_map_legend");
+  if(filename=="") return;
+  STD_string format=check_and_get_format(filename,get_possible_image_fileformats());
+  if(format!="") {
+    ODINLOG(odinlog,infoLog) << "Writing map legend of format " << format <<  " to file " << filename << STD_endl;
     displaywidget->write_map_legend(filename.c_str(), format.c_str());
   }
 }
 
 
 void MiViewView::writeLegend() {
-  exportLegend(get_save_filename("File for Legend", "", "", this));
+  export_legend(get_save_filename("File for Legend", "", "", this));
+}
+
+void MiViewView::writeMapLegend() {
+  export_map_legend(get_save_filename("File for Map Legend", "", "", this));
 }
 
 void MiViewView::selectVoxel() {
@@ -559,15 +578,9 @@ void MiViewView::filedata2displaydata() {
 
   ODINLOG(odinlog,normalDebug) << "lowbound/uppbound=" << lowbound << "/" << uppbound << STD_endl;
 
-  if(mopts.noscale) {
-    // this will disable scale
-    ODINLOG(odinlog,normalDebug) << "Disabling scale" << STD_endl;
-    guiprops_cache.scale[displayScale].minval=0.0;
-    guiprops_cache.scale[displayScale].maxval=0.0;
-  } else {
-    guiprops_cache.scale[displayScale].minval=lowbound;
-    guiprops_cache.scale[displayScale].maxval=uppbound;
-  }
+  guiprops_cache.scale[displayScale].minval=lowbound;
+  guiprops_cache.scale[displayScale].maxval=uppbound;
+  guiprops_cache.scale[displayScale].enable=!mopts.noscale;
 
   displaydata.set_gui_props(guiprops_cache);
 
