@@ -74,13 +74,22 @@ bool OdinConf::init(QWidget* parent) {
 #ifdef USING_WIN32
 #ifdef USING_GCC // Assume MinGW
 
-  STD_string instprefix(get_installdir());
-  compiler=instprefix+SEPARATOR_STR+"bin"+SEPARATOR_STR+"g++";
+  STD_string instprefix_bin=get_installdir()+SEPARATOR_STR+"bin";
+
+  // hack for MinGW-gcc440_1.zip, otherwise libgmp-3.dll is not found
+  STD_string oldpath=getenv_nonnull("PATH");
+  if(oldpath.find(instprefix_bin) != 0) { // add only if cygnus_bin is not already 1st entry
+    STD_string path="PATH="+instprefix_bin+";"+oldpath;
+    ODINLOG(odinlog,normalDebug) << "oldpath/path=" << oldpath << "/" << path << STD_endl;
+    _putenv(path.c_str());
+  }
+
+  compiler=instprefix_bin+SEPARATOR_STR+"g++";
   linker=STD_string(compiler); // the same for GCC
 
-  // Try to find and use notepad2
-  STD_string notepad2_fname=instprefix+SEPARATOR_STR+"bin"+SEPARATOR_STR+"notepad2.exe";
-  if(filesize(notepad2_fname.c_str())>0) editor=notepad2_fname;
+  // Try to find and use notepad++
+  STD_string notepadpp_fname=instprefix_bin+SEPARATOR_STR+"notepad++.exe";
+  if(filesize(notepadpp_fname.c_str())>0) editor=notepadpp_fname;
 
 #else // Assume Visual C++ 6
 
@@ -191,9 +200,9 @@ STD_string OdinConf::get_binprefix() {
 
 STD_string OdinConf::get_homedir() {
   Log<OdinComp> odinlog("OdinConf","get_homedir");
-  JDXfileName result(secure_getenv("HOME"));
+  JDXfileName result(getenv_nonnull("HOME"));
 #ifdef USING_WIN32
-  result=secure_getenv("USERPROFILE"); // the windows 'home' directory
+  result=getenv_nonnull("USERPROFILE"); // the windows 'home' directory
 #endif
   if(result=="") ODINLOG(odinlog,warningLog) << "Cannot determine homedir" << STD_endl;
   ODINLOG(odinlog,normalDebug) << "result=" << result << STD_endl;
@@ -278,6 +287,7 @@ bool open_file_in_win32(const STD_string& location, const STD_string& prog) {
     if(errno==ENOENT)  ODINLOG(odinlog,errorLog) << "file not found" << STD_endl;
     if(errno==ENOEXEC) ODINLOG(odinlog,errorLog) << "exe not found" << STD_endl;
     if(errno==ENOMEM)  ODINLOG(odinlog,errorLog) << "no mem" << STD_endl;
+    return false;
   }
   return true;
 }
