@@ -319,11 +319,14 @@ STD_string IdeaDialog::hosttarget(bool debug, const STD_string& build_includes,
   STD_string result;
   result+="configure-"+target+":\n";
   result+=mprefix+"cd "+target+"/build && "+confstr+"\n";
-  result+=mprefix+"cat "+target+"/build/libtool | sed s/\\\\.libs/libs/g > "+target+"/build/libtool.tmp\n"; // dot in .libs confuses lib.exe in MinGW
+  result+=mprefix+"cat "+target+"/build/libtool | sed s/\\\\.libs/tmplibfiles/g > "+target+"/build/libtool.tmp\n"; // dot in .libs (dir for temporary lib files) confuses lib.exe in MinGW
   result+=mprefix+"mv "+target+"/build/libtool.tmp "+target+"/build/libtool\n\n";
 
   result+="build-"+target+":\n";
-  result+=mprefix+"cd "+target+"/build && "+make_install+"\n\n";
+  result+=mprefix+"cd "+target+"/build && "+make_install+"\n";
+  // add lib prefix, if missing
+  result+=mprefix+"for odinlibname in tjutils odinpara odinseq ; do if test -f "+target+"/lib/$${odinlibname}.lib ; then mv "+target+"/lib/$${odinlibname}.lib "+target+"/lib/lib$${odinlibname}.lib ; fi; done\n\n";
+
   result+="build-"+target+"-clean: build-"+target+"\n";
   result+=mprefix+"rm -rf "+target+"/build\n\n";
 
@@ -461,7 +464,7 @@ void IdeaDialog::do_compile() {
   // hacking configure:
   // 1) default file extension for C++ source code since .cc somehow fails with autoconf 2.59 ...
   // 2) replace limits.h (which fails on VB15) by stdlib.h as header for GCC sanity check
-  makefile+=mprefix+"cat ${ARCHNAME}/configure | sed s/ac_ext=cc/ac_ext=cpp/ | sed s/limits.h/stdlib.h/g> ${ARCHNAME}/configure.tmp\n";
+  makefile+=mprefix+"cat ${ARCHNAME}/configure | sed s/ac_ext=cc/ac_ext=cpp/ | sed s/limits.h/stdlib.h/g > ${ARCHNAME}/configure.tmp\n";
   makefile+=mprefix+"mv ${ARCHNAME}/configure.tmp ${ARCHNAME}/configure\n";
 
 
@@ -543,15 +546,6 @@ void IdeaDialog::do_compile() {
   makefile+="rebuild-clean: clean unpack configure build-clean\n\n";
 
 
-  // Set up IDEA sequence
-  makefile+="ideaseq:\n";
-  makefile+=mprefix+"mkdir -p ${ODIN2IDEADIR_MGWPATH}\n";
-  makefile+=mprefix+"echo \"\\\""+replaceStr(conf_cache.get_installdir(),"\\","/")+"/bin/odin.exe\\\" -m \\\"${ODIN2IDEADIR_SLASH}\\\"\" > ${ODIN2IDEADIR_MGWPATH}/odin.bat\n";
-
-  // copying files
-  makefile+=mprefix+"cp ${ARCHNAME}/platforms/IDEA_n4/odin2idea.cpp ${ODIN2IDEADIR_MGWPATH}\n";
-  makefile+=mprefix+"cp ${ARCHNAME}/platforms/IDEA_n4/tjdx4idea.h ${ODIN2IDEADIR_MGWPATH}\n";
-  makefile+=mprefix+"cat ${ARCHNAME}/platforms/IDEA_n4/makefile.trs | sed s/ODIN2IDEA_TAG/${ODIN2IDEA_LABEL}/ > ${ODIN2IDEADIR_MGWPATH}/makefile.trs\n";
 
   // find location of IDEA libs
   JDXfileName idea_libdir;
@@ -562,17 +556,25 @@ void IdeaDialog::do_compile() {
     idea_libdir=opts_cache.ideadir+"/n4_prod/x86/prod/lib"; // default (e.g. VA15)
   }
 
-  // Create libs_host(d).txt which contains all libs found in the directory where IDEA libs are stored
-  makefile+=mprefix+"rm -f ${ODIN2IDEADIR_MGWPATH}/libs_host.txt ${ODIN2IDEADIR_MGWPATH}/libs_hostd.txt\n";
-  makefile+=mprefix+"for file in "+mgwpath(idea_libdir)+"/*d.lib; do \\\n";
-  makefile+="\t  bname=`basename $$file d.lib`; \\\n";
-  makefile+="\t  if test -f "+mgwpath(idea_libdir)+"/$${bname}.lib; then \\\n";
-  makefile+="\t    echo \"LDLIBS += \"$${bname}.lib  >> ${ODIN2IDEADIR_MGWPATH}/libs_host.txt; \\\n";
-  makefile+="\t    echo \"LDDLLS += \"$${bname}.dll  >> ${ODIN2IDEADIR_MGWPATH}/libs_host.txt; \\\n";
-  makefile+="\t    echo \"LDLIBS += \"$${bname}d.lib >> ${ODIN2IDEADIR_MGWPATH}/libs_hostd.txt; \\\n";
-  makefile+="\t    echo \"LDDLLS += \"$${bname}d.dll >> ${ODIN2IDEADIR_MGWPATH}/libs_hostd.txt; \\\n";
-  makefile+="\t  fi; \\\n";
-  makefile+="\tdone\n";
+  bool has_idea_libdir=false;
+  JDXfileName testdir;
+  testdir.set_dir(true);
+  testdir=idea_libdir;
+  if(testdir.exists()) has_idea_libdir=true;
+
+  // shell command as separate variable to avoid problems with linebreak under MSYS make
+  if(has_idea_libdir) {
+    makefile+="LIB_HOST_CMD = \\\n";
+    makefile+="for file in "+mgwpath(idea_libdir)+"/*d.lib; do \\\n";
+    makefile+="  bname=$$(basename $$file d.lib); \\\n";
+    makefile+="  if test -f "+mgwpath(idea_libdir)+"/$${bname}.lib; then \\\n";
+    makefile+="    echo \"LDLIBS += \"$${bname}.lib  >> ${ODIN2IDEADIR_MGWPATH}/libs_host.txt; \\\n";
+    makefile+="    echo \"LDDLLS += \"$${bname}.dll  >> ${ODIN2IDEADIR_MGWPATH}/libs_host.txt; \\\n";
+    makefile+="    echo \"LDLIBS += \"$${bname}d.lib >> ${ODIN2IDEADIR_MGWPATH}/libs_hostd.txt; \\\n";
+    makefile+="    echo \"LDDLLS += \"$${bname}d.dll >> ${ODIN2IDEADIR_MGWPATH}/libs_hostd.txt; \\\n";
+    makefile+="  fi; \\\n";
+    makefile+="done\n\n";
+  }
 
   // find location of IDEA includes
   STD_list<STD_string> possible_includepaths;
@@ -599,8 +601,6 @@ void IdeaDialog::do_compile() {
   possible_includepaths.push_back("n4/pkg/MrServers/MrProtSrv/MrProtocol/UILink/StdProtRes");
   possible_includepaths.push_back("n4/pkg/MrCommon/MrCFramework/STL");
 
-  JDXfileName testdir;
-  testdir.set_dir(true);
   STD_string idea_includes;
   for(STD_list<STD_string>::const_iterator it=possible_includepaths.begin(); it!=possible_includepaths.end(); ++it) {
     testdir=opts_cache.ideadir+SEPARATOR_STR+(*it);
@@ -608,10 +608,15 @@ void IdeaDialog::do_compile() {
       idea_includes+=" "+opts_cache.get_ideadir_slash()+"/"+(*it);
     }
   }
-  makefile+=mprefix+"rm -f ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt\n";
-  makefile+=mprefix+"for include in "+idea_includes+"; do \\\n";
-  makefile+="\t  echo \"CPPFLAGS_LOCAL += -I$${include}\" >> ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt; \\\n";
-  makefile+="\tdone\n";
+
+  // shell command as separate variable to avoid problems with linebreak under MSYS make
+  makefile+="IDEA_INCLUDES_CMD = \\\n";
+  makefile+="for include in "+idea_includes+"; do \\\n";
+  makefile+="  echo \"CPPFLAGS_LOCAL += -I$${include}\" >> ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt; \\\n";
+  makefile+="done\n\n";
+
+
+
 
   STD_string idea_defines;
 
@@ -620,8 +625,13 @@ void IdeaDialog::do_compile() {
   if(testfile.exists()) idea_defines="-DHAVE_iPAT";
 
   // checking whether standard STL header 'vector' is available (which is the case on VB13)
-  testfile=opts_cache.ideadir+"/n4_opensource/STLport/stlport/vector";
-  if(testfile.exists()) idea_defines+=" -DHAVE_STL_VECTOR";
+
+  STD_list<STD_string> vector_header_alternatives;
+  vector_header_alternatives.push_back(opts_cache.ideadir+"/n4_opensource/STLport/stlport/vector");
+  vector_header_alternatives.push_back(opts_cache.ideadir+"/n4/opensource/STLport/stlport/vector"); // VB18P
+  JDXfileName vector_header_file;
+  select_alternative(vector_header_file, vector_header_alternatives);
+  if(vector_header_file.exists()) idea_defines+=" -DHAVE_STL_VECTOR";
 
 
   // Checking for MultiByteToWideChar in MrProt.h
@@ -664,41 +674,81 @@ void IdeaDialog::do_compile() {
   testfile=opts_cache.ideadir+"/n4/x86/delivery/lib/libGTR.lib";
   bool has_libgtr=testfile.exists();
 
+
+  // shell command as separate variable to avoid problems with linebreak under MSYS make
+  makefile+="VXWORKS_MAKEFILE_CMD = \\\n";
+  makefile+="cat ${ARCHNAME}/platforms/IDEA_n4/"+opts_cache.get_vxworks_Makefile()+" | \\\n";
+  makefile+="awk -v repl=${ODIN2IDEA_LABEL} '{gsub(\"_ODIN2IDEA_TAG_\",repl); print; }' | \\\n";
+  makefile+="awk -v repl=\"$$(cat ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt)\"  '{gsub(\"_IDEA_INCLUDES_TAG_\",repl); print; }' | \\\n";
+  makefile+="awk -v repl=\""+odindir_slash+"/vxworks\"  '{gsub(\"_ODINDIR_TAG_\",repl); print; }' | \\\n";
+  makefile+="awk -v repl=\""+idea_defines+"\" '{gsub(\"_CPPFLAGS_TAG_\",repl); print; }' \\\n";
+  makefile+="> ${ODIN2IDEADIR_MGWPATH}/"+opts_cache.get_vxworks_Makefile()+"\n\n";
+
+  // shell command as separate variable to avoid problems with linebreak under MSYS make
+  STD_string idea_libdir_backslash=replaceStr(idea_libdir,"\\","\\\\\\\\"); // double protect backslash from shell
+  makefile+="HOST_MAKEFILE_CMD = \\\n";
+  makefile+="for HOSTLETTER in \"d\" \"\" ; do \\\n";
+  makefile+="  cat ${ARCHNAME}/platforms/IDEA_n4/MakHost.txt | \\\n";
+  makefile+="  awk -v repl=\"$$HOSTLETTER\" '{gsub(\"_DEBUGLETTER_TAG_\",repl); print; }' | \\\n";
+  makefile+="  awk -v repl=${ODIN2IDEA_LABEL} '{gsub(\"_ODIN2IDEA_TAG_\",repl); print; }' | \\\n";
+  makefile+="  awk -v repl=\""+idea_defines+"\" '{gsub(\"_CPPFLAGS_TAG_\",repl); print; }' | \\\n";
+  makefile+="  awk -v repl=\""+idea_libdir_backslash+"\" '{gsub(\"_IDEA_LIBDIR_TAG_\",repl); print; }' | \\\n";
+  if(has_libgtr)      makefile+="  awk '{gsub(\"\\\\\\#REM_IF_HAS_LIBGTR \",\"\"); print; }' | \\\n";
+  if(has_idea_libdir) makefile+="  awk -v repl=\"$$(cat ${ODIN2IDEADIR_MGWPATH}/libs_host$${HOSTLETTER}.txt)\"  '{gsub(\"\\\\\\#REPL_IF_HAS_IDEA_HOST_LIBS\",repl); print; }' | \\\n";
+  makefile+="  awk -v repl=\"$$(cat ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt)\"  '{gsub(\"_IDEA_INCLUDES_TAG_\",repl); print; }' | \\\n";
+  makefile+="  awk -v repl=\""+odindir_slash+"/host$${HOSTLETTER}\"  '{gsub(\"_ODINDIR_TAG_\",repl); print; }' \\\n";
+  makefile+="  > ${ODIN2IDEADIR_MGWPATH}/MakHost$${HOSTLETTER}.txt; \\\n";
+  makefile+="done\n\n";
+
+  // shell command as separate variable to avoid problems with linebreak under MSYS make
+  makefile+="VB_MAKEFILE_CMD = \\\n";
+  makefile+="cat ${ARCHNAME}/platforms/IDEA_n4/odin.mk | \\\n";
+  makefile+="awk -v repl=${ODIN2IDEA_LABEL} '{gsub(\"_ODIN2IDEA_TAG_\",repl); print; }' | \\\n";
+  makefile+="awk -v repl=\"$$(cat ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt)\"  '{gsub(\"_IDEA_INCLUDES_TAG_\",repl); print; }' | \\\n";
+  makefile+="awk -v repl=\""+idea_defines+"\" '{gsub(\"_CPPFLAGS_TAG_\",repl); print; }' | \\\n";
+  makefile+="awk -v repl=\""+odindir_slash+"\"  '{gsub(\"_ODINDIR_TAG_\",repl); print; }' \\\n";
+  makefile+="> ${ODIN2IDEADIR_MGWPATH}/${ODIN2IDEA_LABEL}.mk\n\n";
+
+
+
+
+
+
+
+  // Set up IDEA sequence
+  makefile+="ideaseq:\n";
+  makefile+=mprefix+"mkdir -p ${ODIN2IDEADIR_MGWPATH}\n";
+  makefile+=mprefix+"echo \"\\\""+replaceStr(conf_cache.get_installdir(),"\\","/")+"/bin/odin.exe\\\" -m \\\"${ODIN2IDEADIR_SLASH}\\\"\" > ${ODIN2IDEADIR_MGWPATH}/odin.bat\n";
+
+  // copying files
+  makefile+=mprefix+"cp ${ARCHNAME}/platforms/IDEA_n4/odin2idea.cpp ${ODIN2IDEADIR_MGWPATH}\n";
+  makefile+=mprefix+"cp ${ARCHNAME}/platforms/IDEA_n4/tjdx4idea.h ${ODIN2IDEADIR_MGWPATH}\n";
+  makefile+=mprefix+"cat ${ARCHNAME}/platforms/IDEA_n4/makefile.trs | sed s/ODIN2IDEA_TAG/${ODIN2IDEA_LABEL}/ > ${ODIN2IDEADIR_MGWPATH}/makefile.trs\n";
+
+
+
+
+  // Create libs_host(d).txt which contains all libs found in the directory where IDEA libs are stored
+  if(has_idea_libdir) {
+    makefile+=mprefix+"rm -f ${ODIN2IDEADIR_MGWPATH}/libs_host.txt ${ODIN2IDEADIR_MGWPATH}/libs_hostd.txt\n";
+    makefile+=mprefix+"${LIB_HOST_CMD}\n";
+  }
+
+  makefile+=mprefix+"rm -f ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt\n";
+  makefile+=mprefix+"${IDEA_INCLUDES_CMD}\n";
+
+
   // Creating batch script for Makefiles
-  makefile+=mprefix+"cat ${ARCHNAME}/platforms/IDEA_n4/MakSeq.bat | \\\n";
-  makefile+="\tsed s/_VXWORKS_EXT_TAG_/"+opts_cache.get_vxworks_ext()+"/g \\\n";
-  makefile+="\t> ${ODIN2IDEADIR_MGWPATH}/MakSeq.bat\n";
+  makefile+=mprefix+"cat ${ARCHNAME}/platforms/IDEA_n4/MakSeq.bat | sed s/_VXWORKS_EXT_TAG_/"+opts_cache.get_vxworks_ext()+"/g > ${ODIN2IDEADIR_MGWPATH}/MakSeq.bat\n";
 
   // creating VA*/VB12 Makefile for vxworks
-  makefile+=mprefix+"cat ${ARCHNAME}/platforms/IDEA_n4/"+opts_cache.get_vxworks_Makefile()+" | \\\n";
-  makefile+="\tawk -v repl=${ODIN2IDEA_LABEL} '{gsub(\"_ODIN2IDEA_TAG_\",repl); print; }' | \\\n";
-  makefile+="\tawk -v repl=\"`cat ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt`\"  '{gsub(\"_IDEA_INCLUDES_TAG_\",repl); print; }' | \\\n";
-  makefile+="\tawk -v repl=\""+odindir_slash+"/vxworks\"  '{gsub(\"_ODINDIR_TAG_\",repl); print; }' | \\\n";
-  makefile+="\tawk -v repl=\""+idea_defines+"\" '{gsub(\"_CPPFLAGS_TAG_\",repl); print; }' \\\n";
-  makefile+="\t> ${ODIN2IDEADIR_MGWPATH}/"+opts_cache.get_vxworks_Makefile()+"\n";
+  makefile+=mprefix+"${VXWORKS_MAKEFILE_CMD}\n";
 
   // creating VA*/VB12 Makefiles for host(d)
-  STD_string idea_libdir_backslash=replaceStr(idea_libdir,"\\","\\\\\\\\"); // double protect backslash from shell
-  makefile+=mprefix+"for HOSTLETTER in \"d\" \"\" ; do \\\n";
-  makefile+="\t  cat ${ARCHNAME}/platforms/IDEA_n4/MakHost.txt | \\\n";
-  makefile+="\t  awk -v repl=\"$$HOSTLETTER\" '{gsub(\"_DEBUGLETTER_TAG_\",repl); print; }' | \\\n";
-  makefile+="\t  awk -v repl=${ODIN2IDEA_LABEL} '{gsub(\"_ODIN2IDEA_TAG_\",repl); print; }' | \\\n";
-  makefile+="\t  awk -v repl=\""+idea_defines+"\" '{gsub(\"_CPPFLAGS_TAG_\",repl); print; }' | \\\n";
-  makefile+="\t  awk -v repl=\""+idea_libdir_backslash+"\" '{gsub(\"_IDEA_LIBDIR_TAG_\",repl); print; }' | \\\n";
-  if(has_libgtr) makefile+="\t  awk '{gsub(\"#REM_IF_HAS_LIBGTR \",\"\"); print; }' | \\\n";
-  makefile+="\t  awk -v repl=\"`cat ${ODIN2IDEADIR_MGWPATH}/libs_host$${HOSTLETTER}.txt`\"  '{gsub(\"_IDEA_HOST_LIBS_TAG_\",repl); print; }' | \\\n";
-  makefile+="\t  awk -v repl=\"`cat ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt`\"  '{gsub(\"_IDEA_INCLUDES_TAG_\",repl); print; }' | \\\n";
-  makefile+="\t  awk -v repl=\""+odindir_slash+"/host$${HOSTLETTER}\"  '{gsub(\"_ODINDIR_TAG_\",repl); print; }' \\\n";
-  makefile+="\t  > ${ODIN2IDEADIR_MGWPATH}/MakHost$${HOSTLETTER}.txt; \\\n";
-  makefile+="\tdone\n";
+  makefile+=mprefix+"${HOST_MAKEFILE_CMD}\n";
 
-  // creating Makefile for VB13
-  makefile+=mprefix+"cat ${ARCHNAME}/platforms/IDEA_n4/odin.mk | \\\n";
-  makefile+="\tawk -v repl=${ODIN2IDEA_LABEL} '{gsub(\"_ODIN2IDEA_TAG_\",repl); print; }' | \\\n";
-  makefile+="\tawk -v repl=\"`cat ${ODIN2IDEADIR_MGWPATH}/idea_includes.txt`\"  '{gsub(\"_IDEA_INCLUDES_TAG_\",repl); print; }' | \\\n";
-  makefile+="\tawk -v repl=\""+idea_defines+"\" '{gsub(\"_CPPFLAGS_TAG_\",repl); print; }' | \\\n";
-  makefile+="\tawk -v repl=\""+odindir_slash+"\"  '{gsub(\"_ODINDIR_TAG_\",repl); print; }' \\\n";
-  makefile+="\t> ${ODIN2IDEADIR_MGWPATH}/${ODIN2IDEA_LABEL}.mk\n\n";
+  // creating Makefile for VB13 and later
+  makefile+=mprefix+"${VB_MAKEFILE_CMD}\n";
 
 
   // Set up Ice
@@ -723,7 +773,7 @@ void IdeaDialog::do_compile() {
    // set environment variables which would be set by cygwin.bat otherwise
 #ifdef USING_WIN32
 /*
-  STD_string oldpath=secure_getenv("PATH");
+  STD_string oldpath=getenv_nonnull("PATH");
   if(oldpath.find(cygnus_bin) != 0) { // add only if cygnus_bin is not already 1st entry
     STD_string path="PATH="+cygnus_bin+";"+oldpath;
     ODINLOG(odinlog,normalDebug) << "oldpath/path=" << oldpath << "/" << path << STD_endl;
@@ -787,6 +837,10 @@ bool IdeaDialog::execute_make(const STD_string& make, const STD_string& target)
 void IdeaDialog::update() {
   Log<OdinComp> odinlog("IdeaDialog","update");
 
+  if(!checkdir(opts_cache.ideadir.c_str())) {
+    error_msg("Cannot find IDEA installation under "+opts_cache.ideadir);
+    return;
+  }
 
   // check for space characters
   if(opts_cache.odindir.find(" ") != STD_string::npos) {
