@@ -2,8 +2,8 @@
                           odindialog_process.h  -  description
                              -------------------
     begin                : Sun Oct 2 21:30:11 CEST 2005
-    copyright            : (C) 2003 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
