@@ -2,8 +2,8 @@
                           odinplot.h  -  description
                              -------------------
     begin                : Mon Jul 26 2004
-    copyright            : (C) 2003 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
