@@ -505,8 +505,11 @@ void OdinView::kspace() {
   geometryMode geomode=method->get_geometry().get_Mode();
   for(int i=0; i<n_directions; i++) {
     if(geomode==voxel_3d || i<sliceDirection) { // Excluding 3rd direction in slicepack mode
-      float kmaxdir=secureDivision( PII * method->get_commonPars().get_MatrixSize(direction(i)) , method->get_geometry().get_FOV(direction(i)) );
-      kmax=STD_max(kmax,kmaxdir);
+      unsigned int n=method->get_commonPars().get_MatrixSize(direction(i));
+      if(n>1) {
+        float kmaxdir=secureDivision( PII * n , method->get_geometry().get_FOV(direction(i)) );
+        kmax=STD_max(kmax,kmaxdir);
+      }
     }
   }
 
@@ -629,6 +632,10 @@ void OdinView::bruker_scan(bool autorg) {
 void OdinView::pv_scan() {bruker_scan(false);}
 void OdinView::pv_rgscan() {bruker_scan(true);}
 
+void OdinView::pv_howto() {
+  settings.open_ascfile(settings.get_installdir()+SEPARATOR_STR+"share"+SEPARATOR_STR+"doc"+SEPARATOR_STR+"odin"+SEPARATOR_STR+"Paravision"+SEPARATOR_STR+"HOWTO.txt",subprocs);
+}
+
 
 void OdinView::ideaevents() {
   Log<OdinComp> odinlog("OdinView","ideaevents");
@@ -655,6 +662,10 @@ void OdinView::ideaevents() {
   evdlg->show();
 }
 
+void OdinView::ideahowto() {
+  settings.open_ascfile(settings.get_installdir()+SEPARATOR_STR+"share"+SEPARATOR_STR+"doc"+SEPARATOR_STR+"odin"+SEPARATOR_STR+"IDEA_n4"+SEPARATOR_STR+"HOWTO.txt",subprocs);
+}
+
 
 void OdinView::epiccode() {
   Log<OdinComp> odinlog("OdinView","epiccode");
