@@ -2,8 +2,8 @@
                           odinview.h  -  description
                              -------------------
     begin                : Sun Sep 28 21:30:11 CEST 2003
-    copyright            : (C) 2003 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
