@@ -8,7 +8,9 @@
 //////////////////////////////////////////////////
 
 int fileio_autowrite(const Data<float,4>& data, const STD_string& filename, const FileWriteOpts& opts, const Protocol* prot) {
+  Log<OdinData> odinlog("","fileio_autowrite");
   FileIO::ProtocolDataMap pdmap;
+  ODINLOG(odinlog,normalDebug) << "filename:opts.format:opts.datatype=" << filename << ":" << opts.format << ":" << opts.datatype << STD_endl;
 
   if(prot) {
     pdmap[*prot].reference(data);
@@ -141,6 +143,7 @@ class DataTest : public UnitTest {
         return false;
       }
 
+/*
       // Test non-upscaled conversion of small numbers
       smallvals.convert_to(dst,noupscale);
       minval=min(dst);
@@ -152,11 +155,11 @@ class DataTest : public UnitTest {
         ODINLOG(odinlog,errorLog) << "minnum/maxnum=" << minnum << "/" << maxnum << STD_endl;
         return false;
       }
-
+*/
 
       // do an additional test without auto-scaling if data is signed
       if(std::numeric_limits<Type>::is_signed) {
-        testarray.convert_to(dst,noscale);
+        testarray.convert_to(dst,false);
         float sumdiff=sum(dst)-sum(testarray);
         if(fabs(sumdiff)>0.1) {
           ODINLOG(odinlog,errorLog) << prefix << "no-scale sum sumdiff=" << sumdiff << STD_endl;
@@ -216,7 +219,7 @@ class DataTest : public UnitTest {
     }
 
     // Cross-wise testing of template vs. format read/write
-    if(testarray.write(TypeTraits::type2label((Type)0),testfname,autoscale)) { // implicit conversion, use full range of integer
+    if(testarray.write(TypeTraits::type2label((Type)0),testfname,true)) { // implicit conversion, use full range of integer
       ODINLOG(odinlog,errorLog) << prefix << "write(" << TypeTraits::type2label((Type)0) << "," << testfname <<")" << STD_endl;
       return false;
     }
