@@ -2,8 +2,8 @@
                           data.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2001 by Thies Jochimsen & Michael von Mengershausen
-    email                : jochimse@cns.mpg.de  mengers@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen & Michael von Mengershausen
+    email                : thies@jochimsen.de  mengers@cns.mpg.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -62,7 +62,9 @@
 
 
 #include <blitz/array.h>
+#ifdef HAVE_BLITZ_TINYVEC_ET
 #include <blitz/tinyvec-et.h> // to use arithmetics of TinyVectors
+#endif
 using namespace blitz;
 
 
@@ -206,8 +208,7 @@ public:
   */
   template<class T_expr>
   inline Data<T,N_rank>& operator = (BZ_ETPARM(_bz_ArrayExpr<T_expr>) expr) {
-    typedef _bz_typename T_expr::T_numtype T_numtype;
-    evaluate(expr, _bz_update<T_numtype, _bz_typename T_expr::T_numtype>());
+    Data<T,N_rank>::reference(Data<T,N_rank>(expr)); // forwarding to constructor
     return *this;
   }
 
@@ -217,18 +218,18 @@ public:
   Data<T,N_rank>& operator = (const tjarray<tjvector<T>,T>& a);
 
 
-  // resolve ambiguities
-  Array<T,N_rank> operator + (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)+Array<T,N_rank>(b));}
-  Array<T,N_rank> operator - (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)-Array<T,N_rank>(b));}
-  Array<T,N_rank> operator * (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)*Array<T,N_rank>(b));}
-  Array<T,N_rank> operator / (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)/Array<T,N_rank>(b));}
+  // resolve ambiguities, appears to be obsolete with blitz-0.9 and later versions
+//  Array<T,N_rank> operator + (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)+Array<T,N_rank>(b));}
+//  Array<T,N_rank> operator - (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)-Array<T,N_rank>(b));}
+//  Array<T,N_rank> operator * (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)*Array<T,N_rank>(b));}
+//  Array<T,N_rank> operator / (const Data<T,N_rank>& b) const {return Array<T,N_rank>(Array<T,N_rank>(*this)/Array<T,N_rank>(b));}
 
 
-  // resolve ambiguities
-  Array<T,N_rank> operator + (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)+v);}
-  Array<T,N_rank> operator - (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)-v);}
-  Array<T,N_rank> operator * (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)*v);}
-  Array<T,N_rank> operator / (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)/v);}
+  // resolve ambiguities, appears to be obsolete with blitz-0.9 and later versions
+//  Array<T,N_rank> operator + (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)+v);}
+//  Array<T,N_rank> operator - (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)-v);}
+//  Array<T,N_rank> operator * (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)*v);}
+//  Array<T,N_rank> operator / (const T& v) const {return Array<T,N_rank>(Array<T,N_rank>(*this)/v);}
 
 
 
@@ -253,17 +254,19 @@ public:
 /**
   * Writes the array to a raw data file 'filename' of type 'format' which can be one of
   * 's8bit, u8bit, s16bit, u16bit, s32bit, u32bit, float or double'.
+  * If 'autoscale' is true, use full range of integer values (if applicable).
   * - Return value: 0 if succesful, otherwise -1
   */
-  int write(const STD_string& format,const STD_string& filename, autoscaleOption scaleopt=autoscale) const;
+  int write(const STD_string& format,const STD_string& filename, bool autoscale=true) const;
 
 
 /**
   * Writes the array to a raw data file 'filename' of type 'T2'.
+  * If 'autoscale' is true, use full range of integer values (if applicable).
   * - Return value: 0 if succesful, otherwise -1
   */
   template<typename T2>
-  int write(const STD_string& filename, autoscaleOption scaleopt=autoscale) const;
+  int write(const STD_string& filename, bool autoscale=true) const;
 
 
 
@@ -350,14 +353,14 @@ public:
 
 /**
   * Converts the array to type 'T2', with dimensionality 'N_rank2' and stores the result in 'dst'.
-  * The scaling strategy can be specified by 'scaleopt'.
   * 'dst' will be unique, i.e. no other references to the array exist.
   * In addition to changing 'dst', a reference to the same array is returned for convenience.
+  * If 'autoscale' is true, use full range of integer values (if applicable).
   */
-  template<typename T2, int N_rank2> Data<T2,N_rank2>& convert_to(Data<T2,N_rank2>& dst, autoscaleOption scaleopt=autoscale) const;
+  template<typename T2, int N_rank2> Data<T2,N_rank2>& convert_to(Data<T2,N_rank2>& dst, bool autoscale=true) const;
 
-  // specialization which uses reference if type/rank are same and scale/offset==0.0 to reduce memory usage
-  Data<T,N_rank>& convert_to(Data<T,N_rank>& dst, autoscaleOption scaleopt=autoscale) const;
+  // specialization which uses reference if type/rank are same and scale/offset==1.0/0.0 to reduce memory usage
+  Data<T,N_rank>& convert_to(Data<T,N_rank>& dst, bool autoscale=true) const;
 
 
 /**
@@ -429,7 +432,7 @@ TinyVector<int,N_rank> index2extent(const TinyVector<int,N_rank>& shape, unsigne
 // leave this function outside of class Data, otherwise it screws up
 // when using optimization
 template<typename T, int N_rank, typename T2>
-void convert_from_ptr(Data<T,N_rank>& dst, const T2* src, const TinyVector<int, N_rank>& shape, autoscaleOption scaleopt=autoscale) {
+void convert_from_ptr(Data<T,N_rank>& dst, const T2* src, const TinyVector<int, N_rank>& shape, bool autoscale=true) {
   Log<OdinData> odinlog("Data","convert_from_ptr");
 
   int dstsize=product(shape);
@@ -438,7 +441,7 @@ void convert_from_ptr(Data<T,N_rank>& dst, const T2* src, const TinyVector<int,
 
   dst.resize(shape);
 
-  Converter::convert_array(src, dst.c_array(), srcsize, dstsize, scaleopt);
+  Converter::convert_array(src, dst.c_array(), srcsize, dstsize, autoscale);
 }
 
 // specialization in case the type is the same
@@ -516,7 +519,7 @@ Data<T,N_rank>& Data<T,N_rank>::operator = (const tjarray<tjvector<T>,T>& a) {
     ODINLOG(odinlog,normalDebug) << "nn(pad)" << nn << STD_endl;
     TinyVector<int,N_rank> tv;
     for(unsigned int i=0; i<N_rank; i++) tv(i)=nn[i];
-    resize(tv);
+    Data<T,N_rank>::resize(tv); // scope reuired by GCC 4.7
     for(unsigned int i=0;i<a.total();i++) (*this)(create_index(i))=a[i];
   } else ODINLOG(odinlog,errorLog) << "dimension mismatch: this=" << N_rank<< " < tjarray=" << a.dim() << STD_endl;
   return *this;
@@ -575,16 +578,16 @@ int Data<T,N_rank>::read(const STD_string& filename, LONGEST_INT offset) {
 ////////////////////////////////////////////////////////////////////////////
 
 template<typename T,int N_rank>
-int Data<T,N_rank>::write(const STD_string& format, const STD_string& filename, autoscaleOption scaleopt) const {
+int Data<T,N_rank>::write(const STD_string& format, const STD_string& filename, bool autoscale) const {
   Log<OdinData> odinlog("Data","write");
-  if(format==TypeTraits::type2label((u8bit)0))  return write<u8bit> (filename,scaleopt);
-  if(format==TypeTraits::type2label((s8bit)0))  return write<s8bit> (filename,scaleopt);
-  if(format==TypeTraits::type2label((u16bit)0)) return write<u16bit>(filename,scaleopt);
-  if(format==TypeTraits::type2label((s16bit)0)) return write<s16bit>(filename,scaleopt);
-  if(format==TypeTraits::type2label((u32bit)0)) return write<u32bit>(filename,scaleopt);
-  if(format==TypeTraits::type2label((s32bit)0)) return write<s32bit>(filename,scaleopt);
-  if(format==TypeTraits::type2label((float)0))  return write<float> (filename,scaleopt);
-  if(format==TypeTraits::type2label((double)0)) return write<double>(filename,scaleopt);
+  if(format==TypeTraits::type2label((u8bit)0))  return write<u8bit> (filename,autoscale);
+  if(format==TypeTraits::type2label((s8bit)0))  return write<s8bit> (filename,autoscale);
+  if(format==TypeTraits::type2label((u16bit)0)) return write<u16bit>(filename,autoscale);
+  if(format==TypeTraits::type2label((s16bit)0)) return write<s16bit>(filename,autoscale);
+  if(format==TypeTraits::type2label((u32bit)0)) return write<u32bit>(filename,autoscale);
+  if(format==TypeTraits::type2label((s32bit)0)) return write<s32bit>(filename,autoscale);
+  if(format==TypeTraits::type2label((float)0))  return write<float> (filename,autoscale);
+  if(format==TypeTraits::type2label((double)0)) return write<double>(filename,autoscale);
   ODINLOG(odinlog,errorLog) << "Unable to write file " << filename << " with data type " << format << STD_endl;
   return -1;
 }
@@ -620,13 +623,13 @@ int Data<T,N_rank>::write(const STD_string& filename, fopenMode mode) const {
 
 template<typename T,int N_rank>
 template<typename T2>
-  int Data<T,N_rank>::write(const STD_string& filename, autoscaleOption scaleopt) const {
+  int Data<T,N_rank>::write(const STD_string& filename, bool autoscale) const {
   Log<OdinData> odinlog("Data","write");
 
   rmfile(filename.c_str()); // remove old file to get new file size with mmap
 
   ODINLOG(odinlog,normalDebug) << "mem(pre): " << Profiler::get_memory_usage() << STD_endl;
-  Data<T2,N_rank> converted_data; convert_to(converted_data,scaleopt);
+  Data<T2,N_rank> converted_data; convert_to(converted_data,autoscale);
   ODINLOG(odinlog,normalDebug) << "mem(cnv): " << Profiler::get_memory_usage() << STD_endl;
   Data<T2,N_rank> filedata(filename,false,converted_data.shape());
   ODINLOG(odinlog,normalDebug) << "mem(map): " << Profiler::get_memory_usage() << STD_endl;
@@ -732,7 +735,7 @@ Data<T,N_rank>::operator tjarray<tjvector<T>,T> () const {
 
 template<typename T,int N_rank>
 template<typename T2, int N_rank2>
-Data<T2,N_rank2>& Data<T,N_rank>::convert_to(Data<T2,N_rank2>& dst, autoscaleOption scaleopt) const {
+Data<T2,N_rank2>& Data<T,N_rank>::convert_to(Data<T2,N_rank2>& dst, bool autoscale) const {
   Log<OdinData> odinlog("Data","convert_to");
 
   TinyVector<int,N_rank2> newshape; newshape=1;
@@ -752,7 +755,7 @@ Data<T2,N_rank2>& Data<T,N_rank>::convert_to(Data<T2,N_rank2>& dst, autoscaleOpt
 
   Data<T,N_rank> src_copy(*this); // make read/write copy of this
 
-  Converter::convert_array(src_copy.c_array(), dst.c_array(), src_copy.numElements(), dst.numElements(), scaleopt);
+  Converter::convert_array(src_copy.c_array(), dst.c_array(), src_copy.numElements(), dst.numElements(), autoscale);
 
   return dst;
 }
@@ -760,15 +763,15 @@ Data<T2,N_rank2>& Data<T,N_rank>::convert_to(Data<T2,N_rank2>& dst, autoscaleOpt
 
 // specialization which uses reference if type/rank are same and no scaling is necessary to reduce memory usage
 template<typename T,int N_rank>
-Data<T,N_rank>& Data<T,N_rank>::convert_to(Data<T,N_rank>& dst, autoscaleOption scaleopt) const {
+Data<T,N_rank>& Data<T,N_rank>::convert_to(Data<T,N_rank>& dst, bool autoscale) const {
   Log<OdinData> odinlog("Data","convert_to");
-  if(scaleopt==noscale || !std::numeric_limits<T>::is_integer) {
+  if(!autoscale || !std::numeric_limits<T>::is_integer) {
     ODINLOG(odinlog,normalDebug) << "Using reference" << STD_endl;
     dst.reference(*this);
   } else {
     Data<T,N_rank> src_copy(*this); // make read/write copy of this
     dst.resize(src_copy.shape()); // dst will be unique now
-    Converter::convert_array(src_copy.c_array(), dst.c_array(), src_copy.numElements(), dst.numElements(), scaleopt);
+    Converter::convert_array(src_copy.c_array(), dst.c_array(), src_copy.numElements(), dst.numElements(), autoscale);
   }
   return dst;
 }
@@ -883,7 +886,7 @@ void Data<T,N_rank>::interpolate1dim(unsigned int dim, int newsize, float subpix
 
   TinyVector<int,N_rank> newshape(oldshape);
   newshape(dim)=newsize;
-  resize(newshape);
+  Data<T,N_rank>::resize(newshape); // scope reuired by GCC 4.7
 
   // This holds the the shape of the subspace which is orthogonal to direction 'dim'
   TinyVector<int,N_rank> ortho_shape(oldshape);
