@@ -17,7 +17,7 @@ LOGGROUNDWORK(FileIO)
 
 void FileFormat::register_format() {
   svector suffs=suffix();
-  for(unsigned int i=0; i<suffs.size(); i++) formats[suffs[i]]=this;
+  for(unsigned int i=0; i<suffs.size(); i++) formats[suffs[i]].push_back(this);
 }
 
 
@@ -43,10 +43,13 @@ int FileFormat::write(const Data<float,4>& data, const STD_string& filename, con
   return -1;
 }
 
+
 int FileFormat::write(const FileIO::ProtocolDataMap& pdmap, const STD_string& filename, const FileWriteOpts& opts) {
+  Log<FileIO> odinlog("FileFormat","write");
   int result=0;
 
   svector fnames=create_unique_filenames(filename, pdmap, opts.fnamepar);
+  ODINLOG(odinlog,normalDebug) << "fnames=" << fnames.printbody() << STD_endl;
 
   int ifile=0;
   for(FileIO::ProtocolDataMap::const_iterator pdit=pdmap.begin(); pdit!=pdmap.end(); ++pdit) {
@@ -67,13 +70,26 @@ STD_string FileFormat::analyze_suffix(const STD_string& filename) {
 }
 
 FileFormat* FileFormat::get_format(const STD_string& filename, const STD_string& override_suffix) {
+  Log<FileIO> odinlog("FileFormat","get_format");
+
   STD_string suffix;
   if(override_suffix==AUTODETECTSTR) {
     suffix=analyze_suffix(filename);
   } else {
     suffix=override_suffix;
   }
-  if(formats.find(suffix)!=formats.end()) return formats[suffix];
+  ODINLOG(odinlog,normalDebug) << "filename:override_suffix:suffix=" << filename << ":" << override_suffix << ":" << suffix << STD_endl;
+
+  if(formats.find(suffix)!=formats.end()) {
+    const FormatList& formatlist=formats[suffix];
+    ODINLOG(odinlog,normalDebug) << "#formats(" << suffix << ")=" << formatlist.size() << STD_endl;
+    if(formatlist.size()>1) {
+       ODINLOG(odinlog,errorLog) << "Ambiguous file extension >" << analyze_suffix(filename) << "<" << STD_endl;
+       ODINLOG(odinlog,errorLog) << "Use -wf/-rf option with unique identifier (e.g. -wf analyze)" << STD_endl;
+       return 0;
+    }
+    return *(formatlist.begin());
+  }
   return 0;
 }
 
@@ -81,7 +97,7 @@ FileFormat* FileFormat::get_format(const STD_string& filename, const STD_string&
 svector FileFormat::possible_formats() {
   svector result; result.resize(formats.size());
   int index=0;
-  for(STD_map<STD_string,FileFormat*>::const_iterator it=formats.begin(); it!=formats.end(); ++it) {
+  for(FormatMap::const_iterator it=formats.begin(); it!=formats.end(); ++it) {
     result[index]=it->first;
     index++;
   }
@@ -90,11 +106,14 @@ svector FileFormat::possible_formats() {
 
 STD_string FileFormat::formats_str(const STD_string& indent) {
   STD_string result;
-  for(STD_map<STD_string,FileFormat*>::const_iterator it=formats.begin(); it!=formats.end(); ++it) {
-    result+=indent+(it->first)+" \t ("+it->second->description();
-    svector dialects=it->second->dialects();
-    if(dialects.size()) result+=", dialects: "+dialects.printbody();
-    result+=")\n";
+  for(FormatMap::const_iterator it=formats.begin(); it!=formats.end(); ++it) {
+    const FormatList& formatlist=it->second;
+    for(FormatList::const_iterator it2=formatlist.begin(); it2!=formatlist.end(); ++it2) {
+      result+=indent+(it->first)+" \t ("+(*it2)->description();
+      svector dialects=(*it2)->dialects();
+      if(dialects.size()) result+=", dialects: "+dialects.printbody();
+      result+=")\n";
+    }
   }
   return result;
 }
@@ -113,6 +132,8 @@ svector FileFormat::create_unique_filenames(const STD_string& filename, const Fi
   unsigned int nnames=pdmap.size();
   svector result; result.resize(nnames);
 
+  ODINLOG(odinlog,normalDebug) << "nnames=" << nnames << STD_endl;
+
   if(nnames==1) {
     result[0]=filename;
     return result;
@@ -138,31 +159,41 @@ svector FileFormat::create_unique_filenames(const STD_string& filename, const Fi
   unsigned int iname=0;
   for(FileIO::ProtocolDataMap::const_iterator pdit=pdmap.begin(); pdit!=pdmap.end(); ++pdit) {
     pdit->first.study.get_Series(serDesc,serNum);
-    for(unsigned int i=0;i<serDesc.length();i++) { //replace odd characters in the description by "_" (gives better filenames)
-      const char cr=serDesc[i];
-      if(cr==' ' || cr==':' || cr==';' || cr=='/' || cr=='&') serDesc[i]='_';
-    }
     STD_string str("S"+itos(serNum,maxseries));
     if(serDesc!="") str+=STD_string("_")+serDesc;
     
     if(npars) {
       for(int ipar=0; ipar<npars; ipar++) {
-        str+=STD_string("_")+rmblock(pdit->first.printval(pars[ipar]), "\n", ""); // truncate after first newline
+        str+=STD_string("_")+rmblock(pdit->first.printval(pars[ipar], true), "\n", ""); // truncate after first newline
       }
     }
-    
-    if(namescount.find(str)==namescount.end()) namescount[str]=0;
+
+    //replace characters not suitable for file names
+    for(unsigned int i=0;i<str.length();i++) {
+      const char cr=str[i];
+      if(cr==' ' || cr==':' || cr==';' || cr=='/' || cr=='&' || cr=='*') str[i]='_';
+    }
+
+    if(namescount.find(str)==namescount.end()) namescount[str]=1;
     else namescount[str]++;
+
     unique_names[iname]=str;
     iname++;
   }
+  ODINLOG(odinlog,normalDebug) << "unique_names=" << unique_names.printbody() << STD_endl;
+
+
+  for(STD_map<STD_string,unsigned int>::const_iterator it=namescount.begin(); it!=namescount.end(); ++it) {
+    ODINLOG(odinlog,normalDebug) << "namescount(" << it->first << ")=" << it->second << STD_endl;
+  }
+ 
 
   // Make sure filenames are unique by appending enumeration, if neccessary
   STD_map<STD_string,unsigned int> uniqueindex; // separate count for each non-unique filename
   for(unsigned int i=0; i<nnames; i++) {
     STD_string str=unique_names[i];
     int ncount=namescount[str];
-    if(ncount>0) {
+    if(ncount>1) {
       if(uniqueindex.find(str)==uniqueindex.end()) uniqueindex[str]=0;
       else uniqueindex[str]++;
       unique_names[i]+="_"+itos(uniqueindex[str],ncount);
@@ -227,7 +258,7 @@ float FileFormat::voxel_extent(const Geometry& geometry, direction direction, in
 }
 
 
-STD_map<STD_string,FileFormat*> FileFormat::formats;
+FileFormat::FormatMap FileFormat::formats;
 
 //////////////////////////////////////////////////////////////////////////
 
@@ -235,6 +266,7 @@ void register_asc_format();
 void register_dicom_format();
 void register_gzip_format();
 void register_hfss_format();
+void register_interfile_format();
 void register_jdx_format();
 void register_mhd_format();
 void register_mat_format();
@@ -253,6 +285,7 @@ struct FileFormatCreator : public StaticHandler<FileFormatCreator> {
     register_asc_format();
     register_dicom_format();
     register_gzip_format();
+    register_interfile_format();
     register_jdx_format();
     register_mhd_format();
     register_mat_format();
@@ -453,7 +486,7 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
   opts_copy.dset="";
 
   if(progmeter) progmeter->new_task( nfiles,"FileIO::read_dir");
-  
+
   for(unsigned int i=0; i<nfiles; i++) {
 
     ProtocolDataMap onepdmap;
@@ -602,13 +635,30 @@ int FileIO::read_dir(ProtocolDataMap& pdmap, const STD_string& dirname, const Fi
       }
     }
 
+
     // set new acquisition start and duration
     prot.seqpars.set_AcquisitionStart(min_acqstart);
     ODINLOG(odinlog,normalDebug) << "min_acqstart: " << min_acqstart << " max_acqstart: " << max_acqstart << " dur: "<< max_acqstart - min_acqstart+ prot.seqpars.get_RepetitionTime()/1000 << STD_endl;
     prot.seqpars.set_ExpDuration( (max_acqstart - min_acqstart+ prot.seqpars.get_RepetitionTime()/1000 ) /60.0);
 
+    int nslices=shape(sliceDim);
+
     // overwrite slice settings in protocol
-    prot.geometry.set_nSlices(shape(sliceDim));
+    prot.geometry.set_nSlices(nslices);
+
+    // store slice order in protocol for following steps
+    ODINLOG(odinlog,normalDebug) << "nslices/sliceindexmap.size()=" << nslices << "/" << sliceindexmap.size() << STD_endl;
+    if( nslices>1 && nslices<=sliceindexmap.size()) {
+      JDXintArr sliceorder;
+      sliceorder.redim(nslices); sliceorder.set_label("SliceOrder"); // separately instead of using constructor for GCC3.2
+      STD_map<double,int>::const_iterator it=sliceindexmap.begin();
+      for(int i=0; i<nslices; i++) {
+        sliceorder[i]=it->second;
+        ++it;
+      }
+      ODINLOG(odinlog,normalDebug) << "sliceorder=" << sliceorder.printbody() << STD_endl;
+      prot.methpars.append_copy(sliceorder);
+    }
 
     fvector slicevec=list2vector(slice_offsets);
     ODINLOG(odinlog,normalDebug) << "slicevec=" << slicevec.printbody() << STD_endl;
@@ -644,6 +694,8 @@ int FileIO::autowrite(const ProtocolDataMap& pdmap, const STD_string& filename,
 
   FileFormatCreator ffc;
 
+  ODINLOG(odinlog,normalDebug) << "filename:opts.format:opts.datatype=" << filename << ":" << opts.format << ":" << opts.datatype << STD_endl;
+
   FileFormat* ff=FileFormat::get_format(filename,opts.format);
   if(!ff) {
     FileFormat::format_error(filename);
@@ -716,7 +768,7 @@ STD_string FileIO::autoformats_str(const STD_string& indent) {
 
 bool FileIO::do_trace=true;
 
-STD_string FileFormat::selectDataType(const Protocol &prot,const FileWriteOpts& opts){
+STD_string FileFormat::select_write_datatype(const Protocol &prot,const FileWriteOpts& opts){
   if(opts.datatype != AUTOTDATAYPESTR)
     return opts.datatype;
   else
@@ -825,15 +877,29 @@ void create_fileio_testarr(Data<float,4>& testarr, const TinyVector<int,4>& shap
   }
 }
 
-template <int XSize, int YSize, typename CompareType, bool OnlyBitmap, bool ReadDir, bool HasOrientation, bool HasSliceThick>
+STD_string label4unittest(const STD_string& suff, const STD_string& uniquesuff, const STD_string& datatype) {
+  STD_string result("FileIO "+suff);
+  if(uniquesuff!="" || datatype!="") {
+    result+="( ";
+    if(uniquesuff!="") result+=uniquesuff+" ";
+    if(datatype!="") result+=datatype+" ";
+    result+=")";
+  }
+  return result;
+}
+
+template <int XSize, int YSize, typename CompareType, bool OnlyBitmap, bool HasRepetitions, bool ReadDir, bool HasOrientation, bool HasSliceThick>
 class FileIOFormatTest : public UnitTest {
 
  public:
-  FileIOFormatTest(const STD_string& suff) : UnitTest(("FileIO "+suff).c_str()), suffix(suff) {}
+  FileIOFormatTest(const STD_string& suff, const STD_string& uniquesuff="", const STD_string& datatype="")
+    : UnitTest(label4unittest(suff,uniquesuff,datatype).c_str()), suffix(suff), uniquesuffix(uniquesuff), dtype(datatype) {}
 
  private:
 
   STD_string suffix;
+  STD_string uniquesuffix;
+  STD_string dtype;
 
   bool compare_arrays(const STD_string& test, const Data<float,4>& a1, const Data<CompareType,4>& a2) const {
     Log<UnitTest> odinlog(this,"compare_arrays");
@@ -867,14 +933,17 @@ class FileIOFormatTest : public UnitTest {
     STD_list<TinyVector<int,4> > shapelst;
     shapelst.push_back(TinyVector<int,4>(1,1,YSize,XSize));
     if(!OnlyBitmap) {
-      shapelst.push_back(TinyVector<int,4>(3,4,YSize,XSize));
       shapelst.push_back(TinyVector<int,4>(1,4,YSize,XSize));
-      shapelst.push_back(TinyVector<int,4>(3,1,YSize,XSize));
+      if(HasRepetitions) {
+        shapelst.push_back(TinyVector<int,4>(3,4,YSize,XSize));
+        shapelst.push_back(TinyVector<int,4>(3,1,YSize,XSize));
+      }
     }
 
     for(STD_list<TinyVector<int,4> >::const_iterator it=shapelst.begin(); it!=shapelst.end(); ++it) {
 
       FileReadOpts readopts;
+      FileWriteOpts writeopts;
 
       STD_string prefix(tempfile()); // separate name for each shape
       STD_string writefname=prefix+"."+suffix;
@@ -884,15 +953,32 @@ class FileIOFormatTest : public UnitTest {
         readopts.format=suffix;
       }
 
+      if(uniquesuffix!="") {
+        readopts.format=uniquesuffix;
+        writeopts.format=uniquesuffix;
+      }
+
+      if(dtype!="") {
+        writeopts.datatype=dtype;
+      }
+
       Data<float,4> testarr;
       create_fileio_testarr(testarr,*it);
 
 
       Data<CompareType,4> readdata;
 
+      ODINLOG(odinlog,normalDebug) << "writefname:writeopts.format:writeopts.datatype=" << writefname << ":" << writeopts.format << ":" << writeopts.datatype << STD_endl;
+
       // simple write/read
-      if(testarr.autowrite(writefname)<0) return false;
-      if(readdata.autoread(readfname, readopts)<0) return false;
+      if(testarr.autowrite(writefname, writeopts)<0) {
+        ODINLOG(odinlog,errorLog) << "simple autowrite failed" << STD_endl;
+        return false;
+      }
+      if(readdata.autoread(readfname, readopts)<0) {
+        ODINLOG(odinlog,errorLog) << "simple autoread failed" << STD_endl;
+        return false;
+      }
       if(!compare_arrays("autowrite/autoread("+readfname+")", testarr, readdata)) return false;
 
       // Testing whether geometry info is preserved
@@ -914,9 +1000,15 @@ class FileIOFormatTest : public UnitTest {
         } else {
           geo.set_sliceThickness(6.1); // the same as slice distance
         }
-        if(testarr.autowrite(writefname, FileWriteOpts(), &prot)<0) return false;
+        if(testarr.autowrite(writefname, writeopts, &prot)<0) {
+          ODINLOG(odinlog,errorLog) << "autowrite with protocol failed" << STD_endl;
+          return false;
+        }
         Protocol readprot;
-        if(readdata.autoread(readfname, readopts, &readprot)<0) return false;
+        if(readdata.autoread(readfname, readopts, &readprot)<0) {
+          ODINLOG(odinlog,errorLog) << "autoread with protocol failed" << STD_endl;
+          return false;
+        }
         if(!compare_arrays("autowrite/autoread+geo("+readfname+")", testarr, readdata)) return false;
         Protocol protcopy(prot); // Create copy of protocol to use limited accuracy comparison of Protocol
         protcopy.geometry=readprot.geometry; // only geometry may differ
@@ -940,31 +1032,33 @@ void alloc_FileIOTest() { // create test instances
 
   new FileIOTest;
 
-  new FileIOFormatTest<7, 13, double, false,false,true,true>("jdx");
+  new FileIOFormatTest<7, 13, double, false,true,false,true,true>("jdx");
 
 #ifdef PNGSUPPORT
-  new FileIOFormatTest<7, 13, u8bit, true,false,false,false>("png");
+  new FileIOFormatTest<7, 13, u8bit, true,false,false,false,false>("png");
 #endif
 
 #ifdef HAVE_LIBZ
 #ifndef STREAM_REPLACEMENT
-  new FileIOFormatTest<7, 13, double, false,false,true,true>("jdx.gz");
+  new FileIOFormatTest<7, 13, double, false,true,false,true,true>("jdx.gz");
 #endif
 #endif
 
 #ifdef DICOMSUPPORT
-  new FileIOFormatTest<16, 16, u16bit, false,true,true,true>("dcm"); // needs square matrix size
+  new FileIOFormatTest<16, 16, u16bit, false,true,true,true,true>("dcm"); // needs square matrix size
 #endif
 #ifdef NIFTISUPPORT
-  new FileIOFormatTest<7, 13, double, false,false,true,false>("nii");
-  new FileIOFormatTest<7, 13, double, false,false,false,false>("hdr");
+  new FileIOFormatTest<7, 13, double, false,true,false,true,false>("nii","","float");
+  new FileIOFormatTest<7, 13, double, false,true,false,false,false>("hdr", "analyze");
 #ifdef HAVE_LIBZ
 #ifndef STREAM_REPLACEMENT
-  new FileIOFormatTest<7, 13, double, false,false,true,false>("nii.gz");
+  new FileIOFormatTest<7, 13, double, false,true,false,true,false>("nii.gz");
 #endif
 #endif
 #endif
 
+  new FileIOFormatTest<7, 13, s16bit, false,false,false,false,false>("hdr", "interfile","s16bit");
+  new FileIOFormatTest<7, 13, s16bit, false,false,false,false,false>("hdr", "interfile","float");
 
 }
 #endif
