@@ -51,6 +51,12 @@
 #define DCM_PAT_WEIGHT DCM_PatientWeight
 #endif
 
+#ifdef DCM_PatientsAge
+#define DCM_PAT_AGE DCM_PatientsAge
+#else
+#define DCM_PAT_AGE DCM_PatientAge
+#endif
+
 #ifdef DCM_PerformingPhysiciansName
 #define DCM_PERF_PHYS DCM_PerformingPhysiciansName
 #else
@@ -195,6 +201,19 @@ svector fetch_from_MR_CSA_Header(DcmElement* csaHeader, STD_string label){
 
 //////////////////////////////////////////////////////////////
 
+void timestr2seconds(const OFString& timestr, LONGEST_INT& sec, double& fract) {
+  sec=0;
+  fract=0;
+  if(timestr.length()<13) return;
+  //@todo backward compatibility missing (http://idlastro.gsfc.nasa.gov/idl_html_help/Value_Representations.html#TM)
+  LONGEST_INT hh=atoi(timestr.substr(0,2).c_str());
+  LONGEST_INT mm=atoi(timestr.substr(2,2).c_str());
+  LONGEST_INT ss=atoi(timestr.substr(4,2).c_str());
+  sec=ss + 60*mm + 3600*hh;
+  fract=atof(timestr.substr(6,7).c_str());
+}
+
+//////////////////////////////////////////////////////////////
 
 struct DicomFormat : public FileFormat {
   STD_string description() const {return "DICOM";}
@@ -405,6 +424,7 @@ struct DicomFormat : public FileFormat {
     if(intercept!=0.0 || slope!=1.0) {
       ODINLOG(odinlog,normalDebug) << "rescaling data with intercept/slope=" << intercept << "/" << slope << STD_endl;
       data=data*slope+intercept;
+      prot.system.set_data_type(TypeTraits::type2label((float)0)); // use float to preserve correct values
     }
 
 
@@ -417,8 +437,9 @@ struct DicomFormat : public FileFormat {
     if(!check_status(func,"SeriesDate",dset->findAndGetOFString(DCM_SeriesDate, valstr),warning)) {
       scandate=valstr.c_str();
     }
-    if(!check_status(func,"SeriesTime",dset->findAndGetOFString(DCM_SeriesTime, valstr),warning)) {
-      svector toks=tokens(valstr.c_str(), '.');
+    OFString seriestimestr;
+    if(!check_status(func,"SeriesTime",dset->findAndGetOFString(DCM_SeriesTime, seriestimestr),warning)) {
+      svector toks=tokens(seriestimestr.c_str(), '.');
       if(toks.size()) scantime=toks[0];
     }
     prot.study.set_DateTime(scandate,scantime);
@@ -638,17 +659,27 @@ struct DicomFormat : public FileFormat {
     if(dset->findAndGetOFString(DCM_FrameReferenceTime, valstr).good()){ // for dynamic PET data
       prot.seqpars.set_AcquisitionStart(atof(valstr.c_str()));
     } else {
-      if(dset->findAndGetOFString(DCM_InstanceNumber, valstr).good()) {
-        prot.seqpars.set_AcquisitionStart(atof(valstr.c_str()));
+      if(dset->findAndGetOFString(DCM_AcquisitionTime, valstr).good()){// Try timestamp field first
+        LONGEST_INT sec, sec_series;
+        double fract, fract_series;
+        timestr2seconds(valstr, sec, fract);
+        timestr2seconds(seriestimestr, sec_series, fract_series);
+        ODINLOG(odinlog,normalDebug) << "sec / fract = " << sec << " / " << fract << STD_endl;
+        ODINLOG(odinlog,normalDebug) << "sec_series / fract_series = " << sec_series << " / " << fract_series << STD_endl;
+        prot.seqpars.set_AcquisitionStart( 1000.0*(sec-sec_series) + 1000.0*(fract-fract_series) );  // subtracting series time to avoid overflow of double precision
+        ODINLOG(odinlog,normalDebug) << "AcquisitionStart=" << ftos(prot.seqpars.get_AcquisitionStart(),10) << STD_endl;
+
       } else {
-        if(dset->findAndGetOFString(DCM_AcquisitionTime, valstr).good()){// Try timestamp field first
-          //@todo backward compatibility missing (http://idlastro.gsfc.nasa.gov/idl_html_help/Value_Representations.html#TM)
-          int hh=atoi(valstr.substr(0,2).c_str());
-          int mm=atoi(valstr.substr(2,2).c_str());
-          double ss=atof(valstr.substr(4,7).c_str());
-          ODINLOG(odinlog,normalDebug) << "hh/mm/ss=" << hh << "/" << mm << "/" << ss << STD_endl;
-          prot.seqpars.set_AcquisitionStart( 1000.0*(ss + 60*mm + 3600*hh) );
-	}
+        if(dset->findAndGetOFString(DCM_InstanceNumber, valstr).good()) { // fallback
+          prot.seqpars.set_AcquisitionStart(atof(valstr.c_str()));
+        }
+      }
+    }
+
+    if(modality=="PT") {
+      if(!check_status(func,"ActualFrameDuration",dset->findAndGetOFString(DCM_ActualFrameDuration, valstr),optional)) {
+        prot.seqpars.set_RepetitionTime(atof(valstr.c_str()));
+        ODINLOG(odinlog,normalDebug) << "Start / TR(PET) = " << prot.seqpars.get_AcquisitionStart() << " / " << prot.seqpars.get_RepetitionTime() << STD_endl;
       }
     }
 
@@ -718,9 +749,6 @@ struct DicomFormat : public FileFormat {
       // Pixel data stuff
       if(check_status(func,"SamplesPerPixel",          dataset->putAndInsertUint16(DCM_SamplesPerPixel, 1))) return -1;
       if(check_status(func,"PhotometricInterpretation",dataset->putAndInsertString(DCM_PhotometricInterpretation, "MONOCHROME2"))) return -1;
-      if(check_status(func,"BitsAllocated",            dataset->putAndInsertString(DCM_BitsAllocated,       "16"))) return -1;
-      if(check_status(func,"BitsStored",               dataset->putAndInsertString(DCM_BitsStored,          "16"))) return -1;
-      if(check_status(func,"HighBit",                  dataset->putAndInsertString(DCM_HighBit,             "15"))) return -1;
       if(check_status(func,"PixelRepresentation",      dataset->putAndInsertString(DCM_PixelRepresentation, "0")))  return -1;
 
       // Sequence type stuff
@@ -753,20 +781,26 @@ struct DicomFormat : public FileFormat {
       if(check_status(func,"PatientsSex",       dataset->putAndInsertString(DCM_PAT_SEX,       STD_string(1,psex).c_str()))) return -1;
       if(check_status(func,"PatientsWeight",    dataset->putAndInsertString(DCM_PAT_WEIGHT,    ftos(pweight).c_str()))) return -1;
 
+      // Calculate patient age in years
+      int ibirth=atoi(pdbirth.c_str());
+      int iscan=atoi(scandate.c_str());
+      int ageyears=int(1.0e-4*(iscan-ibirth)); // use months/days as digits after comma to round down age
+      ODINLOG(odinlog,normalDebug) << "ageyears=" << ageyears << STD_endl;
+      if(check_status(func,"PatientAge",    dataset->putAndInsertString(DCM_PAT_AGE,    (itos(ageyears)+"Y").c_str()))) return -1;
+
+
       // Study stuff
       STD_string studydescr;
       STD_string physician;
       prot.study.get_Context(studydescr, physician);
       studydescr=replaceStr(studydescr," ","^");
       physician=replaceStr(physician," ","^");
-      STD_string studyid(studydescr);
-      if(studyid=="") studyid="0";
 
       // Mangle date, PatientID and study description into unique Study UID
       STD_string studyinstanceuid;
       studyinstanceuid+=scandate;
       for(unsigned int i=0; i<pid.length(); i++) studyinstanceuid+="."+itos(pid[i]);
-      for(unsigned int i=0; i<studyid.length(); i++) studyinstanceuid+="."+itos(studyid[i]);
+      for(unsigned int i=0; i<studydescr.length(); i++) studyinstanceuid+="."+itos(studydescr[i]);
       if(studyinstanceuid.length()>64) studyinstanceuid=studyinstanceuid.substr(0,64);
 
       if(check_status(func,"StudyInstanceUID",         dataset->putAndInsertString(DCM_StudyInstanceUID, studyinstanceuid.c_str()))) return -1;
@@ -774,7 +808,7 @@ struct DicomFormat : public FileFormat {
       if(check_status(func,"StudyTime",                dataset->putAndInsertString(DCM_StudyTime,        scantime.c_str()))) return -1;
       if(check_status(func,"PerformingPhysiciansName", dataset->putAndInsertString(DCM_PERF_PHYS,        physician.c_str()))) return -1;
       if(check_status(func,"ReferringPhysiciansName",  dataset->putAndInsertString(DCM_REF_PHYS,         physician.c_str()))) return -1;
-      if(check_status(func,"StudyID",                  dataset->putAndInsertString(DCM_StudyID,          studyid.c_str()))) return -1;
+      if(check_status(func,"StudyID",                  dataset->putAndInsertString(DCM_StudyID,          "1"))) return -1; // notyet defined in ODIN
       if(check_status(func,"StudyDescription",         dataset->putAndInsertString(DCM_StudyDescription, studydescr.c_str()))) return -1;
       if(check_status(func,"AccessionNumber",          dataset->putAndInsertString(DCM_AccessionNumber,  ""))) return -1;
 
@@ -901,9 +935,7 @@ struct DicomFormat : public FileFormat {
       ODINLOG(odinlog,normalDebug) << "cornerpoints" << STD_string(cornerpoints.get_extent()) << "=" << cornerpoints.printbody() << STD_endl;
 
       Data<u16bit,4> u16bitdata;
-      const STD_string type(prot.system.get_data_type());
-      if(type!="float" && type!="double")data.convert_to(u16bitdata,noupscale);
-      else data.convert_to(u16bitdata);
+      data.convert_to(u16bitdata,!opts.noscale);
 
       if(opts.dialect=="siemens") {
         // clip data for viewer on host
@@ -913,9 +945,31 @@ struct DicomFormat : public FileFormat {
         u16bitdata=u16bitdata_copy;
       }
 
+      u16bit min_stored=min(u16bitdata);
+      u16bit max_stored=max(u16bitdata);
+
+      unsigned int bits_used=16;
+      if(opts.noscale) {
+        bits_used=STD_max((unsigned int)1, (unsigned int)ceil(log(max_stored)/log(2)));
+      }
+      ODINLOG(odinlog,normalDebug) << "bits_used=" << bits_used << STD_endl;
+      if(check_status(func,"BitsAllocated",            dataset->putAndInsertString(DCM_BitsAllocated,       "16"))) return -1;
+      if(check_status(func,"BitsStored",               dataset->putAndInsertString(DCM_BitsStored,          itos(bits_used).c_str()))) return -1;
+      if(check_status(func,"HighBit",                  dataset->putAndInsertString(DCM_HighBit,             itos(bits_used-1).c_str()))) return -1;
+
+
+      // preserving (floating point) values
+      if(!opts.noscale && opts.dialect!="siemens") {
+        double minval_out=min(data);
+        double maxval_out=max(data);
+        double slope=secureDivision(maxval_out-minval_out, max_stored-min_stored);
+        double intercept=maxval_out-slope*max_stored;
+        if(check_status(func,"RescaleType",dataset->putAndInsertString(DCM_RescaleType, "US"))) return -1;
+        if(check_status(func,"RescaleSlope",dataset->putAndInsertString(DCM_RescaleSlope, ftos(slope,6,alwaysExp).c_str()))) return -1;
+        if(check_status(func,"RescaleIntercept",dataset->putAndInsertString(DCM_RescaleIntercept, ftos(intercept,6,alwaysExp).c_str()))) return -1;
+      }
+
 
-      u16bit minval=min(u16bitdata);
-      u16bit maxval=max(u16bitdata);
       Data<u16bit,2> oneslice_padded(ysize,xsize);
 
       for(int iframe=0; iframe<data.extent(0); iframe++) {
@@ -950,8 +1004,8 @@ struct DicomFormat : public FileFormat {
           oneslice_padded=0;
           oneslice_padded(Range(yoffset,yoffset+data.extent(2)-1), Range(xoffset,xoffset+data.extent(3)-1))=u16bitdata(iframe,iplane,all,all);
 
-          if(!insert_uint16_hack(dataset, DCM_SmallestImagePixelValue, minval)) return -1;
-          if(!insert_uint16_hack(dataset, DCM_LargestImagePixelValue,  maxval)) return -1;
+          if(!insert_uint16_hack(dataset, DCM_SmallestImagePixelValue, min_stored)) return -1;
+          if(!insert_uint16_hack(dataset, DCM_LargestImagePixelValue,  max_stored)) return -1;
 
           if(check_status(func,"PixelData",dataset->putAndInsertUint16Array(DCM_PixelData, oneslice_padded.c_array(), oneslice_padded.numElements()))) return -1;
 
