@@ -187,7 +187,10 @@ struct ProtFormat : public FileFormat {
 
     if(prot.load(filename)<0) return false;
 
-    data.resize(1, prot.seqpars.get_MatrixSize(sliceDirection), prot.seqpars.get_MatrixSize(phaseDirection), prot.seqpars.get_MatrixSize(readDirection)); // only one repetition
+    int nslices=prot.geometry.get_nSlices();
+    if(prot.geometry.get_Mode()==voxel_3d) nslices=prot.seqpars.get_MatrixSize(sliceDirection);
+
+    data.resize(1, nslices, prot.seqpars.get_MatrixSize(phaseDirection), prot.seqpars.get_MatrixSize(readDirection)); // only one repetition
     data=0.0;
 
     return data.extent(0)*data.extent(1);
