@@ -55,6 +55,10 @@ FileWriteOpts::FileWriteOpts() {
   format.set_cmdline_option("wf").set_description("Write format, use it to override file extension");
   append_member(format,"format");
 
+  noscale=false;
+  noscale.set_cmdline_option("noscale").set_description("Do not rescale values when storing integers");
+  append_member(noscale,"noscale");
+
   append=false;
   append.set_cmdline_option("append").set_description("Append to existing file, only for raw data");
   append_member(append,"append");
