@@ -2,8 +2,8 @@
                           fileio_opts.h  -  description
                              -------------------
     begin                : Mon Nov 13 2006
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -54,6 +54,7 @@ struct FileWriteOpts : JcampDxBlock {
   FileWriteOpts();
 
   JDXenum   format;
+  JDXbool   noscale;
   JDXbool   append;
   JDXstring wprot;
   JDXbool   split;
