@@ -175,9 +175,7 @@ struct PNGFormat : public FileFormat {
     bool ok=true;
     int s=0,t=0;
     Data<u8bit,4> buff;
-    const STD_string type(prot.system.get_data_type());
-    if(type!="float" && type!="double")data.convert_to(buff,noupscale);
-    else data.convert_to(buff);
+    data.convert_to(buff,!opts.noscale);
 
     for(t=0;ok && t<time;t++)
       for (s=0; ok && s<slices; s++) {
