@@ -3,6 +3,7 @@
 #ifdef VTKSUPPORT
 
 #include <vtkStructuredPoints.h>
+#include <vtkStructuredPointsReader.h>
 #include <vtkStructuredPointsWriter.h>
 
 //////////////////////////////////////////////////////////////
@@ -18,10 +19,50 @@ struct VtkFormat : public FileFormat {
 
   int read(Data<float,4>& data, const STD_string& filename, const FileReadOpts& opts, Protocol& prot) {
     Log<FileIO> odinlog("VtkFormat","read");
-    ODINLOG(odinlog,errorLog) << "Implement me" << STD_endl;
-    return -1;
+
+    vtkStructuredPointsReader *in_read=vtkStructuredPointsReader::New();
+    vtkStructuredPoints *in=vtkStructuredPoints::New();
+    in_read->SetOutput(in);
+
+    in_read->SetFileName(filename.c_str());
+    if(!in_read->IsFileStructuredPoints()) {
+      ODINLOG(odinlog,errorLog) << "Not a valid vtkStructuredPoints file" << STD_endl;
+      return -1;
+    }
+    in_read->Update(); // read data
+
+    int dims[3];
+    in->GetDimensions(dims);
+    int nread=dims[0];
+    int nphase=dims[1];
+    int nslice=dims[2];
+    ODINLOG(odinlog,normalDebug) << "nslice/nphase/nread " << nslice << "/" << nphase << "/" << nread << STD_endl;
+
+    ODINLOG(odinlog,normalDebug) << "type=" << in->GetScalarTypeAsString() << STD_endl;
+
+    data.resize(1, nslice, nphase, nread);
+    for(int i=0;i<nread;i++) {
+      for(int j=0;j<nphase;j++) {
+        for(int k=0;k<nslice;k++) {
+          data(0,k,j,i)=in->GetScalarComponentAsFloat(i,j,k,0);
+        }
+      }
+    }
+
+    Geometry& geo=prot.geometry;
+    double spacing[3];
+    in->GetSpacing(spacing);
+    geo.set_FOV(readDirection, nread*spacing[0]);
+    geo.set_FOV(phaseDirection, nphase*spacing[1]);
+    geo.set_FOV(sliceDirection, nslice*spacing[2]);
+
+    in->Delete();
+    in_read->Delete();
+
+    return nslice;
   }
 
+
   int write(const Data<float,4>& data, const STD_string& filename, const FileWriteOpts& opts, const Protocol& prot) {
     Log<FileIO> odinlog("VtkFormat","write");
 
@@ -30,17 +71,16 @@ struct VtkFormat : public FileFormat {
     out_write->SetInput(out);
 
     // setting format
-    STD_string datatype=selectDataType(prot,opts);
-    if(datatype==TypeTraits::type2label((float)0))  out->SetScalarTypeToFloat ();
-    if(datatype==TypeTraits::type2label((double)0)) out->SetScalarTypeToDouble ();
-    if(datatype==TypeTraits::type2label((s32bit)0)) out->SetScalarTypeToInt ();
-    if(datatype==TypeTraits::type2label((u32bit)0)) out->SetScalarTypeToUnsignedInt ();
-    if(datatype==TypeTraits::type2label((s16bit)0)) out->SetScalarTypeToShort ();
-    if(datatype==TypeTraits::type2label((u16bit)0)) out->SetScalarTypeToUnsignedShort ();
-    if(datatype==TypeTraits::type2label((s8bit)0))  out->SetScalarTypeToChar ();
-    if(datatype==TypeTraits::type2label((u8bit)0))  out->SetScalarTypeToUnsignedChar ();
+    STD_string datatype=select_write_datatype(prot,opts);
+    if(datatype==TypeTraits::type2label((float)0))  out->SetScalarTypeToFloat();
+    if(datatype==TypeTraits::type2label((double)0)) out->SetScalarTypeToDouble();
+    if(datatype==TypeTraits::type2label((s32bit)0)) out->SetScalarTypeToInt();
+    if(datatype==TypeTraits::type2label((u32bit)0)) out->SetScalarTypeToUnsignedInt();
+    if(datatype==TypeTraits::type2label((s16bit)0)) out->SetScalarTypeToShort();
+    if(datatype==TypeTraits::type2label((u16bit)0)) out->SetScalarTypeToUnsignedShort();
+    if(datatype==TypeTraits::type2label((s8bit)0))  out->SetScalarTypeToChar();
+    if(datatype==TypeTraits::type2label((u8bit)0))  out->SetScalarTypeToUnsignedChar();
 
-//    Data<float,3> data3d;
 
     const Geometry& geo=prot.geometry;
 
