@@ -13,7 +13,7 @@
 #ifndef FILTER_H
 #define FILTER_H
 
-#include <odindata/filter_step.h>
+#include <odindata/fileio.h>
 
 /**
   * @addtogroup odindata
@@ -21,12 +21,9 @@
   */
 
 
-// helper class for debugging the filter component
-struct Filter {
-  static const char* get_compName();
-};
+struct FilterChainData; // forward declaration
 
-/////////////////////////////////////////////////////////////////////////////
+///////////////////////////////////////////////////////////////////////////////////
 
 /**
   * A chain of filter functors.
@@ -38,12 +35,17 @@ class FilterChain {
 /**
   * Create empty filter chain
   */
-  FilterChain() {}
+  FilterChain();
+
+/**
+  * Destructor
+  */
+  ~FilterChain();
 
 /**
   * Create filter chain from command line string.
   */
-  FilterChain(const STD_string& argstr) {init(argstr);}
+  FilterChain(const STD_string& argstr);
 
 /**
   * Create filter chain from command line.
@@ -65,10 +67,14 @@ class FilterChain {
   */
   bool apply(Protocol& prot, Data<float,4>& data) const;
 
+/**
+  * Returns documention for command line.
+  */
+  STD_string get_cmdline_usage(const STD_string& lineprefix) const;
+
 
  private:
-  FilterFactory factory;
-  STD_list<FilterStep*> filters;
+  FilterChainData* filterchaindata;
 
   bool create(const svector& args);
 
