@@ -38,15 +38,21 @@ TinyVector<int,4> datashape=data.shape();
 
 ///////////////////////////////////////////////////////////////////////////
 
+void FilterAutoMask::init() {
+
+//  dump_histogram_fname.set_description("dump histogram");
+//  append_arg(dump_histogram_fname,"dump_histogram_fname");
+}
 
 bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
   Log<Filter> odinlog(c_label(),"process");
 
   int nslots=100;
-  
-  float step=secureDivision(max(data),nslots);
 
-  ODINLOG(odinlog,normalDebug) << "nslots/step=" << nslots << "/" << step << STD_endl; 
+  float maxval=max(data);
+  float step=secureDivision(maxval,nslots);
+
+  ODINLOG(odinlog,normalDebug) << "maxval/nslots/step=" << maxval << "/" << nslots << "/" << step << STD_endl; 
 
   Data<float,1> hist(nslots); hist=0.0;
 
@@ -57,13 +63,16 @@ bool FilterAutoMask::process(Data<float,4>& data, Protocol& prot) const {
     ODINLOG(odinlog,normalDebug) << "val/slot=" << val << "/" << slot << STD_endl; 
     if(slot>=0 && slot<nslots) hist(slot)++;
   }
-//  hist.write_asc_file("hist.asc");
+
+//  ODINLOG(odinlog,infoLog) << "dump_histogram_fname=" << dump_histogram_fname << STD_endl; 
+//  if(dump_histogram_fname!="") hist.write_asc_file(dump_histogram_fname);
+
 
   // find first minimum
   float thresh=0.0;
   for(int islot=0; islot<(nslots-1); islot++) {
     if(hist(islot+1)>hist(islot)) {
-      thresh=islot*step;
+      thresh=(islot+1)*step; // use one step after min for threshold
       break;
     }
   }
