@@ -2,8 +2,8 @@
                           filter_mask.h  -  description
                              -------------------
     begin                : Wed Nov 5 2008
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,7 @@
 #ifndef FILTER_MASK_H
 #define FILTER_MASK_H
 
-#include <odindata/filter.h>
+#include <odindata/filter_step.h>
 
 class FilterGenMask : public FilterStep {
 
@@ -38,11 +38,13 @@ class FilterGenMask : public FilterStep {
 
 class FilterAutoMask : public FilterStep {
 
+//  JDXfileName dump_histogram_fname;
+
   STD_string label() const {return "automask";}
   STD_string description() const {return "Create mask using automatic histogram-based threshold";}
   bool process(Data<float,4>& data, Protocol& prot) const;
   FilterStep*  allocate() const {return new FilterAutoMask();}
-  void init() {}
+  void init();
 };
 
 
