@@ -2,8 +2,8 @@
                           filter_merge.h  -  description
                              -------------------
     begin                : Mon May 25 2009
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,7 @@
 #ifndef FILTER_MERGE_H
 #define FILTER_MERGE_H
 
-#include <odindata/filter.h>
+#include <odindata/filter_step.h>
 
 class FilterMerge: public FilterStep {
   STD_string label() const {return "merge";}
