@@ -12,7 +12,7 @@
 #ifndef FILTER_NAN_H
 #define FILTER_NAN_H
 
-#include <odindata/filter.h>
+#include <odindata/filter_step.h>
 
 /**
 	@author Enrico Reimer
