@@ -8,10 +8,26 @@ bool str2range(const STD_string& str, Range& range, int srcsize) {
   int colsize=tokscol.size();
   if(colsize<1 || colsize>2) return false;
   if(colsize==2) increment=atoi(tokscol[1].c_str());
-  svector toks=tokens(tokscol[0],'-');
+  STD_string fromto=tokscol[0];
   bool result=false;
-  if(toks.size()==2) {range=Range(atoi(toks[0].c_str()),atoi(toks[1].c_str()),increment); result=true;}
-  if(toks.size()==1) {range=Range(atoi(toks[0].c_str()),atoi(toks[0].c_str()),increment); result=true;}
+  if(fromto=="all") {
+    range=Range::all();
+    result=true;
+  } else {
+    svector toks=tokens(fromto,'-');
+    if(toks.size()==2) {range=Range(atoi(toks[0].c_str()),atoi(toks[1].c_str()),increment); result=true;}
+    if(toks.size()==1) {
+      int singleval=atoi(toks[0].c_str());
+      int low=singleval;
+      int upp=singleval;
+      if(fromto.length()) {
+        if(fromto[0]=='-') low=0;
+        if(fromto[fromto.length()-1]=='-') upp=srcsize-1;
+      }
+      range=Range(low,upp,increment);
+      result=true;
+    }
+  }
 
   if(!result) {
     ODINLOG(odinlog,errorLog) << "Error parsing range string >" << str << "<" << STD_endl;
