@@ -2,8 +2,8 @@
                           filter_reduction.h  -  description
                              -------------------
     begin                : Fri Feb 26 2010
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,11 +18,12 @@
 #ifndef FILTER_REDUCTION_H
 #define FILTER_REDUCTION_H
 
+
+#include <odindata/filter_step.h>
+
 enum                      reductionOp { minip=0, maxip,   proj };
 static const char* reductionOpLabel[]={"minip", "maxip", "proj"};
 
-#include <odindata/filter.h>
-
 template<int Op>
 class FilterReduction : public FilterStep
 {
@@ -34,6 +35,7 @@ class FilterReduction : public FilterStep
     STD_string opstr;
     if(Op==minip) opstr="minimum intensity ";
     if(Op==maxip) opstr="maximum intensity ";
+    if(Op==proj)  opstr="mean ";
     return "Perform "+opstr+"projection over given direction";
   }
 
@@ -69,7 +71,7 @@ class FilterReduction : public FilterStep
     
       if(Op==minip) outdata(index)=min(data(RectDomain<4>(lowerBounds, upperBounds)));
       if(Op==maxip) outdata(index)=max(data(RectDomain<4>(lowerBounds, upperBounds)));
-      if(Op==proj)  outdata(index)=sum(data(RectDomain<4>(lowerBounds, upperBounds)));
+      if(Op==proj)  outdata(index)=mean(data(RectDomain<4>(lowerBounds, upperBounds)));
     }
 
     data.reference(outdata);
