@@ -1,5 +1,4 @@
 #include "filter_resize.h"
-#include <blitz/tinyvec-et.h>
 
 
 
@@ -43,12 +42,15 @@ void FilterResample::init() {
 
 bool FilterResample::process(Data<float,4>& data, Protocol& prot) const {
 
+  double totaldur=data.extent(timeDim)*prot.seqpars.get_RepetitionTime();
+
   TinyVector<int,4> newshape(data.shape());
   newshape(0)=newsize;
   data.congrid(newshape);
 
   // update stuff in the protocol after regridding
   prot.seqpars.set_NumOfRepetitions(newsize);
+  prot.seqpars.set_RepetitionTime(secureDivision(totaldur,newsize));
 
   return true;
 }
@@ -60,7 +62,7 @@ bool FilterResample::process(Data<float,4>& data, Protocol& prot) const {
 
 void FilterIsotrop::init() {
   size=0;
-  size.set_description("voxelsize");
+  size.set_description("voxelsize").set_unit(ODIN_SPAT_UNIT);
   append_arg(size,"voxelsize");
 }
 
