@@ -1,5 +1,5 @@
 //
-// C++ Interface: filter_reorient
+// C++ Interface: filter_reslice
 //
 // Description:
 //
@@ -12,7 +12,7 @@
 #ifndef FILTER_RESLICE_H
 #define FILTER_RESLICE_H
 
-#include <odindata/filter.h>
+#include <odindata/filter_step.h>
 
 class FilterReSlice : public FilterStep
 {
