@@ -2,8 +2,8 @@
                           filter_rot.h  -  description
                              -------------------
     begin                : Sun Jan 20 2008
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,7 @@
 #ifndef FILTER_ROT_H
 #define FILTER_ROT_H
 
-#include <odindata/filter.h>
+#include <odindata/filter_step.h>
 
 class FilterRot : public FilterStep {
 
