@@ -2,8 +2,8 @@
                           filter_shift.h  -  description
                              -------------------
     begin                : Fri Nov 21 2008
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,7 @@
 #ifndef FILTER_SHIFT_H
 #define FILTER_SHIFT_H
 
-#include <odindata/filter.h>
+#include <odindata/filter_step.h>
 
 class FilterShift : public FilterStep {
 
@@ -31,4 +31,19 @@ class FilterShift : public FilterStep {
   void init();
 };
 
+
+////////////////////////////////////////////////////
+
+
+class FilterTimeShift : public FilterStep {
+
+  JDXfloat shiftframes;
+
+  STD_string label() const {return "tshift";}
+  STD_string description() const {return "Shift data in time";}
+  bool process(Data<float,4>& data, Protocol& prot) const;
+  FilterStep*  allocate() const {return new FilterTimeShift();}
+  void init();
+};
+
 #endif
