@@ -1,9 +1,9 @@
 /***************************************************************************
-                          filter_reduction.h  -  description
+                          filter_splice.h  -  description
                              -------------------
     begin                : Fri Feb 17 2012
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,7 @@
 #ifndef FILTER_SPLICE_H
 #define FILTER_SPLICE_H
 
-#include "filter_step.h"
+#include <odindata/filter_step.h>
 
 class FilterSplice: public FilterStep {
   JDXenum dir;
