@@ -3,7 +3,10 @@
 
 #include "filter_align.h"
 #include "filter_clip.h"
+#include "filter_cluster.h"
+#include "filter_convolve.h"
 #include "filter_detrend.h"
+#include "filter_edit.h"
 #include "filter_lowpass.h"
 #include "filter_mask.h"
 #include "filter_merge.h"
@@ -16,6 +19,7 @@
 #include "filter_reslice.h"
 #include "filter_scale.h"
 #include "filter_shift.h"
+#include "filter_slicetime.h"
 #include "filter_tile.h"
 #include "filter_splice.h"
 
@@ -41,7 +45,11 @@ void FilterStep::create_templates(STD_list<FilterStep*>& result) {
   result.push_back(new FilterTypeMin());
 
   result.push_back(new FilterDeTrend());
+  result.push_back(new FilterSliceTime());
   result.push_back(new FilterLowPass());
+  result.push_back(new FilterConvolve());
+
+  result.push_back(new FilterCluster());
 
   result.push_back(new FilterGenMask());
   result.push_back(new FilterAutoMask());
@@ -62,6 +70,7 @@ void FilterStep::create_templates(STD_list<FilterStep*>& result) {
 
   result.push_back(new FilterScale());
   result.push_back(new FilterShift());
+  result.push_back(new FilterTimeShift());
   result.push_back(new FilterReSlice());
   result.push_back(new FilterSwapdim());
 
@@ -71,6 +80,8 @@ void FilterStep::create_templates(STD_list<FilterStep*>& result) {
 
   result.push_back(new FilterTile());
 
+  result.push_back(new FilterEdit());
+
   result.push_back(new FilterMerge());
   result.push_back(new FilterSplice());
 
