@@ -1,5 +1,6 @@
 
 #include "fitting.h"
+#include "statistics.h" // for Monte-Carlo error estimation
 
 #include <tjutils/tjtest.h>
 
@@ -31,15 +32,6 @@ struct GslData4Fit {
 
 ////////////////////////////////////////////////////////////////
 
-bool ModelFunction::fit(const Array<float,1>& yvals,
-         const Array<float,1>& ysigma,
-         const Array<float,1>& xvals,
-         unsigned int max_iterations, double tolerance) {
-  FunctionFit ff(*this,yvals.extent(firstDim),max_iterations,tolerance);
-  return ff.fit(yvals,ysigma,xvals);
-}
-
-
 Array<float,1> ModelFunction::get_function(const Array<float,1>& xvals) const {
   int n=xvals.extent(firstDim);
   Array<float,1> result(n);
@@ -51,12 +43,15 @@ Array<float,1> ModelFunction::get_function(const Array<float,1>& xvals) const {
 
 const Array<float,1> ModelFunction::defaultArray;
 
+////////////////////////////////////////////////////////////////
+
+const Array<float,1> FunctionFitInterface::defaultArray;
 
 ////////////////////////////////////////////////////////////////
 
 // functions to be used by GSL solver
 
-int FunctionFit_func_f (const gsl_vector * gv, void *params, gsl_vector * f) {
+int FunctionFitDerivative_func_f (const gsl_vector * gv, void *params, gsl_vector * f) {
 
   // get current model function
   ModelData* data=(ModelData*)params;
@@ -77,7 +72,7 @@ int FunctionFit_func_f (const gsl_vector * gv, void *params, gsl_vector * f) {
   return GSL_SUCCESS;
 }
 
-int FunctionFit_func_df (const gsl_vector * gv, void *params, gsl_matrix * df) {
+int FunctionFitDerivative_func_df (const gsl_vector * gv, void *params, gsl_matrix * df) {
 
   // get current model function
   ModelData* data=(ModelData*)params;
@@ -102,17 +97,16 @@ int FunctionFit_func_df (const gsl_vector * gv, void *params, gsl_matrix * df) {
   return GSL_SUCCESS;
 }
 
-int FunctionFit_func_fdf (const gsl_vector * gv, void *params, gsl_vector * f, gsl_matrix * df) {
-  FunctionFit_func_f (gv, params, f);
-  FunctionFit_func_df (gv, params, df);
+int FunctionFitDerivative_func_fdf (const gsl_vector * gv, void *params, gsl_vector * f, gsl_matrix * df) {
+  FunctionFitDerivative_func_f (gv, params, f);
+  FunctionFitDerivative_func_df (gv, params, df);
   return GSL_SUCCESS;
 }
 
 ////////////////////////////////////////////////////////////////
 
 
-FunctionFit::FunctionFit(ModelFunction& model_func, unsigned int nvals, unsigned int max_iterations, double tolerance)
- : func(model_func), max_it(max_iterations), tol(tolerance) {
+bool FunctionFitDerivative::init(ModelFunction& model_func, unsigned int nvals) {
 
   data4fit= new ModelData(nvals);
 
@@ -121,24 +115,34 @@ FunctionFit::FunctionFit(ModelFunction& model_func, unsigned int nvals, unsigned
   gsldata=new GslData4Fit;
 
   // allocate and initialize GSL stuff
-  gsldata->covar  = gsl_matrix_alloc (func.numof_fitpars(), func.numof_fitpars());
-  gsldata->solver = gsl_multifit_fdfsolver_alloc (gsl_multifit_fdfsolver_lmsder, data4fit->n, func.numof_fitpars());
+  unsigned int npars=model_func.numof_fitpars();
+  gsldata->covar  = gsl_matrix_alloc (npars, npars);
+  gsldata->solver = gsl_multifit_fdfsolver_alloc (gsl_multifit_fdfsolver_lmsder, data4fit->n, npars);
+  
+  return true;
 }
 
-FunctionFit::~FunctionFit() {
-  // free GSL stuff
-  gsl_multifit_fdfsolver_free(gsldata->solver);
-  gsl_matrix_free(gsldata->covar);
-  delete data4fit;
-  delete gsldata;
+FunctionFitDerivative::~FunctionFitDerivative() {
+  if(gsldata) {
+    gsl_multifit_fdfsolver_free(gsldata->solver);
+    gsl_matrix_free(gsldata->covar);
+    delete gsldata;
+  }
+  if(data4fit) delete data4fit;
 }
 
 
-bool FunctionFit::fit(const Array<float,1>& yvals,
+bool FunctionFitDerivative::fit(const Array<float,1>& yvals,
          const Array<float,1>& ysigma,
-         const Array<float,1>& xvals) {
-  Log<OdinData> odinlog("FunctionFit","fit");
+         const Array<float,1>& xvals,
+         unsigned int max_iterations, double tolerance) {
+  Log<OdinData> odinlog("FunctionFitDerivative","fit");
 
+  if(!gsldata || !data4fit) {
+    ODINLOG(odinlog,errorLog) << "not initialized" << STD_endl;
+    return false;
+  }
+  
   bool haveSigma;
   bool haveXvals;
 
@@ -158,7 +162,9 @@ bool FunctionFit::fit(const Array<float,1>& yvals,
     ODINLOG(odinlog,normalDebug) << "no x values provided, taking index as x value" << STD_endl;
   }
 
-  ODINLOG(odinlog,normalDebug) << "n/numof_fitpars=" << data4fit->n << "/" <<  func.numof_fitpars() << STD_endl;
+  ModelFunction* func=data4fit->modelfunc;
+  unsigned int npars=func->numof_fitpars();
+  ODINLOG(odinlog,normalDebug) << "n/numof_fitpars=" << data4fit->n << "/" <<  npars << STD_endl;
 
   // copy Blitz arrays to data4fit
   for (unsigned long i=0;i<data4fit->n;i++) {
@@ -173,20 +179,20 @@ bool FunctionFit::fit(const Array<float,1>& yvals,
 
   // initialize GSL fitting function
   gsl_multifit_function_fdf gsl_func;
-  gsl_func.f=&FunctionFit_func_f;
-  gsl_func.df=&FunctionFit_func_df;
-  gsl_func.fdf=&FunctionFit_func_fdf;
+  gsl_func.f=&FunctionFitDerivative_func_f;
+  gsl_func.df=&FunctionFitDerivative_func_df;
+  gsl_func.fdf=&FunctionFitDerivative_func_fdf;
   gsl_func.n=data4fit->n;
-  gsl_func.p=func.numof_fitpars();
+  gsl_func.p=npars;
   gsl_func.params=(void *)data4fit;
   ODINLOG(odinlog,normalDebug) << "gsl_func done" << STD_endl;
 
   // starting values
-  double x_init[func.numof_fitpars()];
-  for(unsigned int i=0; i<func.numof_fitpars(); i++) {
-    x_init[i]=func.get_fitpar(i).val;
+  double x_init[npars];
+  for(unsigned int i=0; i<npars; i++) {
+    x_init[i]=func->get_fitpar(i).val;
   }
-  gsl_vector_view initial_guess = gsl_vector_view_array (x_init, func.numof_fitpars());
+  gsl_vector_view initial_guess = gsl_vector_view_array (x_init, npars);
   ODINLOG(odinlog,normalDebug) << "starting values done" << STD_endl;
 
   // initialize solver
@@ -203,10 +209,10 @@ bool FunctionFit::fit(const Array<float,1>& yvals,
     ODINLOG(odinlog,normalDebug) << "status(fit)= " << gsl_strerror (status) << STD_endl;
     print_state (iter);
     if (status!=GSL_SUCCESS) break;
-    status = gsl_multifit_test_delta (gsldata->solver->dx, gsldata->solver->x, tol, tol);
+    status = gsl_multifit_test_delta (gsldata->solver->dx, gsldata->solver->x, tolerance, tolerance);
     ODINLOG(odinlog,normalDebug) << "status(test)= " << gsl_strerror (status) << STD_endl;
-    ODINLOG(odinlog,normalDebug) << "iter/max_it= " << iter << "/" << max_it << STD_endl;
-  } while (status == GSL_CONTINUE && iter < max_it);
+    ODINLOG(odinlog,normalDebug) << "iter/max_iterations= " << iter << "/" << max_iterations << STD_endl;
+  } while (status == GSL_CONTINUE && iter < max_iterations);
 
   if(status!=GSL_SUCCESS && status!=GSL_ENOPROG) { // ignoring error 'iteration is not making progress towards solution' and taking intermediate result as best fit
     ODINLOG(odinlog,errorLog) << gsl_strerror(status) << STD_endl;
@@ -216,9 +222,9 @@ bool FunctionFit::fit(const Array<float,1>& yvals,
   gsl_multifit_covar (gsldata->solver->J, 0.0, gsldata->covar);
 
   // copy results
-  for(unsigned int i=0;i<func.numof_fitpars();i++) {
-    func.get_fitpar(i).val=gsl_vector_get(gsldata->solver->x, i);
-    func.get_fitpar(i).err=sqrt(gsl_matrix_get(gsldata->covar,i,i));
+  for(unsigned int i=0;i<npars;i++) {
+    func->get_fitpar(i).val=gsl_vector_get(gsldata->solver->x, i);
+    func->get_fitpar(i).err=sqrt(gsl_matrix_get(gsldata->covar,i,i));
   }
 
   return true;
@@ -226,18 +232,17 @@ bool FunctionFit::fit(const Array<float,1>& yvals,
 
 
 
-void FunctionFit::print_state (size_t iter) {
+void FunctionFitDerivative::print_state (size_t iter) {
 #ifdef ODIN_DEBUG
-  Log<OdinData> odinlog("FunctionFit","fit");
+  Log<OdinData> odinlog("FunctionFitDerivative","fit");
   ODINLOG(odinlog,normalDebug) << "iter=" << iter << STD_endl;
-  for(unsigned int i=0;i<func.numof_fitpars();i++) {
+  for(unsigned int i=0;i<data4fit->modelfunc->numof_fitpars();i++) {
     ODINLOG(odinlog,normalDebug) << "  x" << i << "=" <<  gsl_vector_get (gsldata->solver->x,i) << STD_endl;
   }
   ODINLOG(odinlog,normalDebug) << " |f(x)|=" << fabs(gsl_blas_dnrm2 (gsldata->solver->f)) << STD_endl;
 #endif
 }
 
-const Array<float,1> FunctionFit::defaultArray;
 
 
 
@@ -505,8 +510,11 @@ DownhillSimplex::DownhillSimplex(MinimizationFunction& function) {
   gsldata->minex_func.f = &DownhillSimplex_func_f;
   gsldata->minex_func.params = &function;
 
+#ifdef HAVE_GSL_MULTIMIN_FMINIMIZER_NMSIMPLEX2
   gsldata->s = gsl_multimin_fminimizer_alloc(gsl_multimin_fminimizer_nmsimplex2, ndim); // newer algorithm, only available in recent GSL
-//  gsldata->s = gsl_multimin_fminimizer_alloc(gsl_multimin_fminimizer_nmsimplex, ndim);
+#else
+  gsldata->s = gsl_multimin_fminimizer_alloc(gsl_multimin_fminimizer_nmsimplex, ndim);
+#endif
 
 }
 
@@ -519,22 +527,22 @@ DownhillSimplex::~DownhillSimplex() {
 }
 
 
-fvector DownhillSimplex::get_minimum_parameters(const fvector& starting_points, const fvector& step_size, float ftol, unsigned int nmax) {
+fvector DownhillSimplex::get_minimum_parameters(const fvector& starting_point, const fvector& step_size, unsigned int max_iterations, double tolerance) {
   Log<OdinData> odinlog("DownhillSimplex","get_minimum_parameters");
 
   fvector result(ndim);
 
-  if(starting_points.size()!=ndim) {
-    ODINLOG(odinlog,errorLog) << "size mismatch: starting_points.size()=" << starting_points.size() << ", ndim=" << ndim << STD_endl;
+  if(starting_point.size()!=ndim) {
+    ODINLOG(odinlog,errorLog) << "size mismatch: starting_point.size()=" << starting_point.size() << ", ndim=" << ndim << STD_endl;
     return result;
   }
   if(step_size.size()!=ndim) {
-    ODINLOG(odinlog,errorLog) << "size mismatch: starting_points.size()=" << starting_points.size() << ", ndim=" << ndim << STD_endl;
+    ODINLOG(odinlog,errorLog) << "size mismatch: starting_point.size()=" << starting_point.size() << ", ndim=" << ndim << STD_endl;
     return result;
   }
  
   for(unsigned int idim=0; idim<ndim; idim++) {
-    gsl_vector_set (gsldata->x, idim, starting_points[idim]);
+    gsl_vector_set (gsldata->x, idim, starting_point[idim]);
     gsl_vector_set (gsldata->ss, idim, step_size[idim]);
   }
 
@@ -551,7 +559,7 @@ fvector DownhillSimplex::get_minimum_parameters(const fvector& starting_points,
     if (status) break;
      
     size = gsl_multimin_fminimizer_size(gsldata->s);
-    status = gsl_multimin_test_size(size, ftol);
+    status = gsl_multimin_test_size(size, tolerance);
      
 /*
           if (status == GSL_SUCCESS)
@@ -565,16 +573,156 @@ fvector DownhillSimplex::get_minimum_parameters(const fvector& starting_points,
                    gsl_vector_get (s->x, 1), 
                    s->fval, size);
 */
-  } while (status == GSL_CONTINUE && niterations < nmax);
 
-   for(unsigned int idim=0; idim<ndim; idim++) result[idim]=gsl_vector_get(gsldata->s->x, idim);
+  } while (status == GSL_CONTINUE && niterations < max_iterations);
 
-   ODINLOG(odinlog,normalDebug) << "result" << result << STD_endl;
-   ODINLOG(odinlog,normalDebug) << "min value=" << gsldata->s->fval << STD_endl;
+  for(unsigned int idim=0; idim<ndim; idim++) result[idim]=gsl_vector_get(gsldata->s->x, idim);
+
+  ODINLOG(odinlog,normalDebug) << "result" << result << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "min value=" << gsldata->s->fval << STD_endl;
     
   return result;
 }
 
+//////////////////////////////////////////////////////////////
+
+FunctionFitDownhillSimplex::FunctionFitDownhillSimplex() : func(0), ds(0) {
+}
+
+FunctionFitDownhillSimplex::~FunctionFitDownhillSimplex() {
+  delete ds;
+}
+
+
+bool FunctionFitDownhillSimplex::init(ModelFunction& model_func, unsigned int nvals) {
+  Log<OdinData> odinlog("FunctionFitDownhillSimplex","init");
+  func=&model_func;
+  ODINLOG(odinlog,normalDebug) << "initialized, numof_fitpars=" << func->numof_fitpars() << STD_endl;
+
+  if(!ds) ds=new DownhillSimplex(*this); // has to be initialized after func was assigned
+
+  yvals_cache.resize(nvals);
+  ysigma_cache.resize(nvals);
+  xvals_cache.resize(nvals);
+
+  return true;
+}
+
+
+bool FunctionFitDownhillSimplex::fit(const Array<float,1>& yvals,
+           const Array<float,1>& ysigma,
+           const Array<float,1>& xvals,
+           unsigned int max_iterations, double tolerance) {
+  Log<OdinData> odinlog("FunctionFitDownhillSimplex","fit");
+
+  if(!ds) {
+    ODINLOG(odinlog,errorLog) << "not initialized" << STD_endl;
+    return false;
+  }
+
+  if(yvals.size() != yvals_cache.size()) {
+    ODINLOG(odinlog,errorLog) << "size mismatch in yvals" << STD_endl;
+    return false;
+  }
+  yvals_cache=yvals;
+
+  bool has_ysigma=false;
+  if(ysigma.size()) {
+    if(ysigma.size()!= ysigma_cache.size()) {
+      ODINLOG(odinlog,errorLog) << "size mismatch in ysigma" << STD_endl;
+      return false;
+    }
+    ysigma_cache=ysigma;
+    has_ysigma=true;
+  } else {
+    ysigma_cache=0.0;
+  }
+
+
+  if(xvals.size()) {
+    if(xvals.size()!= xvals_cache.size()) {
+      ODINLOG(odinlog,errorLog) << "size mismatch in xvals" << STD_endl;
+      return false;
+    }
+    xvals_cache=xvals;
+  } else {
+    for(int i=0; i<xvals_cache.size(); i++) xvals_cache(i)=i;
+  }
+
+  unsigned int npars=numof_fitpars();
+
+  fvector starting_point(npars);
+  fvector step_size(npars);
+  for(unsigned int ipar=0; ipar<npars; ipar++) {
+    float fval=func->get_fitpar(ipar).val;
+    starting_point[ipar]=fval;
+    step_size[ipar]=0.1*fabs(fval); // 10% in positive direction
+  }
+
+
+  if(has_ysigma) {
+    int nruns=1000;
+
+    STD_vector<Array<float,1> > fitpar_ensemble(npars);
+    for(unsigned int ipar=0; ipar<npars; ipar++) fitpar_ensemble[ipar].resize(nruns);
+
+    Array<float,1> yvals_cache_orig(yvals_cache.copy());
+    RandomDist rd;
+
+    for(int irun=0; irun<nruns; irun++) {
+      for(int i=0; i<yvals_cache.size(); i++) yvals_cache(i)=yvals_cache_orig(i)+rd.gaussian(ysigma_cache(i));
+
+      fvector mcminvec=ds->get_minimum_parameters(starting_point, step_size, max_iterations, tolerance);
+      for(unsigned int ipar=0; ipar<npars; ipar++) fitpar_ensemble[ipar](irun)=mcminvec[ipar];
+
+    }
+
+    for(unsigned int ipar=0; ipar<npars; ipar++) {
+      ODINLOG(odinlog,normalDebug) << "fitpar_ensemble[" << ipar << "]" << fitpar_ensemble[ipar] << STD_endl;
+      func->get_fitpar(ipar).err=statistics(fitpar_ensemble[ipar]).stdev;
+    }
+
+    yvals_cache=yvals_cache_orig;
+  }
+
+
+  // final run without noise
+  fvector minvec=ds->get_minimum_parameters(starting_point, step_size, max_iterations, tolerance);
+  for(unsigned int ipar=0; ipar<npars; ipar++) func->get_fitpar(ipar).val=minvec[ipar];
+
+  return true;
+}
+
+
+unsigned int FunctionFitDownhillSimplex::numof_fitpars() const {
+  Log<OdinData> odinlog("FunctionFitDownhillSimplex","numof_fitpars");
+  if(func) return func->numof_fitpars();
+  else ODINLOG(odinlog,errorLog) << "not initialized" << STD_endl;
+  return 0;
+}
+
+
+float FunctionFitDownhillSimplex::evaluate(const fvector& pars) const {
+  Log<OdinData> odinlog("FunctionFitDownhillSimplex","evaluate");
+  double result=0.0; // double for higher accuracy when summing up small numbers
+
+  unsigned int npars=numof_fitpars();
+  if(pars.size() != npars) {
+    ODINLOG(odinlog,errorLog) << "size mismatch in npars" << STD_endl;
+    return result;
+  }
+
+  ODINLOG(odinlog,normalDebug) << "pars" << pars << STD_endl;
+
+  for(unsigned int ipar=0; ipar<npars; ipar++) func->get_fitpar(ipar).val=pars[ipar];
+
+  for(int i=0; i<xvals_cache.size(); i++) {
+    float f=func->evaluate_f(xvals_cache(i));
+    result+=pow(f-yvals_cache(i),2);
+  }
+
+  return result;
+}
 
 //////////////////////////////////////////////////////////////
 // Unit test
@@ -590,6 +738,7 @@ class DownhillSimplexTestFunction : public MinimizationFunction {
 };
 
 
+typedef STD_map<STD_string,FunctionFitInterface*> FitterMap;
 
 class FunctionFitTest : public UnitTest {
 
@@ -600,90 +749,135 @@ class FunctionFitTest : public UnitTest {
   bool check() const {
     Log<UnitTest> odinlog(this,"check");
 
-    int numoftestvals=5;
-
-    ExponentialFunctionWithOffset expf_offset;
-    FunctionFit expfit_offset(expf_offset,numoftestvals);
-
-    Array<float,1> yvals(numoftestvals);
-    Array<float,1> ysigma(numoftestvals);
-    Array<float,1> xvals(numoftestvals);
-
-    // some arbitrary values for testing
-    xvals(0)=0.1; yvals(0)=12.4; ysigma(0)=0.7;
-    xvals(1)=1.2; yvals(1)=8.4;  ysigma(1)=1.2;
-    xvals(2)=1.9; yvals(2)=6.1;  ysigma(2)=0.9;
-    xvals(3)=3.0; yvals(3)=5.0;  ysigma(3)=0.8;
-    xvals(4)=4.1; yvals(4)=5.0;  ysigma(4)=1.0;
-
-    expf_offset.A.val=1.0;  // starting value
-    expf_offset.lambda.val=-1.0; // starting value
-    expf_offset.C.val=1.0;  // starting value
-
-    if(!expfit_offset.fit(yvals,ysigma,xvals)) {
-      ODINLOG(odinlog,errorLog) << "ExponentialFunctionWithOffset fit failed" << STD_endl;
-      return false;
-    } 
-
-    float A_expected=8.74419;
-    float A_err_expected=1.32811;
-    float lambda_expected=-0.76985;
-    float lambda_err_expected=0.37922;
-    float C_expected=4.33682;
-    float C_err_expected=1.31881;
-
-    STD_string A_str              =ftos(expf_offset.A.val) +"+-"+ftos(expf_offset.A.err);
-    STD_string A_expected_str     =ftos(A_expected    ) +"+-"+ftos(A_err_expected);
-    STD_string lambda_str         =ftos(expf_offset.lambda.val) +"+-"+ftos(expf_offset.lambda.err);
-    STD_string lambda_expected_str=ftos(lambda_expected)+"+-"+ftos(lambda_err_expected);
-    STD_string C_str              =ftos(expf_offset.C.val) +"+-"+ftos(expf_offset.C.err);
-    STD_string C_expected_str     =ftos(C_expected)     +"+-"+ftos(C_err_expected);
-
-  /*
-    // gives different results depending on the GSL version
-    if(A_str     !=A_expected_str)      {ODINLOG(odinlog,errorLog) << "FunctionFit_check: ExponentialFunctionWithOffset failed: A="      << A_str      << ", but expected A="      << A_expected_str      << STD_endl; return false;}
-    if(lambda_str!=lambda_expected_str) {ODINLOG(odinlog,errorLog) << "FunctionFit_check: ExponentialFunctionWithOffset failed: lambda=" << lambda_str << ", but expected lambda=" << lambda_expected_str << STD_endl; return false;}
-    if(C_str     !=C_expected_str)      {ODINLOG(odinlog,errorLog) << "FunctionFit_check: ExponentialFunctionWithOffset failed: C="      << C_str      << ", but expected C="      << C_expected_str      << STD_endl; return false;}
-  */
-
-
     /////////////////////////////////////////////////////
 
-    int numoftestvals2=100;
+    DownhillSimplexTestFunction dstf;
+    DownhillSimplex ds(dstf);
 
-    ExponentialFunction expf;
-    FunctionFit expfit(expf,numoftestvals2);
+    fvector starting_point(2);
+    starting_point=0.0;
 
-    // arbitrary values for testing
-    A_expected=44.5;
-    lambda_expected=0.78;
+    fvector step_size(2);
+    step_size=1.0;
 
-    expf.A.val=A_expected;
-    expf.lambda.val=lambda_expected;
+    fvector dsresult=ds.get_minimum_parameters(starting_point, step_size);
 
-    yvals.resize(numoftestvals2);
-    ysigma.resize(numoftestvals2);
-    xvals.resize(numoftestvals2);
-
-    for(int i=0; i<numoftestvals2; i++) xvals(i)=2.0 * double(i)/double(numoftestvals2);
-
-    // check self integrity of fit
-    yvals=expf.get_function(xvals);
-
-    ysigma=1.0;
-
-    if(!expfit.fit(yvals,ysigma,xvals)) {
-      ODINLOG(odinlog,errorLog) << "ExponentialFunction fit failed" << STD_endl;
+    fvector dsexpected(2);
+    dsexpected[0]=2.0;
+    dsexpected[1]=3.0;
+    float maxdiff=(dsresult-dsexpected).maxabs();
+    ODINLOG(odinlog,normalDebug) << "maxdiff=" << maxdiff << STD_endl;
+    if((dsresult-dsexpected).maxabs()>1.0e-3) {
+      ODINLOG(odinlog,errorLog) << "DownhillSimplex failed, result" << dsresult << ", but expected" << dsexpected << STD_endl;
       return false;
     }
 
-    A_str              =ftos(expf.A.val);
-    A_expected_str     =ftos(A_expected);
-    lambda_str         =ftos(expf.lambda.val);
-    lambda_expected_str=ftos(lambda_expected);
+    /////////////////////////////////////////////////////
 
-    if(A_str     !=A_expected_str)      {ODINLOG(odinlog,errorLog) << "ExponentialFunction failed: A="      << A_str      << ", but expected A="      << A_expected_str      << STD_endl; return false;}
-    if(lambda_str!=lambda_expected_str) {ODINLOG(odinlog,errorLog) << "ExponentialFunction failed: lambda=" << lambda_str << ", but expected lambda=" << lambda_expected_str << STD_endl; return false;}
+    FitterMap fittermap;
+    fittermap["FunctionFitDerivative"]=new FunctionFitDerivative;
+    fittermap["FunctionFitDownhillSimplex"]=new FunctionFitDownhillSimplex;
+
+    int numoftestvals=5;
+    Array<float,1> yvals;
+    Array<float,1> ysigma;
+    Array<float,1> xvals;
+
+    for(FitterMap::iterator it=fittermap.begin(); it!=fittermap.end(); ++it) {
+
+      STD_string fitterlabel=it->first;
+      FunctionFitInterface* fitter=it->second;
+
+/*
+
+      ExponentialFunctionWithOffset expf_offset;
+      if(!fitter->init(expf_offset,numoftestvals)) return false;
+
+      yvals.resize(numoftestvals);
+      ysigma.resize(numoftestvals);
+      xvals.resize(numoftestvals);
+
+      // some arbitrary values for testing
+      xvals(0)=0.1; yvals(0)=12.4; ysigma(0)=0.7;
+      xvals(1)=1.2; yvals(1)=8.4;  ysigma(1)=1.2;
+      xvals(2)=1.9; yvals(2)=6.1;  ysigma(2)=0.9;
+      xvals(3)=3.0; yvals(3)=5.0;  ysigma(3)=0.8;
+      xvals(4)=4.1; yvals(4)=5.0;  ysigma(4)=1.0;
+
+
+      expf_offset.A.val=1.0;  // starting value
+      expf_offset.lambda.val=-1.0; // starting value
+      expf_offset.C.val=1.0;  // starting value
+
+      if(!fitter->fit(yvals,ysigma,xvals)) {
+        ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunctionWithOffset) fit failed" << STD_endl;
+        return false;
+      } 
+
+      float A_expected=8.77292;
+      float A_err_expected=1.34177;
+      float lambda_expected=-0.76177;
+      float lambda_err_expected=0.37545;
+      float C_expected=4.30505;
+      float C_err_expected=1.33666;
+
+      STD_string A_str              =ftos(expf_offset.A.val) +"+-"+ftos(expf_offset.A.err);
+      STD_string A_expected_str     =ftos(A_expected    ) +"+-"+ftos(A_err_expected);
+      STD_string lambda_str         =ftos(expf_offset.lambda.val) +"+-"+ftos(expf_offset.lambda.err);
+      STD_string lambda_expected_str=ftos(lambda_expected)+"+-"+ftos(lambda_err_expected);
+      STD_string C_str              =ftos(expf_offset.C.val) +"+-"+ftos(expf_offset.C.err);
+      STD_string C_expected_str     =ftos(C_expected)     +"+-"+ftos(C_err_expected);
+
+
+      // gives different results depending on the GSL version
+      if(A_str     !=A_expected_str)      {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunctionWithOffset) failed: A="      << A_str      << ", but expected A="      << A_expected_str      << STD_endl; return false;}
+      if(lambda_str!=lambda_expected_str) {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunctionWithOffset) failed: lambda=" << lambda_str << ", but expected lambda=" << lambda_expected_str << STD_endl; return false;}
+      if(C_str     !=C_expected_str)      {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunctionWithOffset) failed: C="      << C_str      << ", but expected C="      << C_expected_str      << STD_endl; return false;}
+*/
+
+      /////////////////////////////////////////////////////
+
+      int numoftestvals2=100;
+
+      ExponentialFunction expf;
+      if(!fitter->init(expf,numoftestvals2)) return false;
+
+      // arbitrary values for testing
+      float A_expected=44.5;
+      float lambda_expected=0.78;
+
+      expf.A.val=A_expected;
+      expf.lambda.val=lambda_expected;
+
+      yvals.resize(numoftestvals2);
+      ysigma.resize(0); // no error bars
+      xvals.resize(numoftestvals2);
+
+      for(int i=0; i<numoftestvals2; i++) xvals(i)=2.0 * double(i)/double(numoftestvals2);
+
+      // check self integrity of fit
+      yvals=expf.get_function(xvals);
+
+      // starting values
+      expf.A.val=1.0;
+      expf.lambda.val=-1.0;
+
+
+      if(!fitter->fit(yvals,ysigma,xvals)) {
+        ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) fit failed" << STD_endl;
+        return false;
+      }
+
+      int digits=2;
+      STD_string A_str              =ftos(expf.A.val,digits);
+      STD_string A_expected_str     =ftos(A_expected,digits);
+      STD_string lambda_str         =ftos(expf.lambda.val,digits);
+      STD_string lambda_expected_str=ftos(lambda_expected,digits);
+
+      if(A_str     !=A_expected_str)      {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: A="      << A_str      << ", but expected A="      << A_expected_str      << STD_endl; return false;}
+      if(lambda_str!=lambda_expected_str) {ODINLOG(odinlog,errorLog) << fitterlabel << "(ExponentialFunction) failed: lambda=" << lambda_str << ", but expected lambda=" << lambda_expected_str << STD_endl; return false;}
+
+    } // end iteration over fittermap
 
     /////////////////////////////////////////////////////
 
@@ -806,31 +1000,6 @@ class FunctionFitTest : public UnitTest {
       return false;
     }
 
-    
-    
-    /////////////////////////////////////////////////////
-  
-    DownhillSimplexTestFunction dstf;
-    DownhillSimplex ds(dstf);
-
-    fvector starting_points(2);
-    starting_points=0.0;
-
-    fvector step_size(2);
-    step_size=1.0;
-
-    fvector dsresult=ds.get_minimum_parameters(starting_points, step_size);
-
-    fvector dsexpected(2);
-    dsexpected[0]=2.0;
-    dsexpected[1]=3.0;
-    float maxdiff=(dsresult-dsexpected).maxabs();
-    ODINLOG(odinlog,normalDebug) << "maxdiff=" << maxdiff << STD_endl;
-    if((dsresult-dsexpected).maxabs()>1.0e-3) {
-      ODINLOG(odinlog,errorLog) << "DownhillSimplex failed, result" << dsresult << ", but expected" << dsexpected << STD_endl;
-      return false;
-    }
-
     return true;
 
   }
