@@ -2,8 +2,8 @@
                           fitting.h  -  description
                              -------------------
     begin                : Fri Apr 6 2001
-    copyright            : (C) 2001 by Thies Jochimsen & Michael von Mengershausen
-    email                : jochimse@cns.mpg.de  mengers@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen & Michael von Mengershausen
+    email                : thies@jochimsen.de  mengers@cns.mpg.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -24,6 +24,9 @@
 #include <odindata/utils.h>
 
 
+#define DEFAULT_MAX_ITER 1000
+#define DEFAULT_TOLERANCE 1e-4
+
 /**
   * @addtogroup odindata
   * @{
@@ -86,24 +89,6 @@ class ModelFunction {
   */
   virtual fitpar& get_fitpar(unsigned int i) = 0;
 
-
-/**
-  * Fit the function to the given dataset.
-  * The current parameters are taken as starting values.
-  * Fits the function to the y-values 'yvals', and optionally
-  * to the corresponding y-error bars 'ysigma' and x-vals 'xvals'.
-  * If no error-bars are given, they are all set to 0.1 and if no
-  * x-vals are given equidistant points with an increment of one are chosen,
-  * i.e. xvals(i)=i;
-  * A maximum of 'max_iterations' iterations and the given 'tolerance'
-  * is used for the fit.
-  * Returns true on success.
-  */
-  bool fit(const Array<float,1>& yvals,
-           const Array<float,1>& ysigma=defaultArray,
-           const Array<float,1>& xvals=defaultArray,
-           unsigned int max_iterations=500, double tolerance=1.0e-4);
-  
 /**
   * Returns the function values for x-values 'xvals'.
   */
@@ -123,26 +108,19 @@ class ModelFunction {
 
 ////////////////////////////////////////////////////////////////////////
 
-class ModelData; // forward declaration
-class GslData4Fit; // forward declaration
-
 /**
-  * Class which is used for fitting of functions.
+  * Interface class for all function fits
   */
-class FunctionFit {
+class FunctionFitInterface {
 
  public:
 
-/**
-  * Prepare a non-linear least-square fit of function 'model_func' for 'nvals' values with a
-  * maximum of 'max_iterations' iterations and the given 'tolerance'.
-  */
-  FunctionFit(ModelFunction& model_func, unsigned int nvals, unsigned int max_iterations=500, double tolerance=1.0e-4);
+  virtual ~FunctionFitInterface() {}
 
 /**
-  * Destructor
+  * Prepare a non-linear least-square fit of function 'model_func' for 'nvals' values
   */
-  ~FunctionFit();
+  virtual bool init(ModelFunction& model_func, unsigned int nvals) = 0;
 
 /**
   * The fitting routine that takes the starting values from the model function,
@@ -150,24 +128,52 @@ class FunctionFit {
   * and x-vals 'xvals'. If no error-bars are given, they are all set to 0.1 and if no
   * x-vals are given equidistant points with an increment of one are chosen,
   * i.e. xvals(i)=i;
+  * A maximum of 'max_iterations' iterations and the given 'tolerance' is used during the fit.
   * Returns true on success.
   */
-  bool fit(const Array<float,1>& yvals,
+  virtual bool fit(const Array<float,1>& yvals,
            const Array<float,1>& ysigma=defaultArray,
-           const Array<float,1>& xvals=defaultArray);
-
+           const Array<float,1>& xvals=defaultArray,
+           unsigned int max_iterations=DEFAULT_MAX_ITER, double tolerance=DEFAULT_TOLERANCE) = 0;
 
   // dummy array used for default arguments
   static const Array<float,1> defaultArray;
+};
+
+////////////////////////////////////////////////////////////////////////
+
+class ModelData; // forward declaration
+class GslData4Fit; // forward declaration
+
+/**
+  * Class which is used for derivative-based fitting of functions.
+  */
+class FunctionFitDerivative : public virtual FunctionFitInterface {
+
+ public:
+
+/**
+  * Constructs uninitialized function fit
+  */
+   FunctionFitDerivative() : gsldata(0), data4fit(0) {}
+
+/**
+  * Destructor
+  */
+  ~FunctionFitDerivative();
+
+  // overloading virtual functions of FunctionFitInterface
+  bool init(ModelFunction& model_func, unsigned int nvals);
+  bool fit(const Array<float,1>& yvals,
+           const Array<float,1>& ysigma=defaultArray,
+           const Array<float,1>& xvals=defaultArray,
+           unsigned int max_iterations=DEFAULT_MAX_ITER, double tolerance=DEFAULT_TOLERANCE);
+
 
  private:
 
   void print_state (size_t iter);
 
-  ModelFunction& func;
-  unsigned int max_it;
-  double tol;
-
   GslData4Fit* gsldata;
   ModelData* data4fit;
 };
@@ -464,12 +470,12 @@ class DownhillSimplex {
 
 /**
   * Returns parameter values which minimize function
-  * - starting_points: Starting from this initial point
+  * - starting_point: Starting from this initial point
   * - step_size: The size of the initial trial steps
   * - ftol:  Tolerannce
   * - nmax: Max number of iterations
   */
-  fvector get_minimum_parameters(const fvector& starting_points, const fvector& step_size, float ftol=1e-3, unsigned int nmax=1000);
+  fvector get_minimum_parameters(const fvector& starting_point, const fvector& step_size, unsigned int max_iterations=DEFAULT_MAX_ITER, double tolerance=DEFAULT_TOLERANCE);
 
 
  private:
@@ -481,6 +487,45 @@ class DownhillSimplex {
 
 ///////////////////////////////////////////////////////////////////////
 
+/**
+  * Class for downhill-simplex-based fitting of functions.
+  */
+class FunctionFitDownhillSimplex : public virtual FunctionFitInterface, public MinimizationFunction {
+
+ public:
+
+/**
+  * Constructs uninitialized function fit
+  */
+   FunctionFitDownhillSimplex();
+
+/**
+  * Destructor
+  */
+  ~FunctionFitDownhillSimplex();
+
+  // overloading virtual functions of FunctionFitInterface
+  bool init(ModelFunction& model_func, unsigned int nvals);
+  bool fit(const Array<float,1>& yvals,
+           const Array<float,1>& ysigma=defaultArray,
+           const Array<float,1>& xvals=defaultArray,
+           unsigned int max_iterations=DEFAULT_MAX_ITER, double tolerance=DEFAULT_TOLERANCE);
+
+
+  // overloading virtual functions of MinimizationFunction
+  unsigned int numof_fitpars() const;
+  float evaluate(const fvector& pars) const;
+
+
+ private:
+  ModelFunction* func;
+  DownhillSimplex* ds;
+  Array<float,1> yvals_cache;
+  Array<float,1> ysigma_cache;
+  Array<float,1> xvals_cache;
+};
+
+///////////////////////////////////////////////////////////////////////
 
 /**
   * Fits an N_rank-dimensional polynomial of order 'polynom_order' to each point of the
