@@ -2,7 +2,7 @@
                           mri_utils.h  -  description
                              -------------------
     begin                : Wed Feb 9 2005
-    copyright            : (C) 2005 by Thies H. Jochimsen
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
     email                : 
  ***************************************************************************/
 
@@ -142,6 +142,25 @@ bool operator != (const TinyVector<T,N_rank>& t1, const TinyVector<T,N_rank>& t2
 
 //////////////////////////////////////////////////////////
 
+/**
+  * Product operator for TinyMatrix*TinyMatrix (defined here because the product(TinyMatrix,TinyMatrix) function is missing in blitz-0.10)
+  */
+template<typename T, int N_rows, int N_columns>
+TinyVector<T,N_rows> operator * (const TinyMatrix<T, N_rows, N_columns>& matrix, const TinyVector<T, N_columns>& vector) {
+  TinyVector<T,N_rows> result;
+  result=0;
+
+  for(int icol=0; icol<N_columns; icol++) {
+    for(int irow=0; irow<N_rows; irow++) {
+      result(irow)+=matrix(irow,icol)*vector(icol);
+    }
+  }
+
+  return result;
+}
+
+//////////////////////////////////////////////////////////
+
 /**
   * Compares array shapes while discarding dimensions with zero value in dimmask. Returns true if equal.
   */
