@@ -154,9 +154,9 @@ Geometry::Geometry(const STD_string& label) : JcampDxBlock(label) {
   nSlices.set_description("Number of sices");
   sliceThickness.set_unit(ODIN_SPAT_UNIT).set_cmdline_option("st").set_description("Slice thickness");
   sliceDistance.set_unit(ODIN_SPAT_UNIT).set_cmdline_option("sd").set_description("Inter-slice distance (from center to center)");
-  heightAngle.set_description("1st orientation angle");
-  azimutAngle.set_description("2nd orientation angle");
-  inplaneAngle.set_description("3rd orientation angle");
+  heightAngle.set_description("height rotation angle").set_cmdline_option("ah");
+  azimutAngle.set_description("azimuthal rotation angle").set_cmdline_option("aa");
+  inplaneAngle.set_description("inplane rotation angle").set_cmdline_option("ai");
   reverseSlice.set_description("Reverse direction of slice vector");
   Reset.set_description("Reset to default values");
   Transpose.set_description("Transpose in-plane");
@@ -345,7 +345,6 @@ dvector Geometry::get_sliceOffsetVector() const {
 }
 
 
-
 darray Geometry::get_cornerPoints(const Geometry& background, unsigned int backgrslice) const {
   Log<Para> odinlog(this,"get_cornerPoints");
 
