@@ -2,8 +2,8 @@
                           geometry.h  -  description
                              -------------------
     begin                : Wed Apr 17 2002
-    copyright            : (C) 2001 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -277,7 +277,6 @@ public:
   double get_sliceThickness() const {return sliceThickness;}
 
 
-
 /**
   * Returns a 5-dimensional array that contains the corner points of the slices/voxels where indexing is as follows:
   * (unsigned int slice,sliceBoundary boundary1,sliceBoundary boundary2,sliceBoundary boundary3, axis direction) with
@@ -399,6 +398,7 @@ public:
   JDXint    nSlices;
   JDXdouble sliceDistance;
   JDXdouble sliceThickness;
+  JDXintArr sliceOrder;
 
   JDXaction Reset;
   JDXaction Transpose;
