@@ -2,8 +2,8 @@
                           jdxbase.h  -  description
                              -------------------
     begin                : Sun Jun 6 2004
-    copyright            : (C) 2001 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -108,9 +108,9 @@ enum scaleType {displayScale=0,xPlotScale,yPlotScaleLeft,yPlotScaleRight,n_Scale
   */
 struct ArrayScale {
 
-  ArrayScale() : minval(0), maxval(0) {}
+  ArrayScale() : minval(0), maxval(0), enable(true) {}
 
-  ArrayScale(const STD_string& scalelabel, const STD_string& scaleunit, float scalemin=0.0, float scalemax=0.0);
+  ArrayScale(const STD_string& scalelabel, const STD_string& scaleunit, float scalemin=0.0, float scalemax=0.0, bool enablescale=true);
 
   STD_string get_label_with_unit() const;
 
@@ -128,6 +128,11 @@ struct ArrayScale {
   * Lower and upper bound of scale
   */
   float minval,maxval;
+
+/**
+  * Whether scale is enabled
+  */
+  bool enable;
 };
 
 ///////////////////////////////////////////////////////////////////////
