@@ -164,12 +164,13 @@ STD_ostream& JcampDxBlock::print2stream(STD_ostream& os) const {
 }
 
 
-STD_string JcampDxBlock::printval(const STD_string& parameterName) const {
+STD_string JcampDxBlock::printval(const STD_string& parameterName, bool append_unit) const {
   Log<JcampDx> odinlog(this,"printval");
   STD_string retstring;
   constiter it=ldr_exists(parameterName);
   if(it!=get_const_end()) {
     retstring=(*it)->printvalstring();
+    if(append_unit) retstring+=(*it)->get_unit();
   }
   return retstring;
 }
