@@ -232,8 +232,8 @@ System::System(const STD_string& object_label) : JcampDxBlock(object_label) {
   datatype=TypeTraits::type2label(float(0));
   datatype.set_description("Digital representation of raw data");
 
-  grad_reson_center.set_filemode(exclude).set_unit(ODIN_FREQ_UNIT).set_description("Center of gradient resonance frequencies");
-  grad_reson_width.set_filemode(exclude).set_unit(ODIN_FREQ_UNIT).set_description("Width of gradient resonance frequencies");
+  grad_reson_center.set_unit(ODIN_FREQ_UNIT).set_description("Center of gradient resonance frequencies");
+  grad_reson_width.set_unit(ODIN_FREQ_UNIT).set_description("Width of gradient resonance frequencies");
 
   min_duration.resize(endObj);
   min_duration=0.0;
@@ -250,6 +250,30 @@ System& System::operator = (const System& s) {
   // copy only visible members of JcampDxBlock
   copy_ldr_vals(s);
 
+
+
+
+  // preserve parmode and filemode which varies across platforms
+
+
+  grad_shift         .set_filemode(s.grad_shift         .get_filemode()).set_parmode(s.grad_shift         .get_parmode());
+  inter_grad_delay   .set_filemode(s.inter_grad_delay   .get_filemode()).set_parmode(s.inter_grad_delay   .get_parmode());
+  reference_gain     .set_filemode(s.reference_gain     .get_filemode()).set_parmode(s.reference_gain     .get_parmode());
+  transmit_coil_name .set_filemode(s.transmit_coil_name .get_filemode()).set_parmode(s.transmit_coil_name .get_parmode());
+  delay_rastertime   .set_filemode(s.delay_rastertime   .get_filemode()).set_parmode(s.delay_rastertime   .get_parmode());
+  rf_rastertime      .set_filemode(s.rf_rastertime      .get_filemode()).set_parmode(s.rf_rastertime      .get_parmode());
+  grad_rastertime    .set_filemode(s.grad_rastertime    .get_filemode()).set_parmode(s.grad_rastertime    .get_parmode());
+  min_grad_rastertime.set_filemode(s.min_grad_rastertime.get_filemode()).set_parmode(s.min_grad_rastertime.get_parmode());
+  acq_rastertime     .set_filemode(s.acq_rastertime     .get_filemode()).set_parmode(s.acq_rastertime     .get_parmode());
+  max_rf_samples     .set_filemode(s.max_rf_samples     .get_filemode()).set_parmode(s.max_rf_samples     .get_parmode());
+  max_grad_samples   .set_filemode(s.max_grad_samples   .get_filemode()).set_parmode(s.max_grad_samples   .get_parmode());
+  datatype           .set_filemode(s.datatype           .get_filemode()).set_parmode(s.datatype           .get_parmode());
+  grad_reson_center  .set_filemode(s.grad_reson_center  .get_filemode()).set_parmode(s.grad_reson_center  .get_parmode());
+  grad_reson_width   .set_filemode(s.grad_reson_width   .get_filemode()).set_parmode(s.grad_reson_width   .get_parmode());
+
+
+
+
   return *this;
 }
 
