@@ -4,7 +4,7 @@
 
 
 floatBox3D::floatBox3D(const float *data, float lowbound, float uppbound, long int nx, long int ny, long int nz,
-                       int coarseFactor, QWidget *parent, const char *name,
+                       bool disable_scale, int coarseFactor, QWidget *parent, const char *name,
                        const float *overlay_map, float lowbound_map, float uppbound_map, unsigned int nx_map, unsigned int ny_map, unsigned int nz_map, bool map_firescale, float map_rectsize,
                        bool colormap)
  : QGroupBox(name,parent) {
@@ -42,7 +42,7 @@ floatBox3D::floatBox3D(const float *data, float lowbound, float uppbound, long i
 
   grid=new GuiGridLayout( this, nrow, ncol);
 
-  label = new floatLabel2D(data,lowbound,uppbound,nx,ny,coarseFactor,this,name,overlay_map,lowbound_map,uppbound_map,nx_map,ny_map,map_firescale,map_rectsize,colormap);
+  label = new floatLabel2D(data,lowbound,uppbound,nx,ny,disable_scale,coarseFactor,this,name,overlay_map,lowbound_map,uppbound_map,nx_map,ny_map,map_firescale,map_rectsize,colormap);
   grid->add_widget( label, 0, 0, GuiGridLayout::Default, 1, 2 );
   connect(label,SIGNAL(clicked(int,int)),this,SLOT(emitClicked(int,int)));
   connect(label,SIGNAL(newProfile(const float *, int, bool, int)),this,SLOT(emitNewProfile(const float *, int, bool, int)));
