@@ -2,8 +2,8 @@
                           jdxblockwidget.h  -  description
                              -------------------
     begin                : Mon Aug 5 2005
-    copyright            : (C) 2002 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
