@@ -383,6 +383,10 @@ void JDXwidget::write_pixmap(const char* fname, const char* format, bool dump_al
   if(floatArrwidget2) floatArrwidget2->write_pixmap(fname, format, dump_all);
 }
 
+void JDXwidget::write_legend(const char* fname, const char* format) const {
+  if(floatArrwidget2) floatArrwidget2->write_legend(fname, format);
+}
+
 void JDXwidget::write_map_legend(const char* fname, const char* format) const {
   if(floatArrwidget2) floatArrwidget2->write_map_legend(fname, format);
 }
@@ -596,7 +600,8 @@ void JDXwidget::create_or_update_floatArrwidget(const farray& arr, bool initial)
       }
 
 
-      floatArrwidget2=new floatBox3D(sizedfarray.c_array(),dispscale.minval,dispscale.maxval,nx,ny,nz,factor,vport,ldrlabel.c_str(),
+      floatArrwidget2=new floatBox3D(sizedfarray.c_array(),dispscale.minval,dispscale.maxval,nx,ny,nz,
+        !dispscale.enable,factor,vport,ldrlabel.c_str(),
         olm,olm_low,olm_upp,olm_x,olm_y,olm_z,olm_firescale,olm_rectsize,colormap);
       set_widget(floatArrwidget2, GuiGridLayout::Default, true);
       connect(floatArrwidget2,SIGNAL(clicked(int,int,int)),this,SLOT(emitClicked(int, int, int)));
