@@ -31,14 +31,14 @@
 
 
 #if QT_VERSION > 0x03FFFF
-#define QT_VERSION_4
+#define QT_VERSION_POST3
 #else
 #define QT_VERSION_3
 #endif
 
 
 
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
 #include <qmenu.h>
 #include <qscrollarea.h>
 #include <qtablewidget.h>
@@ -73,8 +73,8 @@ LOGGROUNDWORK(OdinQt)
 
 const char* c_str(const QString& qs) {
   if(qs.isEmpty()) return "";
-#ifdef QT_VERSION_4
-  return qs.toAscii().constData();
+#ifdef QT_VERSION_POST3
+  return qs.toLocal8Bit().constData();
 #else
   return qs;
 #endif
@@ -82,7 +82,7 @@ const char* c_str(const QString& qs) {
 
 
 int layout_border_size() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return 0;
 #else
   return (3*QFontInfo(QFont(_FONT_TYPE_, _FONT_SIZE_)).pixelSize()/2);
@@ -92,7 +92,7 @@ int layout_border_size() {
 void init_label(QLabel* ql) {
   ql->setFrameStyle( QFrame::Box | QFrame::Sunken );
   ql->setIndent( 0 );
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   ql->setCursor(Qt::CrossCursor);
 #else
   ql->setCursor(Qt::crossCursor);
@@ -100,7 +100,7 @@ void init_label(QLabel* ql) {
 }
 
 bool left_button(const QMouseEvent* qme, bool return_current_state) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(return_current_state) return (qme->buttons() & Qt::LeftButton);
   else                     return (qme->button()  & Qt::LeftButton);
 #else
@@ -110,7 +110,7 @@ bool left_button(const QMouseEvent* qme, bool return_current_state) {
 }
 
 bool right_button(const QMouseEvent* qme, bool return_current_state) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(return_current_state) return (qme->buttons() & Qt::RightButton);
   else                     return (qme->button()  & Qt::RightButton);
 #else
@@ -120,7 +120,7 @@ bool right_button(const QMouseEvent* qme, bool return_current_state) {
 }
 
 bool middle_button(const QMouseEvent* qme, bool return_current_state) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(return_current_state) return (qme->buttons() & Qt::MidButton);
   else                     return (qme->button()  & Qt::MidButton);
 #else
@@ -130,7 +130,7 @@ bool middle_button(const QMouseEvent* qme, bool return_current_state) {
 }
 
 void add_tooltip(QWidget* w, const char* txt) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   w->setToolTip(txt);
 #else
   QToolTip::add(w,txt);
@@ -140,7 +140,7 @@ void add_tooltip(QWidget* w, const char* txt) {
 
 void set_platform_defaults(QWidget* w, bool enable) {
 #ifdef Q_WS_MAC
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   w->setAttribute(Qt::WA_MacMetalStyle,enable);
 #endif
 #endif
@@ -150,7 +150,7 @@ void set_platform_defaults(QWidget* w, bool enable) {
 
 
 STD_string get_save_filename(const char* caption, const char* startwith, const char* filter, QWidget* parent) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QFileDialog::Options opts=0;
 #ifdef Q_WS_MAC
   opts=QFileDialog::DontUseNativeDialog; // native dialog does not work well, e.g. with symlinks
@@ -163,7 +163,7 @@ STD_string get_save_filename(const char* caption, const char* startwith, const c
 }
 
 STD_string get_open_filename(const char* caption, const char* startwith, const char* filter, QWidget* parent) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QFileDialog::Options opts=0;
 #ifdef Q_WS_MAC
   opts=QFileDialog::DontUseNativeDialog; // native dialog does not work well, e.g. with symlinks
@@ -176,7 +176,7 @@ STD_string get_open_filename(const char* caption, const char* startwith, const c
 }
 
 STD_string get_directory(const char* caption, const char* startwith, QWidget* parent) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QFileDialog::Options opts=QFileDialog::ShowDirsOnly;
 #ifdef Q_WS_MAC
   opts|=QFileDialog::DontUseNativeDialog; // native dialog does not work well, e.g. with symlinks
@@ -213,7 +213,7 @@ bool message_question(const char* text, const char* caption, QWidget* parent, bo
 ///////////////////////////////////////////////////
 
 int paintdevice_height(const QPaintDevice* qpd) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qpd->height();
 #else
   QPaintDeviceMetrics metrics(qpd);
@@ -222,7 +222,7 @@ int paintdevice_height(const QPaintDevice* qpd) {
 }
 
 int paintdevice_width(const QPaintDevice* qpd) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qpd->width();
 #else
   QPaintDeviceMetrics metrics(qpd);
@@ -234,7 +234,7 @@ int paintdevice_width(const QPaintDevice* qpd) {
 ///////////////////////////////////////////////////
 
 svector get_possible_image_fileformats() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QList<QByteArray> fmtlist=QImageReader::supportedImageFormats();
   int nfmts=fmtlist.size();
 #else
@@ -243,7 +243,7 @@ svector get_possible_image_fileformats() {
 #endif
   svector result; result.resize(nfmts);
   for(int ifmt=0; ifmt<nfmts; ifmt++) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
     result[ifmt]=tolowerstr((const char*)fmtlist[ifmt]);
 #else
     result[ifmt]=tolowerstr((const char*)fmtlist.at(ifmt));
@@ -256,7 +256,7 @@ svector get_possible_image_fileformats() {
 ///////////////////////////////////////////////////
 
 GuiGridLayout::GuiGridLayout(QWidget *parent, int rows, int columns, bool margin) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qgl=new QGridLayout( parent );
 #else
   qgl=new QGridLayout( parent, rows, columns );
@@ -269,7 +269,7 @@ GuiGridLayout::~GuiGridLayout() {
 }
 
 void GuiGridLayout::add_widget(QWidget *w, int row, int column, Alignment alignment, int rowSpan, int columnSpan ) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   Qt::Alignment align=0;
   if(alignment==VCenter) align=Qt::AlignVCenter;
   if(alignment==VCenter) align=Qt::AlignVCenter;
@@ -284,7 +284,7 @@ void GuiGridLayout::add_widget(QWidget *w, int row, int column, Alignment alignm
 }
 
 void GuiGridLayout::set_col_stretch(int col, int factor) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qgl->setColumnStretch(col,factor);
 #else
   qgl->setColStretch(col,factor);
@@ -296,7 +296,7 @@ void GuiGridLayout::set_row_stretch(int row, int factor) {
 }
 
 void GuiGridLayout::set_col_minsize(int col, int minsize) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qgl->setColumnMinimumWidth(col, minsize);
 #else
   qgl->addColSpacing(col, minsize);
@@ -304,7 +304,7 @@ void GuiGridLayout::set_col_minsize(int col, int minsize) {
 }
 
 void GuiGridLayout::set_row_minsize(int row, int minsize) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qgl->setRowMinimumHeight(row, minsize);
 #else
   qgl->addRowSpacing(row, minsize);
@@ -321,7 +321,7 @@ GuiButton::GuiButton(QWidget *parent, QObject* receiver, const char* member, con
   qpb = new QPushButton(parent);
 
   if(onlabel && offlabel) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
     qpb->setCheckable(true);
 #else
     qpb->setToggleButton(true);
@@ -350,7 +350,7 @@ void GuiButton::set_text(bool state) {
 void GuiButton::set_toggled(bool state) {
   if(!(ontext && offtext)) return;
   set_text(state);
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qpb->setChecked (state);
 #else
   qpb->setOn (state);
@@ -366,7 +366,7 @@ QWidget* GuiButton::get_widget() {
 }
 
 bool GuiButton::is_on() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qpb->isChecked();
 #else
   return qpb->isOn();
@@ -397,7 +397,7 @@ void GuiLineEdit::set_text(const char* txt) {qle->setText(txt);}
 const char* GuiLineEdit::get_text() const {return c_str(qle->text());}
 
 bool GuiLineEdit::is_modified() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   bool result=qle->isModified();
   qle->setModified(false);
 #else
@@ -413,7 +413,7 @@ QWidget* GuiLineEdit::get_widget() {return qle;}
 ///////////////////////////////////////////////////
 
 GuiPopupMenu::GuiPopupMenu(QWidget *parent) : id(0) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qm=new QMenu(parent);
 #else
   qpm=new QPopupMenu(parent);
@@ -422,7 +422,7 @@ GuiPopupMenu::GuiPopupMenu(QWidget *parent) : id(0) {
 
 GuiPopupMenu::~GuiPopupMenu() {
 /* // never deleted
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   delete qm;
 #else
   delete qpm;
@@ -431,7 +431,7 @@ GuiPopupMenu::~GuiPopupMenu() {
 }  
 
 void GuiPopupMenu::insert_item(const char* text, const QObject* receiver, const char* member, int accel) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
  qm->addAction(text, receiver, member, accel);
 #else
   id++;
@@ -440,7 +440,7 @@ void GuiPopupMenu::insert_item(const char* text, const QObject* receiver, const
 }
 
 void GuiPopupMenu::insert_separator() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qm->addSeparator();
 #else
   qpm->insertSeparator();
@@ -449,7 +449,7 @@ void GuiPopupMenu::insert_separator() {
 
 
 void GuiPopupMenu::popup(const QPoint& p) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
  qm->exec(p); // synchronous popup
 #else
   qpm->exec(p); // synchronous popup
@@ -461,7 +461,7 @@ void GuiPopupMenu::popup(const QPoint& p) {
 
 
 GuiSlider::GuiSlider(QWidget *parent, int minValue, int maxValue, int pageStep, int value, int tickInterval) : modified(false) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qs=new QSlider(Qt::Horizontal, parent);
   qs->setRange(minValue, maxValue);
   qs->setPageStep(pageStep);
@@ -488,7 +488,7 @@ GuiSlider::~GuiSlider() {
 ///////////////////////////////////////////////////
 
 void GuiComboBox::set_names(const svector& names) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   for (unsigned int i=0; i<names.size(); i++) qcb->insertItem(i, names[i].c_str());
 #else
   for (unsigned int i=0; i<names.size(); i++) qcb->insertItem( names[i].c_str() );
@@ -497,7 +497,7 @@ void GuiComboBox::set_names(const svector& names) {
 }
 
 void GuiComboBox::common_init(QWidget* parent, const svector& names) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qcb = new QComboBox(parent);
   qcb->setEditable(false);
   qcb->setSizeAdjustPolicy(QComboBox::AdjustToContents); // Width to fit all entries
@@ -516,14 +516,14 @@ GuiComboBox::GuiComboBox(QWidget* parent, const svector& names) {
 
 GuiComboBox::GuiComboBox(GuiToolBar* parent, const svector& names) {
   common_init(parent->get_widget(),names);
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   parent->qtb->addWidget(qcb);
 #endif
 }
 
 
 void GuiComboBox::set_current_item(int index) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qcb->setCurrentIndex(index);
 #else
   qcb->setCurrentItem(index);
@@ -531,7 +531,7 @@ void GuiComboBox::set_current_item(int index) {
 }
 
 int GuiComboBox::get_current_item() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qcb->currentIndex();
 #else
   return qcb->currentItem();
@@ -549,7 +549,7 @@ GuiPainter::GuiPainter(QPixmap* qpm) {
   qpm_cache=qpm;
   qp=new QPainter(qpm);
   qp->setPen(_ARRAY_SELECTION_COLOR_);
-#ifndef QT_VERSION_4
+#ifndef QT_VERSION_POST3
   qp->setFont(QFont(_FONT_TYPE_,_FONT_SIZE_));
 #endif
 }
@@ -559,7 +559,7 @@ GuiPainter::~GuiPainter() {
 }
 
 void GuiPainter::moveTo(int x, int y) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   x_cache=x;
   y_cache=y;
 #else
@@ -568,7 +568,7 @@ void GuiPainter::moveTo(int x, int y) {
 }
 
 void GuiPainter::lineTo(int x, int y) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qp->drawLine(x_cache,y_cache,x,y);
   x_cache=x;
   y_cache=y;
@@ -578,7 +578,7 @@ void GuiPainter::lineTo(int x, int y) {
 }
 
 void GuiPainter::repaint(QLabel* dst) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
 //  qp->drawPixmap(0,0,*qpm_cache);
   bool active=qp->isActive();
   if(active) qp->end();
@@ -636,7 +636,7 @@ void GuiPainter::drawText( int x, int y, const QString& txt, const QColor& col)
 QRegion* GuiPainter::draw_region(const STD_list<QPoint>& plist) {
   QRegion* rgn=0;
   if(plist.size()<3) return rgn;
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QPolygon qpg(plist.size());
   unsigned int index=0;
   for(STD_list<QPoint>::const_iterator it=plist.begin(); it!=plist.end(); ++it) {
@@ -690,13 +690,13 @@ GuiApplication::GuiApplication(int argc, char *argv[]) {
 
   qa=new QApplication(argc4qt,argv4qt);
 
-#ifndef QT_VERSION_4
+#ifndef QT_VERSION_POST3
   qa->setFont(QFont(_FONT_TYPE_, _FONT_SIZE_));
 #endif
 
   // setting text color back to normal, even if noedit
   QPalette pal=qa->palette();
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   pal.setColor(QPalette::Disabled, QPalette::Foreground, pal.color (  QPalette::Active, QPalette::Foreground ) );
   pal.setColor(QPalette::Disabled, QPalette::Text,       pal.color (  QPalette::Active, QPalette::Text ) );
   qa->setPalette(pal);
@@ -711,7 +711,7 @@ GuiApplication::GuiApplication(int argc, char *argv[]) {
 
 
 int GuiApplication::start(QWidget* mainwidget) {
-#ifndef QT_VERSION_4
+#ifndef QT_VERSION_POST3
   qa->setMainWidget(mainwidget);
 #endif
 //  mainwidget->show();
@@ -757,7 +757,7 @@ GuiMainWindow::~GuiMainWindow() {
 void GuiMainWindow::show(QWidget* central_widget, bool show_toolbutton_text) {
   set_status_message("Ready ...", 2000); // necessary to show status bar in the first place
 
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(show_toolbutton_text) qmw->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
 #else
   qmw->setUsesTextLabel(show_toolbutton_text);
@@ -770,7 +770,7 @@ void GuiMainWindow::show(QWidget* central_widget, bool show_toolbutton_text) {
 
 void GuiMainWindow::set_caption(const char* text) {
   STD_string captext(text);
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qmw->setWindowTitle(captext.c_str());
 #else
   qmw->setCaption(captext.c_str());
@@ -781,7 +781,7 @@ void GuiMainWindow::set_status_message(const char* text, int timeout_ms) {
 
   if(statusText) statusText->setText(text);
   else {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
     qmw->statusBar()->showMessage(text,timeout_ms);
 #else
     if(timeout_ms) qmw->statusBar()->message(text);
@@ -797,7 +797,7 @@ void GuiMainWindow::set_status_xpm(const char** xpm) {
     statusIcon=new QLabel(qmw->statusBar());
     statusText=new QLabel(qmw->statusBar());
     statusText->setMinimumWidth(qmw->width()-qp.width());
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
     qmw->statusBar()->addPermanentWidget(statusIcon);
     qmw->statusBar()->addPermanentWidget(statusText);
 #else
@@ -813,7 +813,7 @@ QWidget* GuiMainWindow::get_widget() {return qmw;}
 
 
 void GuiMainWindow::insert_menu( const char* text, GuiPopupMenu* gpm) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   gpm->qm->setTitle(text);
   qmw->menuBar()->addMenu(gpm->qm);
 #else
@@ -822,7 +822,7 @@ void GuiMainWindow::insert_menu( const char* text, GuiPopupMenu* gpm) {
 }
 
 void GuiMainWindow::insert_menu_separator() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qmw->menuBar()->addSeparator();
 #else
   qmw->menuBar()->insertSeparator();
@@ -837,7 +837,7 @@ void GuiMainWindow::close() {
 ///////////////////////////////////////////////////
 
 GuiScroll::GuiScroll(QWidget* child, QWidget* parent) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qsa=new QScrollArea(parent);
   qsa->setWidget(child);
   qsa->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -851,7 +851,7 @@ GuiScroll::GuiScroll(QWidget* child, QWidget* parent) {
 }
 
 QWidget* GuiScroll::get_widget() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qsa;
 #else
   return qsv;
@@ -859,7 +859,7 @@ QWidget* GuiScroll::get_widget() {
 }
 
 GuiScroll::~GuiScroll() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   delete qsa;
 #else
   delete qsv;
@@ -872,7 +872,7 @@ class QDialogDerived : public QDialog {
 
  public:
   QDialogDerived(GuiDialog* user, QWidget *parent, const char* caption, bool modal) :
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QDialog(parent) {
     QDialog::setModal(modal);
     QDialog::setWindowTitle(caption);
@@ -936,7 +936,7 @@ GuiDialog::~GuiDialog() {
 /////////////////////////////////////////////////
 
 GuiProgressDialog::GuiProgressDialog(QWidget *parent, bool modal, int total_steps) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qpd=new QProgressDialog("", "Cancel", 0, total_steps, parent);
   qpd->setModal(modal);
 #else
@@ -948,7 +948,7 @@ GuiProgressDialog::GuiProgressDialog(QWidget *parent, bool modal, int total_step
 }
 
 void GuiProgressDialog::set_progress(int progr) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qpd->setValue(progr);
 #else
   qpd->setProgress(progr);
@@ -956,7 +956,7 @@ void GuiProgressDialog::set_progress(int progr) {
 }
 
 int GuiProgressDialog::get_progress() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qpd->value();
 #else
   return qpd->progress();
@@ -964,7 +964,7 @@ int GuiProgressDialog::get_progress() const {
 }
 
 void GuiProgressDialog::set_total_steps(int steps) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qpd->setMaximum(steps);
 #else
   qpd->setTotalSteps(steps);
@@ -974,7 +974,7 @@ void GuiProgressDialog::set_total_steps(int steps) {
 
 
 bool GuiProgressDialog::was_cancelled() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qpd->wasCanceled();
 #else
   return qpd->wasCancelled();
@@ -1007,9 +1007,9 @@ GuiProgressDialog::~GuiProgressDialog() {
 GuiImage::GuiImage(unsigned char* data, int width, int height, bool colormap) {
   Log<OdinQt> odinlog("GuiImage","GuiImage");
   ODINLOG(odinlog,normalDebug) << "width/height/colormap=" << width << "/" << height << "/" << colormap << STD_endl;
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qi=new QImage( data, width, height, QImage::Format_Indexed8);
-  qi->setNumColors (256);
+  qi->setColorCount (256);
 #else
   qi=new QImage( data, width, height, 8, 0, 256, QImage::IgnoreEndian);
 #endif
@@ -1025,7 +1025,7 @@ GuiImage::GuiImage(unsigned char* data, int width, int height, bool colormap) {
 }
 
 QPixmap* GuiImage::create_pixmap() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return new QPixmap(QPixmap::fromImage(*qi));
 #else
   QPixmap* qpm=new QPixmap();
@@ -1042,7 +1042,7 @@ GuiImage::~GuiImage() {
 
 
 GuiListView::GuiListView(QWidget *parent, const svector& column_labels, int first_column_width, int min_height, GuiListViewCallback* callback, bool tree) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
 
   QStringList qsl;
   for(unsigned int i=0; i<column_labels.size(); i++) {
@@ -1097,7 +1097,7 @@ GuiListView::GuiListView(QWidget *parent, const svector& column_labels, int firs
 }
 
 QWidget* GuiListView::get_widget() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(qtrw) return qtrw;
   if(qtw)  return qtw;
   return 0;
@@ -1109,7 +1109,7 @@ QWidget* GuiListView::get_widget() {
 
 GuiListView::~GuiListView() {
   delete sd;
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(qtrw) delete qtrw;
   if(qtw)  delete qtw;
 #else
@@ -1119,7 +1119,7 @@ GuiListView::~GuiListView() {
 
 /////////////////////////////////////////////////
 
-#ifndef QT_VERSION_4
+#ifndef QT_VERSION_POST3
 void create_qstring_list(STD_vector<QString>& label, const svector& column_entries) {
   int ncols=column_entries.size();
   if(ncols>8) ncols=8;
@@ -1143,7 +1143,7 @@ void GuiListItem::common_init() {
 GuiListItem::GuiListItem(GuiListView *parent, const svector& column_entries, bool checkable, bool initstate) {
   Log<OdinQt> odinlog("GuiListItem","GuiListItem");
   common_init();
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   int ncols=column_entries.size();
   if(!ncols) return;
 
@@ -1201,7 +1201,7 @@ GuiListItem::GuiListItem(GuiListView *parent, const svector& column_entries, boo
 GuiListItem::GuiListItem(GuiListItem* parent, GuiListItem* after, const svector& column_entries) {
   Log<OdinQt> odinlog("GuiListItem","GuiListItem");
   common_init();
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QTreeWidgetItem* parent_qtrwi=0;
   if(parent) parent_qtrwi=parent->qtrwi;
   QTreeWidgetItem* after_qtrwi=0;
@@ -1237,7 +1237,7 @@ GuiListItem::GuiListItem(GuiListItem* parent, GuiListItem* after, const svector&
 
 
 bool GuiListItem::is_checked() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(qtwi) return ((qtwi[0].checkState())==Qt::Checked);
 #else
   if(qcli) return qcli->isOn();
@@ -1246,7 +1246,7 @@ bool GuiListItem::is_checked() const {
 }
 
 const char* GuiListItem::get_text() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(qtwi) return c_str(qtwi[0].text());
 #else
   if(qcli) return c_str(qcli->text());
@@ -1257,7 +1257,7 @@ const char* GuiListItem::get_text() const {
 
 
 GuiListItem::~GuiListItem() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   if(qtwi) delete[] qtwi;
   if(qtrwi) delete qtrwi;
 #else
@@ -1268,7 +1268,7 @@ GuiListItem::~GuiListItem() {
 
 
 void GuiListItem::init_static() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   tablemap=new STD_map<QTableWidgetItem*,GuiListItem*>;
 #else
   listmap=new STD_map<QListViewItem*,GuiListItem*>;
@@ -1277,7 +1277,7 @@ void GuiListItem::init_static() {
 
 
 void GuiListItem::destroy_static() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   delete tablemap;
 #else
   delete listmap;
@@ -1293,7 +1293,7 @@ EMPTY_TEMPL_LIST bool StaticHandler<GuiListItem>::staticdone=false;
 
 
 GuiProgressBar::GuiProgressBar(QWidget *parent, int total_steps) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qpb=new QProgressBar(parent);
   qpb->setMinimum(0);
   qpb->setMaximum(total_steps);
@@ -1309,7 +1309,7 @@ GuiProgressBar::~GuiProgressBar() {
 
 
 void GuiProgressBar::set_progress(int progr) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qpb->setValue(progr);
 #else
   qpb->setProgress(progr);
@@ -1338,7 +1338,7 @@ GuiScrollBar::~GuiScrollBar() {
 }
 
 void GuiScrollBar::set_values(int min, int max, int linestep, int pagestep, int value) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qsb->setMinimum(min);
   qsb->setMaximum(max);
   qsb->setSingleStep(linestep);
@@ -1361,7 +1361,7 @@ QScrollBar* GuiScrollBar::get_widget() {
 
 GuiToolBar::GuiToolBar(GuiMainWindow* parent, const char* label) {
   qtb=new QToolBar(label, parent->qmw);
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   parent->qmw->addToolBar(qtb);
 #endif
 }
@@ -1384,7 +1384,7 @@ void GuiToolBar::add_separator() {
 
 
 GuiToolButton::GuiToolButton(GuiToolBar* parent, const char** xpm, const char* label, QObject* receiver, const char* member, bool checkable, bool initstate ) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qtb=new QToolButton(parent->qtb);
   if(xpm) qtb->setIcon(QPixmap(xpm));
   qtb->setCheckable(checkable);
@@ -1404,7 +1404,7 @@ GuiToolButton::~GuiToolButton() {
   Log<OdinQt> odinlog("GuiToolButton","~GuiToolButton");
   ODINLOG(odinlog,normalDebug) << "Deleting sd" << STD_endl; 
   delete sd;
-#ifndef QT_VERSION_4
+#ifndef QT_VERSION_POST3
   ODINLOG(odinlog,normalDebug) << "Deleting qtb" << STD_endl; 
   delete qtb; //  will be done by the parent toolbar on Qt4
 #endif
@@ -1412,7 +1412,7 @@ GuiToolButton::~GuiToolButton() {
 
 
 bool GuiToolButton::is_on() const {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   return qtb->isChecked();
 #else
   return qtb->isOn();
@@ -1420,7 +1420,7 @@ bool GuiToolButton::is_on() const {
 }
 
 void GuiToolButton::set_on(bool flag) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qtb->setChecked(flag);
 #else
   qtb->setOn(flag);
@@ -1432,7 +1432,7 @@ void GuiToolButton::set_enabled(bool flag) {
 }
 
 void GuiToolButton::set_label(const char* text) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qtb->setText(text);
 #else
   qtb->setTextLabel(text);
@@ -1452,7 +1452,7 @@ GuiPrinter::GuiPrinter() {
 }
 
 bool GuiPrinter::setup(QWidget* parent) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QPrintDialog* qpd=new QPrintDialog(qp,parent);
   return bool(qpd->exec());
 #else
@@ -1478,7 +1478,7 @@ GuiTextView::GuiTextView(QWidget* parent, int minwidth, int minheight) {
   qte->setReadOnly(true);
   qte->setMinimumSize(minwidth, minheight);
 
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qte->document()->setMaximumBlockCount(TEXTVIEW_MAXLINES); // only available for Qt 4.2 or later versions
   qte->setLineWrapMode(QTextEdit::NoWrap);
 #else
@@ -1497,7 +1497,7 @@ GuiTextView::~GuiTextView() {
 
 
 void GuiTextView::set_text(const char* txt) {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   qte->setPlainText(txt);
 #else
   qte->setText(txt);
@@ -1511,7 +1511,7 @@ void GuiTextView::append_text(const char* txt) {
 }
 
 void GuiTextView::scroll_end() {
-#ifdef QT_VERSION_4
+#ifdef QT_VERSION_POST3
   QTextCursor qtc(qte->textCursor());
   qtc.movePosition(QTextCursor::End);
   qtc.movePosition(QTextCursor::StartOfLine);
