@@ -2,8 +2,8 @@
                           odinqt.h  -  description
                              -------------------
     begin                : Sun Aug 27 2000
-    copyright            : (C) 2000 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
