@@ -2,48 +2,33 @@
 
 #include "plot.h"
 
-#ifdef HAVE_QWT_QT4_QWT_GLOBAL_H  // For Debian
 
-#include <qwt-qt4/qwt_plot.h>
-#include <qwt-qt4/qwt_plot_canvas.h>
-#include <qwt-qt4/qwt_plot_zoomer.h>
-#include <qwt-qt4/qwt_plot_layout.h>
-#include <qwt-qt4/qwt_wheel.h>
-#include <qwt-qt4/qwt_double_rect.h>
+#include <qwt_plot.h>
+#include <qwt_plot_canvas.h>
+#include <qwt_plot_zoomer.h>
+#include <qwt_plot_layout.h>
+#include <qwt_wheel.h>
+#if QWT_VERSION < 0x060000
+#include <qwt_double_rect.h>
+#else
+#include <qwt_picker_machine.h>
+#include <qwt_plot_renderer.h>
+#endif
 
 #if QWT_VERSION > 0x04FFFF
-#include <qwt-qt4/qwt_plot_curve.h>
-#include <qwt-qt4/qwt_plot_marker.h>
-#include <qwt-qt4/qwt_plot_grid.h>
-#include <qwt-qt4/qwt_symbol.h>
-#include <qwt-qt4/qwt_scale_div.h>
-#include <qwt-qt4/qwt_scale_draw.h>
+#include <qwt_plot_curve.h>
+#include <qwt_plot_marker.h>
+#include <qwt_plot_grid.h>
+#include <qwt_symbol.h>
+#include <qwt_scale_div.h>
+#include <qwt_scale_draw.h>
 #else
-#include <qwt-qt4/qwt_scldraw.h>
+#include <qwt_scldraw.h>
 #endif
 
-#else
 
-#include <qwt/qwt_plot.h>
-#include <qwt/qwt_plot_canvas.h>
-#include <qwt/qwt_plot_zoomer.h>
-#include <qwt/qwt_plot_layout.h>
-#include <qwt/qwt_wheel.h>
-#include <qwt/qwt_double_rect.h>
-
-#if QWT_VERSION > 0x04FFFF
-#include <qwt/qwt_plot_curve.h>
-#include <qwt/qwt_plot_marker.h>
-#include <qwt/qwt_plot_grid.h>
-#include <qwt/qwt_symbol.h>
-#include <qwt/qwt_scale_div.h>
-#include <qwt/qwt_scale_draw.h>
-#else
-#include <qwt/qwt_scldraw.h>
-#endif
-
-#endif
 
+#if QWT_VERSION < 0x060000
 
 class GuiPlotPrintFilter : public QwtPlotPrintFilter {
 
@@ -88,7 +73,7 @@ class GuiPlotPrintFilter : public QwtPlotPrintFilter {
 
 };
 
-
+#endif // QWT_VERSION < 0x060000
 
 
 
@@ -179,11 +164,14 @@ GuiPlot::GuiPlot(QWidget *parent, bool fixed_size, int width, int height) {
   set_x_axis_label(0);
   set_y_axis_label(0,0);
 
+/*
+// still necessary?
 #if QWT_VERSION < 0x04FFFF
   qwtplotter->setAxisTitleFont(QwtPlot::xBottom,QFont(_FONT_TYPE_, _FONT_SIZE_));
   qwtplotter->setAxisTitleFont(QwtPlot::yLeft,  QFont(_FONT_TYPE_, _FONT_SIZE_));
   qwtplotter->setAxisTitleFont(QwtPlot::yRight, QFont(_FONT_TYPE_, _FONT_SIZE_));
 #endif
+*/
 
   qwtplotter->enableAxis(QwtPlot::xBottom,true);
 
@@ -195,27 +183,54 @@ GuiPlot::GuiPlot(QWidget *parent, bool fixed_size, int width, int height) {
   qwtplotter->setAxisScaleDraw(QwtPlot::xBottom, new GuiScaleDraw());
 
 
+#if QWT_VERSION < 0x060000
   qwtplotter->setCanvasBackground(_ARRAY_BACKGROUND_COLOR_);
+#else
+  qwtplotter->setCanvasBackground(QBrush(QColor(_ARRAY_BACKGROUND_COLOR_)));
+#endif
 
 
 #if QWT_VERSION > 0x04FFFF
   plotgrid=new QwtPlotGrid();
-  plotgrid->attach(qwtplotter);
   ODINLOG(odinlog,normalDebug) << "plotgrid=" << plotgrid << STD_endl;
 #endif
+  QPen gridpen(QColor(_ARRAY_GRID_COLOR_).dark(_ARRAY_GRID_DARK_FACTOR_));
+#if QWT_VERSION > 0x04FFFF
+  ODINLOG(odinlog,normalDebug) << "plotgrid=" << plotgrid << STD_endl;
+  plotgrid->setPen(gridpen);
 
+#if QWT_VERSION < 0x060100
+  plotgrid->setMajPen(gridpen);
+  plotgrid->setMinPen(gridpen);
+#else
+  plotgrid->setMajorPen(gridpen);
+  plotgrid->setMinorPen(gridpen);
+#endif
+
+#else
+  qwtplotter->setGridPen(gridpen);
+  qwtplotter->setGridMajPen(gridpen);
+  qwtplotter->setGridMinPen(gridpen);
+#endif
   enable_grid(true);
+#if QWT_VERSION > 0x04FFFF
+  plotgrid->attach(qwtplotter);
+#endif
+
 
 #if QWT_VERSION < 0x04FFFF
   qwtplotter->enableLegend(false);
   qwtplotter->enableOutline(false);
 #endif
 
-  canvas_framewidth=qwtplotter->canvas()->lineWidth();
+  QwtPlotCanvas* canv=(QwtPlotCanvas*)qwtplotter->canvas(); // cast required for qwt 6.1 (and higher?)
 
-  picker=new GuiPlotPicker(qwtplotter->canvas(),this);
+  canvas_framewidth=canv->lineWidth();
+
+  picker=new GuiPlotPicker(canv,this);
   picker->setRubberBandPen(QColor(_ARRAY_SELECTION_COLOR_));
   set_rect_outline_style(); // do this after picker was initialized
+
 }
 
 
@@ -235,10 +250,12 @@ void GuiPlot::set_axis_label(int axisId, const char* label, bool omit, int align
   } else {
 #if QWT_VERSION > 0x04FFFF
     QwtText txt(label);
+    txt.setFont(QFont(_FONT_TYPE_, _FONT_SIZE_));
     txt.setRenderFlags(alignment);
     qwtplotter->setAxisTitle(axisId,txt);
 #else
     qwtplotter->setAxisTitle(axisId,label);
+    qwtplotter->setAxisTitleFont(axisId,QFont(_FONT_TYPE_, _FONT_SIZE_));
     qwtplotter->setAxisTitleAlignment(axisId,alignment);
 #endif
   }
@@ -273,7 +290,11 @@ long GuiPlot::insert_curve(bool use_right_y_axis, bool draw_spikes, bool baselin
 
 #if QWT_VERSION > 0x04FFFF
   QwtPlotCurve* curve=new QwtPlotCurve();
+#if QWT_VERSION < 0x060000
   curve->setAxis(QwtPlot::xBottom, yaxis);
+#else
+  curve->setAxes(QwtPlot::xBottom, yaxis);
+#endif
   curve->setPen(curvepen);
   curve->attach(qwtplotter);
   result=curve_map.size()+1;
@@ -386,19 +407,30 @@ void GuiPlot::set_curve_data(long curveid, const double* x, const double* y, int
   if(symbol) {
     symbstyle=QwtSymbol::Ellipse;
   }
-  QwtSymbol symb(symbstyle,QBrush(),QColor(_ARRAY_FOREGROUND_COLOR1_),QSize(PLOT_SYMBOLS_SIZE,PLOT_SYMBOLS_SIZE));
 
-  if(n) ODINLOG(odinlog,normalDebug) << "y[" << n/2 << "]=" << y[n/2] << STD_endl;
+  QwtSymbol* symb=new QwtSymbol(symbstyle,QBrush(),QColor(_ARRAY_FOREGROUND_COLOR1_),QSize(PLOT_SYMBOLS_SIZE,PLOT_SYMBOLS_SIZE));
+
+  if(n) {
+    ODINLOG(odinlog,normalDebug) << "y[" << n/2 << "]=" << y[n/2] << STD_endl;
+  }
 #if QWT_VERSION > 0x04FFFF
   QwtPlotCurve* qpc=get_curve(curveid);
   if(qpc) {
-    qpc->setSymbol(symb);
+#if QWT_VERSION < 0x060000
+    qpc->setSymbol(*symb);
     qpc->setRawData(x, y, n);
+#else
+    qpc->setSymbol(symb);
+    qpc->setRawSamples(x, y, n);
+#endif
   }
 #else
-  qwtplotter->setCurveSymbol(curveid,symb);
+  qwtplotter->setCurveSymbol(curveid,*symb);
   qwtplotter->setCurveRawData(curveid, x, y, n);
 #endif
+#if QWT_VERSION < 0x060000
+  delete symb;  // qwt6 deletes symbol itself
+#endif
 }
 
 
@@ -424,8 +456,15 @@ void GuiPlot::autoscale_y(double& maxBound) {
 
 #if QWT_VERSION > 0x04FFFF
 #if QWT_VERSION > 0x0501FF
+
+#if QWT_VERSION < 0x060100
    double new_lbound=qwtplotter->axisScaleDiv(QwtPlot::yLeft)->lowerBound();
    double new_hbound=qwtplotter->axisScaleDiv(QwtPlot::yLeft)->upperBound();
+#else
+   double new_lbound=qwtplotter->axisScaleDiv(QwtPlot::yLeft).lowerBound();
+   double new_hbound=qwtplotter->axisScaleDiv(QwtPlot::yLeft).upperBound();
+#endif
+
 #else
    double new_lbound=qwtplotter->axisScaleDiv(QwtPlot::yLeft)->lBound();
    double new_hbound=qwtplotter->axisScaleDiv(QwtPlot::yLeft)->hBound();
@@ -464,7 +503,11 @@ void GuiPlot::clear() {
   ODINLOG(odinlog,normalDebug) << "Removing markers" << STD_endl;
   remove_markers();
 #endif
+#if QWT_VERSION < 0x060000
   qwtplotter->clear();  // do this after detaching curves
+#else
+//  qwtplotter->detachItems(); // does not work with QwtPlotGrid
+#endif
 }
 
 void GuiPlot::remove_markers() {
@@ -545,12 +588,20 @@ void GuiPlot::set_curve_pen(long id, const char* color, int width) {
 }
 
 void GuiPlot::set_rect_outline_style() {
+#if QWT_VERSION < 0x060000
   picker->setSelectionFlags(QwtPicker::RectSelection | QwtPicker::CornerToCorner | QwtPicker::DragSelection);
+#else
+  picker->setStateMachine(new QwtPickerDragRectMachine);
+#endif
   picker->setRubberBand(QwtPicker::RectRubberBand);
 }
 
 void GuiPlot::set_line_outline_style(bool horizontal) {
+#if QWT_VERSION < 0x060000
   picker->setSelectionFlags(QwtPicker::PointSelection | QwtPicker::DragSelection);
+#else
+  picker->setStateMachine(new QwtPickerDragPointMachine);
+#endif
   if(horizontal) picker->setRubberBand(QwtPicker::HLineRubberBand);
   else           picker->setRubberBand(QwtPicker::VLineRubberBand);
 }
@@ -563,21 +614,6 @@ void GuiPlot::enable_axes(bool flag) {
 
 void GuiPlot::enable_grid(bool flag) {
   Log<OdinQt> odinlog("GuiPlot","enable_grid");
-
-  if(flag) {
-    QPen gridpen(QColor(_ARRAY_GRID_COLOR_).dark(_ARRAY_GRID_DARK_FACTOR_));
-#if QWT_VERSION > 0x04FFFF
-    ODINLOG(odinlog,normalDebug) << "plotgrid=" << plotgrid << STD_endl;
-    plotgrid->setPen(gridpen);
-    plotgrid->setMajPen(gridpen);
-    plotgrid->setMinPen(gridpen);
-#else
-    qwtplotter->setGridPen(gridpen);
-    qwtplotter->setGridMajPen(gridpen);
-    qwtplotter->setGridMinPen(gridpen);
-#endif
-  }
-
 #if QWT_VERSION > 0x04FFFF
   plotgrid->enableX(flag);
   plotgrid->enableY(flag);
@@ -587,9 +623,16 @@ void GuiPlot::enable_grid(bool flag) {
 #endif
 }
 
+
 void GuiPlot::print(QPainter* painter, const QRect& rect) const {
+  Log<OdinQt> odinlog("GuiPlot","print");
+#if QWT_VERSION < 0x060000
   GuiPlotPrintFilter pfilter(baseline_id_cache);
   qwtplotter->print(painter,rect,pfilter);
+#else
+  QwtPlotRenderer renderer;
+  renderer.render(qwtplotter, painter, QRectF(rect));
+#endif
 }
 
 
@@ -650,7 +693,8 @@ void GuiWheel::set_range(double min, double max) {
 }
 
 void GuiWheel::set_value(double newval) {
-  wheel->fitValue(newval);
+//  wheel->fitValue(newval); // ?
+  wheel->setValue(newval);
 }
 
 
