@@ -1,12 +1,90 @@
 #include "blade.h"
 #include "data.h"
 #include "controller.h"
+#include "bladegrid.h"
 
+#include <odindata/correlation.h>
 #include <odindata/gridding.h>
 #include <odindata/fitting.h>
 
+void RecoBladeGrid::init() {
+  fft = false;
+  fft.set_description("Perform partial FFT into image space before feeding data into rest of the pipeline");
+  append_arg(fft,"fft");
 
+  filtermask.set_funcpars("Triangle");
+  filtermask.set_description("Filter function for k-space center. NoFilter = whole blade (not only center)");
+  append_arg(filtermask,"filtermask");
+  
+}
 
+bool RecoBladeGrid::process(RecoData& rd, RecoController& controller) {
+  Log<Reco> odinlog(c_label(),"process");
+
+  Range all=Range::all();
+
+  ComplexData<4>& data=rd.data(Rank<4>());
+
+  TinyVector<int,4> inshape=data.shape();
+  TinyVector<int,3> inshape3d(inshape(1), inshape(2), inshape(3));
+  ODINLOG(odinlog,normalDebug) << "inshape3d=" << inshape3d << STD_endl;
+
+  float os_factor=rd.coord().overSamplingFactor;
+  ODINLOG(odinlog,normalDebug) << "os_factor=" << os_factor << STD_endl;
+  if(os_factor<1.0) {
+    ODINLOG(odinlog,errorLog) << "os_factor(" << os_factor << ") < 1.0" << STD_endl;
+    return false;
+  }
+
+  dvector angles=controller.dim_values(cycle);
+  ODINLOG(odinlog,normalDebug) << "angles=" << angles.printbody() << STD_endl;
+
+  TinyVector<float,3> fov; fov=1;
+  // fov(0)=controller.protocol().geometry.get_FOV(sliceDirection);
+  fov(1)=controller.protocol().geometry.get_FOV(phaseDirection);
+  fov(2)=controller.protocol().geometry.get_FOV(readDirection);
+  ODINLOG(odinlog,normalDebug) << "fov=" << fov << STD_endl;
+
+  // Prepare Input Data
+  if(rd.interpolated) measlines.update(*(rd.interpolated)); // take previously interpolated coords into account
+  ivector indexvec3d=measlines.get_indices(rd.coord()); // Use only planes actually measured
+
+  ComplexData<4> infixed(inshape(0),indexvec3d.size(),inshape(2),inshape(3));
+
+  for(int i = 0; i < indexvec3d.size(); i++) {
+
+    int iphase3d = indexvec3d[i];
+    infixed(all,i,all,all) = data(all,iphase3d,all,all);
+  }
+
+  // Grid blades
+  BladeGrid bg;
+  bg.init(inshape3d,fov,controller.image_size(),os_factor,filtermask);
+  ComplexData<4> bladesgrid_kspace = bg(infixed,angles);
+
+  // perform FFT if parameter is set
+  if (fft) {
+    TinyVector<int,4> fftdims(false,false,true,true);
+    bladesgrid_kspace.partial_fft(fftdims,true);
+  }
+
+  data.resize(bladesgrid_kspace.shape());
+  data = bladesgrid_kspace;
+
+  return execute_next_step(rd,controller);
+}
+
+///////////////////////////////////////////////////////////////////////////
+
+bool RecoBladeGrid::query(RecoQueryContext& context) {
+  Log<Reco> odinlog(c_label(),"query");
+  if(context.mode==RecoQueryContext::prep) {
+    if(!measlines.init(context.coord, context.controller)) return false;
+  }
+  return RecoStep::query(context);
+}
+
+////////////////////////////////////////////////////////////////////////////////////
 
 bool RecoCycleRot::process(RecoData& rd, RecoController& controller) {
   Log<Reco> odinlog(c_label(),"process");
@@ -162,7 +240,6 @@ bool RecoBladeCorr::process(RecoData& rd, RecoController& controller) {
   }
 
   bool isNoFilter =  (phasecorr_filter.get_function_name() == "NoFilter");
-  // Data<float,2> koffset(nblades,2);
 
   ComplexData<3> blade_pad(diashape);
   blade_pad=STD_complex(0.0);
@@ -196,7 +273,7 @@ bool RecoBladeCorr::process(RecoData& rd, RecoController& controller) {
         filtermask(all,j,i)=phasecorr_filter.calculate(relradius);
       }
     }
-    // filtermask.autowrite("filtermask-" + phasecorr_filter.get_function_name() + ".jdx");
+    // filtermask.autowrite("filtermask-" + phasecorr_filter.get_function_name() + ".nii");
 
     ComplexData<3> lowpass_kspace(diashape);
 
@@ -230,17 +307,28 @@ bool RecoBladeCorr::process(RecoData& rd, RecoController& controller) {
 ///////////////////////////////////////////////////////////////////////////
 
 void RecoBladeComb::init() {
-
   keyhole=false;
   keyhole.set_description("Keyhole combination of blades");
   append_arg(keyhole,"keyhole");
 
+  corrweight=false;
+  corrweight.set_cmdline_option("bcw").set_description("Correlation weighting of all blades against the mean of all blades (in image space)");
+  append_arg(corrweight,"corrweight");
+
   keyhole_filter.set_funcpars("CosSq");
-  keyhole_filter.set_cmdline_option("kf").set_description("Blade-keyhole filter function (and its arguments)");
+  keyhole_filter.set_cmdline_option("bkf").set_description("Blade-keyhole filter function (and its arguments)");
   append_arg(keyhole_filter,"keyhole_filter");
 
+  kspaceweight_filter.set_funcpars("Triangle");
+  kspaceweight_filter.set_cmdline_option("bwf").set_description("Window/Filter function for kspace weighting of each blade");
+  append_arg(kspaceweight_filter,"kspaceweight_filter");
+
+  kspaceweight_width = 1;
+  kspaceweight_width.set_cmdline_option("bww").set_description("Window/Filter width for kspace weighting of each blade");
+  append_arg(kspaceweight_width,"kspaceweight_width");
+
   transition=0.2;
-  transition.set_cmdline_option("kt").set_description("Blade-keyhole transition width (fraction of oversampled k-space center)");
+  transition.set_cmdline_option("bkt").set_description("Blade-keyhole transition width (fraction of oversampled k-space center)");
   append_arg(transition,"transition");
 }
 
@@ -257,10 +345,83 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
   TinyVector<int,3> inshape3d(inshape(1), inshape(2), inshape(3));
 
   int nblades=inshape(0);
-  // Data<float,2> koffset(nblades,2);
+  dvector angles=controller.dim_values(cycle);
+  ODINLOG(odinlog,normalDebug) << "angles=" << angles.printbody() << STD_endl;
+
+  TinyVector<float,3> fov; fov=1;
+//  fov(0)=controller.protocol().geometry.get_FOV(sliceDirection); // No regridding in line3d direction
+  fov(1)=controller.protocol().geometry.get_FOV(phaseDirection);
+  fov(2)=controller.protocol().geometry.get_FOV(readDirection);
+  ODINLOG(odinlog,normalDebug) << "fov=" << fov << STD_endl;
+
+  Data<float,1> corrweights(nblades);
+
+  // correlation weighting
+  if (corrweight) {
+
+    float os_factor=rd.coord().overSamplingFactor;
+    ODINLOG(odinlog,normalDebug) << "os_factor=" << os_factor << STD_endl;
+    if(os_factor<1.0) {
+      ODINLOG(odinlog,errorLog) << "os_factor(" << os_factor << ") < 1.0" << STD_endl;
+      return false;
+    }
+
+    // Filter for k-space center
+    JDXfilter kernel_center;
+    kernel_center.set_funcpars("Triangle");
+
+    // Prepare Input Data
+    if(rd.interpolated) measlines.update(*(rd.interpolated)); // take previously interpolated coords into account
+    ivector indexvec3d=measlines.get_indices(rd.coord()); // Use only planes actually measured
+
+    ComplexData<4> infixed(inshape(0),indexvec3d.size(),inshape(2),inshape(3));
+
+    for(int i = 0; i < indexvec3d.size(); i++) {
+
+      int iphase3d = indexvec3d[i];
+      infixed(all,i,all,all) = indata(all,iphase3d,all,all);
+    }
+
+    // Grid blades
+    BladeGrid bg;
+    bg.init(inshape3d,fov,controller.image_size(),os_factor,kernel_center);
+    ComplexData<4> bladesgrid_kspace = bg(infixed,angles);
+
+    // FFT
+    TinyVector<int,4> gridshape(bladesgrid_kspace.shape());
+    Data<float,4> bladesgrid(gridshape(0),gridshape(1),gridshape(2),gridshape(3));
+    TinyVector<bool,4> fftdims(false,false,true,true);
+    bladesgrid_kspace.partial_fft(fftdims,true);
+    bladesgrid = cabs(bladesgrid_kspace);
+    //bladesgrid.autowrite("grid-blades.nii");
+
+    // Calculate correlation coefficient for all blades and planes
+    corrweights = 0.0;
+    for (int iphase3d = 0; iphase3d < gridshape(1); iphase3d++) {
+
+      // Merge all blades
+      Data<float, 2> bladesmean(gridshape(2),gridshape(3));
+      bladesmean = 0.0;
+      for (int iblade = 0; iblade < nblades; iblade++) {
+        bladesmean += bladesgrid(iblade,iphase3d,all,all);
+      }
+      bladesmean /= nblades;
+      //bladesmean.autowrite("grid-blades-mean.nii");
+
+      // Calculate correlation coefficient for all blades
+      for (int iblade = 0; iblade < nblades; iblade++) {
+        correlationResult cr = correlation(bladesmean,bladesgrid(iblade,iphase3d,all,all));
+        corrweights(iblade) += cr.r;
+      }
+    }
+    corrweights /= gridshape(1);
+    ODINLOG(odinlog,normalDebug) << "corrweights=" << corrweights << STD_endl;
+  } else corrweights = 1.0;
+
 
   int ikey=0; // the index for the blade filling the center of k-space in keyhole mode
   if(keyhole) {
+
     int irep=rd.coord().index[repetition];
     ikey=(irep+nblades/2)%nblades;
     ODINLOG(odinlog,normalDebug) << "ikey(" << irep << ")=" << ikey << STD_endl;
@@ -275,22 +436,11 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
 
     int npts=inshape(0)*inshape(2)*inshape(3); // cycles x 2D plane
 
-    dvector angles=controller.dim_values(cycle);
-    ODINLOG(odinlog,normalDebug) << "angles=" << angles.printbody() << STD_endl;
-
     trajptr->resize(1,npts);
 
     TinyVector<float,3> kspace_center=inshape3d/2;  // correct index of center: odd N -> N/2 / even N -> (N-1)/2
     ODINLOG(odinlog,normalDebug) << "kspace_center=" << kspace_center << STD_endl;
 
-
-    TinyVector<float,3> fov; fov=1;
-//  fov(0)=controller.protocol().geometry.get_FOV(sliceDirection); // No regridding in line3d direction
-    fov(1)=controller.protocol().geometry.get_FOV(phaseDirection);
-    fov(2)=controller.protocol().geometry.get_FOV(readDirection);
-    ODINLOG(odinlog,normalDebug) << "fov=" << fov << STD_endl;
-
-
     TinyVector<float,3> kmax=inshape3d*2.0*PII/fov;
     kmax(2)/=rd.coord().overSamplingFactor;
 
@@ -326,18 +476,15 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
           kcoord_rot(2)=si*kcoord_shift(1)+co*kcoord_shift(2);
           (*trajptr)(0,itraj).coord=kcoord_rot;
 
-          float weight=1.0;
+          float weight = corrweights(iblade);
 
-          // Triangular Window
           float kcoord_temp;
           if (kmax(1) > kmax(2)) kcoord_temp = kcoord(2); // select the smaller(=y) coordinate
-           else kcoord_temp = kcoord(1);
-          float transition_width = kcent_radius; // width of the transition window at the borders of the blade
-          float dist = kcent_radius - abs(kcoord_temp); // distance from the border
-          if (dist <= 0) // outside of the blade
+            else kcoord_temp = kcoord(1);
+          float y = secureDivision(abs(kcoord_temp),kcent_radius);
+          if (y > 1) // ouside of the blade
             weight = 0.0;
-          else if (dist < transition_width) // inside the transition window
-            weight = secureDivision(dist,transition_width);
+          else weight *= kspaceweight_filter.calculate(kspaceweight_width * y);
 
           if(keyhole && iblade!=ikey) {
             float relradius=secureDivision(norm(kcoord_rot(1),kcoord_rot(2)),kcent_radius);
@@ -346,6 +493,7 @@ bool RecoBladeComb::process(RecoData& rd, RecoController& controller) {
             if(r>=0.0 && r<=1.0) weight*=keyhole_filter.calculate(r);
             if(r>1.0) weight=0.0;
           }
+
           (*trajptr)(0,itraj).weight=weight;
           itraj++;
         }
