@@ -2,8 +2,8 @@
                           channel.h  -  description
                              -------------------
     begin                : Sat Dec 30 2006
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
