@@ -4,7 +4,6 @@
 #include "reader.h"
 #include "measindex.h"
 #include "fieldmap.h" // for posted_fmap_str
-#include "driftcorr.h" // for posted_drift_str
 
 
 
@@ -52,6 +51,10 @@ RecoController::RecoController(JcampDxBlock& parblock) : input(0), pipeline(0),
   dumpKspace.set_cmdline_option("ks").set_description("Store k-space data");
   parblock.append(dumpKspace);
 
+  dumpGrappaTemplate=false;
+  dumpGrappaTemplate.set_cmdline_option("gt").set_description("Store GRAPPA template images");
+  parblock.append(dumpGrappaTemplate);
+
   disableHomodyne=false;
   disableHomodyne.set_cmdline_option("dh").set_description("Disable homodyne reconstruction");
   parblock.append(disableHomodyne);
@@ -60,6 +63,10 @@ RecoController::RecoController(JcampDxBlock& parblock) : input(0), pipeline(0),
   disableMultiFreq.set_cmdline_option("dm").set_description("Disable fieldmap-based multi-frequency reconstruction");
   parblock.append(disableMultiFreq);
 
+  disableDriftCorr=false;
+  disableDriftCorr.set_cmdline_option("dd").set_description("Disable field-drift correction");
+  parblock.append(disableDriftCorr);
+
   disableSliceTime=false;
   disableSliceTime.set_cmdline_option("ds").set_description("Disable slice-time correction");
   parblock.append(disableSliceTime);
@@ -92,13 +99,16 @@ RecoController::RecoController(JcampDxBlock& parblock) : input(0), pipeline(0),
   fieldmapFile.set_cmdline_option("fm").set_description("Load fieldmap data from this file");
   parblock.append(fieldmapFile);
 
-  driftcalcFile="";
-  driftcalcFile.set_cmdline_option("dcw").set_description("Calculate and store field drift to file with this prefix");
-  parblock.append(driftcalcFile);
-
+/*
   driftcorrFile="";
   driftcorrFile.set_cmdline_option("dcr").set_description("Load field drift from this file");
   parblock.append(driftcorrFile);
+*/
+
+  driftcorrSel="";
+  driftcorrSel.set_cmdline_option("dcs").set_description("Index selection string in recipe used for drift correction (space separated list of 'dim=selection', e.g. te=2)");
+  parblock.append(driftcorrSel);
+
 
   factory=new RecoStepFactory(&parblock);
 }
@@ -159,7 +169,10 @@ bool RecoController::inquire_data(const STD_string& label, RecoData& data) {
 
   ODINLOG(odinlog,normalDebug) << "Requested " << label << "(" << data.coord().print() << ")" << STD_endl;
 
-  if(blackboard.inquire(label,data)) return true; // 1st shot without feeding pipeline or signalling waiting state
+  if(blackboard.inquire(label,data)) {
+    ODINLOG(odinlog,normalDebug) << "Returning " << label << "(" << data.coord().print() << ")" << STD_endl;
+    return true; // 1st shot without feeding pipeline or signalling waiting state
+  }
   ODINLOG(odinlog,normalDebug) <<  label << "(" << data.coord().print() << ") not ready" << STD_endl;
 
   int depth=thread_depth[Thread::self()];
@@ -168,7 +181,10 @@ bool RecoController::inquire_data(const STD_string& label, RecoData& data) {
     ODINLOG(odinlog,normalDebug) << "Recursing in depth=" << depth << STD_endl;
 
     while(feed_pipeline()) { // Continue feeding pipeline until no data is available
-      if(blackboard.inquire(label,data)) return true; // Return immediately if inquired data becomes available
+      if(blackboard.inquire(label,data)) {
+        ODINLOG(odinlog,normalDebug) << "Returning " << label << "(" << data.coord().print() << ")" << STD_endl;
+        return true; // Return immediately if inquired data becomes available
+      }
     }
     ODINLOG(odinlog,normalDebug) << "Pipeline empty" << STD_endl;
   }
@@ -198,6 +214,7 @@ bool RecoController::inquire_data(const STD_string& label, RecoData& data) {
 
   decr_waiting_threads();
 
+  ODINLOG(odinlog,normalDebug) << "Returning " << label << "(" << data.coord().print() << ")" << STD_endl;
   return true;
 }
 
@@ -452,9 +469,10 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
   }
 
 
+  bool apply_driftcorr=(numof_cache[repetition]>1 && !disableDriftCorr);
 
   STD_string driftcorrstr;
-  if(driftcorrFile!="") driftcorrstr="driftcorr | ";
+  if(apply_driftcorr) driftcorrstr="driftcorr | ";
 
 
   STD_string averagestr;
@@ -539,6 +557,9 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
         corrstr+="templtype=G {"+averagestr+adcprep+phasecorrstr+"kspace | chancoll | ";
         if(reduction_factor>1)   corrstr+="grappaweightstempl("  +redfactstr+  ")";
         if(reduction_factor3d>1) corrstr+="grappaweightstempl3d("+redfactstr3d+")";
+        if(dumpGrappaTemplate) {
+          corrstr+=" | chansplit | fft | slicecoll | image | store(grappatemplate)";
+        }
         corrstr+="}";
       }
       STD_string weightsstr;
@@ -649,26 +670,41 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
   STD_string freqcomb_and_oversampling=mfreqend+oversamplingstr;
   if(ext_fieldmap) freqcomb_and_oversampling=oversamplingstr+mfreqend; // remove oversampling 1st before combining with external fieldmap
 
+  STD_string kspaceprep="zerofill | filter | ";
+  if(dumpKspace) kspaceprep="";
+
+  if(numof_cache[dti]>1) pp3dpost+="dti | ";
 
   STD_string phasecoursestr;
   if(phaseCourse) {
     phasecoursestr="switch( { chanrepcoll | phasecourse | repsplit | "+ freqcomb_and_oversampling + "slicecoll | image | " + slicetimestr + "store(phasecourse) } ) | ";
   }
 
-  STD_string kspaceprep="zerofill | filter | ";
-  if(dumpKspace) kspaceprep="";
+  STD_string driftcalcstr;
+  if(apply_driftcorr) {
 
-  if(numof_cache[dti]>1) pp3dpost+="dti | ";
+//    STD_string driftrecipe=averagestr + " kspace | fft | driftcoll | driftcalc"; // FFT gives better results than without
+    STD_string driftrecipe=averagestr + " kspace | driftcoll | driftcalc"; // but not with GRAPPA ?
 
-  result = driftcorrstr + averagestr + adcbaselinestr + mfreqbegin + kspacestr + bladestr + offsetstr
+    STD_map<recoDim,unsigned short> selmap;
+    if(!create_selection_map(driftcorrSel, selmap)) return false;
+    if(selmap.size()) {
+      // Apply selected dimensions to recipe recursively
+      driftcalcstr=driftrecipe;
+      for(STD_map<recoDim,unsigned short>::const_iterator it=selmap.begin(); it!=selmap.end(); ++ it) {
+        driftcalcstr=STD_string("switch(")+recoDimLabel[it->first]+"="+itos(it->second)+"{"+driftcalcstr+"})";
+      }
+      driftcalcstr+=" | ";
+    } else {
+      driftcalcstr="switch( { " + averagestr + " kspace | fft | driftcoll | driftcalc } ) | "; // using switch to branch off drift calculation pipeline
+    }
+  }
+
+  result = driftcalcstr + driftcorrstr + averagestr + adcbaselinestr + mfreqbegin + kspacestr + bladestr + offsetstr
                      + kspaceprep + fftstr + adcdeapodize + deapodizestr + gridstr + phasecoursestr + pp3dpre + chanstr
                      + freqcomb_and_oversampling + pp3dpost + maskstr
                      + "slicecoll | image | " + slicetimestr + "store";
 
-  if(driftcalcFile!="") {
-    result= averagestr + adcbaselinestr + kspacestr + bladestr + offsetstr
-                     + kspaceprep + fftstr + adcdeapodize + deapodizestr + gridstr + oversamplingstr + " chanrepslicecoll | driftcalc | dump("+driftcalcFile+",asc)";
-  }
 
   if(disableGrappa || corrstr!="") {
     result="switch(templtype=N { "+result+"} ; "+corrstr+")";
@@ -683,6 +719,40 @@ bool RecoController::autorecipe(const RecoCoord& mask, STD_string& result) const
 }
 
 
+bool RecoController::create_selection_map(const STD_string& selstr, STD_map<recoDim,unsigned short>& selmap, RecoCoord* initcoord) const {
+  Log<Reco> odinlog("RecoController","create_selection_map");
+
+  // Parse selected dimensions
+  selmap.clear();
+  svector seltoks(tokens(selstr));
+  for(unsigned int isel=0; isel<seltoks.size(); isel++) {
+    svector toks(tokens(seltoks[isel],'='));
+    if(toks.size()==2) {
+      int dim=-1;
+      for(int idim=0; idim<n_recoDims; idim++) {
+        if(toks[0]==recoDimLabel[idim]) dim=idim;
+      }
+      if(dim>=0) {
+        int sel=atoi(toks[1].c_str());
+        if(initcoord) {
+          initcoord->index[dim]=sel;
+          initcoord->index[dim].set_mode(RecoIndex::single);
+        }
+        selmap[recoDim(dim)]=sel;
+      } else {
+        ODINLOG(odinlog,errorLog) << "Unknwon selection dimension " << toks[0] << STD_endl;
+        return false;
+      }
+    } else {
+      ODINLOG(odinlog,errorLog) << "Error while parsing selection " << seltoks[isel] << STD_endl;
+      return false;
+    }
+  }
+
+  return true;
+}
+
+
 //////////////////////////////////////////////////////////////////////////////////////
 
 bool RecoController::init(RecoReaderInterface* reader, JcampDxBlock& opts, int argc, char* argv[]) {
@@ -701,16 +771,18 @@ bool RecoController::init(RecoReaderInterface* reader, JcampDxBlock& opts, int a
   bool modify_args=false; // Do not modify command-line args since the same option may be used in different template instantiations
 
   // Parse recoInfo args
-  svector riargs(tokens(input->cmdline_opts(),' ','\"','\"'));
+  svector riargs(tokens(input->cmdline_opts()));
   int riargc=riargs.size()+1; // 1st string is neglected
   ODINLOG(odinlog,normalDebug) << "riargc=" << riargc << STD_endl;
   char* riargv[riargc+1];
   for(int i=0; i<(riargc+1); i++) riargv[i]=0;
   for(unsigned int i=0; i<riargs.size(); i++) {
-    unsigned int nchars=riargs[i].size();
+    STD_string argstr=extract(riargs[i], "\"", "\"", true); // strip escape characters, if possible/neccessary
+    if(argstr=="") argstr=riargs[i]; // use original string otherwise
+    unsigned int nchars=argstr.size();
     unsigned int iarg=i+1; // 1st string is neglected
     riargv[iarg]=new char[nchars+1];
-    sprintf(riargv[iarg], riargs[i].c_str());
+    sprintf(riargv[iarg],"%s",argstr.c_str()); // Extra '%s' format string required for Debian compiler hardening
     ODINLOG(odinlog,normalDebug) << "riargv[" << iarg << "]=" << riargv[iarg] << STD_endl;
   }
   riargv[riargc]=0;
@@ -738,7 +810,10 @@ bool RecoController::init(RecoReaderInterface* reader, JcampDxBlock& opts, int a
   // Parse selected dimensions
   RecoCoord initcoord;
   STD_map<recoDim,unsigned short> selmap;
-  svector seltoks(tokens(select));
+
+  if(!create_selection_map(select, selmap, &initcoord)) return false;
+
+/*  svector seltoks(tokens(select));
   for(unsigned int isel=0; isel<seltoks.size(); isel++) {
     svector toks(tokens(seltoks[isel],'='));
     if(toks.size()==2) {
@@ -760,7 +835,7 @@ bool RecoController::init(RecoReaderInterface* reader, JcampDxBlock& opts, int a
       return false;
     }
   }
-
+*/
 
 
   // create intial numof (only for selected dimension for efficiency)
@@ -924,7 +999,9 @@ bool RecoController::execute_pipeline() {
 
   delete[] threads;
 
-  if(waiting_error!="") ODINLOG(odinlog,errorLog) <<  waiting_error;
+  if(waiting_error!="") {
+    ODINLOG(odinlog,errorLog) <<  waiting_error;
+  }
 
   return status;
 }
@@ -976,6 +1053,7 @@ bool RecoController::prepare_pipeline() {
 
 
   // Loading and posting field drift
+/*
   if(driftcorrFile!="") {
 
     announce_data(posted_drift_str);
@@ -990,6 +1068,7 @@ bool RecoController::prepare_pipeline() {
 
     post_data(posted_drift_str, rdfdrift);
   }
+*/
 
 
   ODINLOG(odinlog,infoLog) << "Preparing pipeline ..." << STD_endl;
