@@ -2,8 +2,8 @@
                           data.h  -  description
                              -------------------
     begin                : Sat Dec 30 2006
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -94,6 +94,8 @@ class RecoData {
   ComplexData<4>& data(Rank<4>) const {return data4;}
   ComplexData<5>& data(Rank<5>) const {return data5;}
   ComplexData<6>& data(Rank<6>) const {return data6;}
+  ComplexData<7>& data(Rank<7>) const {return data7;}
+  ComplexData<8>& data(Rank<8>) const {return data8;}
 
 /**
   * Returns reference to the k-space coordinate.
@@ -144,6 +146,8 @@ class RecoData {
   mutable ComplexData<4> data4;
   mutable ComplexData<5> data5;
   mutable ComplexData<6> data6;
+  mutable ComplexData<7> data7;
+  mutable ComplexData<8> data8;
 
 };
 
