@@ -22,12 +22,23 @@ bool RecoFieldMap::process(RecoData& rd, RecoController& controller) {
     ODINLOG(odinlog,errorLog) << "TE size mismatch: " << tes.size() << "!=" << inshape(0) << STD_endl;
     return false;
   }
+  if(inshape(0)<2) {
+    ODINLOG(odinlog,errorLog) << "too few number of TEs: " << inshape(0) << STD_endl;
+    return false;
+  }
 
-  int npol=2; // Assume odd and even echoes (EPI-type readtout)
+  bool oddeven=(inshape(0)>2); // Assume odd and even echoes (EPI-type readtout) for more than 2 TEs
+
+  int npol=1;
+  if(oddeven) npol=2; 
   int ntes[npol];
-  ntes[0]=ntes[1]=inshape(0)/2;
-  if(inshape(0)%2) ntes[0]++;
-  ODINLOG(odinlog,normalDebug) << "inshape(0)/npol/ntes[0]/ntes[1]=" << inshape(0) << "/" << npol << "/" << ntes[0] << "/" << ntes[1] << STD_endl;
+  if(oddeven) {
+    ntes[0]=ntes[1]=inshape(0)/2;
+    if(inshape(0)%2) ntes[0]++;
+  } else {
+    ntes[0]=inshape(0);
+  }
+  ODINLOG(odinlog,normalDebug) << "oddeven/inshape(0)/npol/ntes[0]/ntes[1]=" << oddeven << "/" << inshape(0) << "/" << npol << "/" << ntes[0] << "/" << ntes[1] << STD_endl;
 
 
 
