@@ -2,8 +2,8 @@
                           grappa.h  -  description
                              -------------------
     begin                : Fri Feb 2 2007
-    copyright            : (C) 2001 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
