@@ -69,7 +69,7 @@ void RecoGrappaWeights<interpolDim,orthoDim,interpolIndex,orthoIndex,Ignore>::in
   svd_trunc.set_cmdline_option("gs").set_description("Truncation value of SVD (i.e. regularization) when calculating GRAPPA weights");
   append_arg(svd_trunc,"svd_trunc");
 
-  discard_level=0.01;
+  discard_level=0.0; //0.01;
   discard_level.set_cmdline_option("gd").set_description("Fraction of k-psace points to discard in auto-calibration lines because of high residuals");
   append_arg(discard_level,"discard_level");
 }
