@@ -2,7 +2,7 @@
 
 #define SWAB_SUFFIX "swab"
 
-RecoReaderOdin::RecoReaderOdin(JcampDxBlock& parblock) : rawdata_fileptr(NULL) {
+RecoReaderOdin::RecoReaderOdin(JcampDxBlock& parblock) : rawdata_fileptr(NULL) { //, rawdata_bytecount(0) {
 
   fifoFile.set_cmdline_option("pf").set_description("File name of FIFO (named pipe) to obtain the raw data from");
   parblock.append(fifoFile);
@@ -103,6 +103,47 @@ bool RecoReaderOdin::init(const STD_string& input_filename) {
     reloffset_cache(2-idir)=recoInfo.get_RelativeOffset()[idir];
   }
 
+  // get read-out shape arrays (for ramp-sampling EPI)
+  for(int j=0; j<MAX_NUMOF_READOUT_SHAPES; j++) {
+    fvector shape;
+    unsigned int dstsize;
+    recoInfo.get_ReadoutShape(j,shape,dstsize);
+    if(shape.size()) {
+      readoutShape_cache[j].first.reference(Data<float,1>(shape));
+      readoutShape_cache[j].second=dstsize;
+      ODINLOG(odinlog,normalDebug) << "shape/dstsize(" << j << ")=" << readoutShape_cache[j].first.size() << "/" << readoutShape_cache[j].second << STD_endl;
+    }
+  }
+
+
+  // get k-space trajectories
+  for(int itraj=0; itraj<MAX_NUMOF_KSPACE_TRAJS; itraj++) {
+    farray ktraj(recoInfo.get_kSpaceTraj(itraj));
+    if(ktraj.dim()==3) {
+
+      // fill trajectory values (kx,ky,kz)
+      int nseg=ktraj.size(0);
+      int npts=ktraj.size(1);
+
+      kspaceTraj_cache[itraj].resize(nseg,npts);
+
+      for(int iseg=0; iseg<nseg; iseg++) {
+        for(int ipt=0; ipt<npts; ipt++) {
+          kspaceTraj_cache[itraj](iseg,ipt).coord=TinyVector<float,3>(ktraj(iseg,ipt,2), ktraj(iseg,ipt,1), ktraj(iseg,ipt,0)); // reverse order of x,y,z
+          kspaceTraj_cache[itraj](iseg,ipt).weight=1.0;
+        }
+      }
+    }
+  }
+
+  // get weighting vectors
+  for(int iweight=0; iweight<MAX_NUMOF_ADC_WEIGHTING_VECTORS; iweight++) {
+    weightVec_cache[iweight].reference(Data<STD_complex,1>(recoInfo.get_AdcWeightVector(iweight)));
+  }
+
+
+
+
 
   STD_string scandir=JDXfileName(input_filename).get_dirname();
 
@@ -176,7 +217,7 @@ bool RecoReaderOdin::init(const STD_string& input_filename) {
     zeroesPerChunk=zeroesTotal/nAdcChunks;
 
     ODINLOG(odinlog,infoLog) << "nAdcChunks/rawheadersize/rawfilesize=" << nAdcChunks << "/" << rawheadersize << "/" << rawfilesize << STD_endl;
-    ODINLOG(odinlog,infoLog) << "samplesTotal/sizePaddedChunk/zeroesPerChunk=" << samplesTotal << "/" << sizePaddedChunk << "/" << zeroesPerChunk << STD_endl;
+    ODINLOG(odinlog,infoLog) << "samplesTotal/zeroesTotal/sizePaddedChunk/zeroesPerChunk=" << samplesTotal << "/" << zeroesTotal << "/" << sizePaddedChunk << "/" << zeroesPerChunk << STD_endl;
   }
 
 
@@ -185,6 +226,16 @@ bool RecoReaderOdin::init(const STD_string& input_filename) {
   if(filesize(protfile.c_str())>0) {
     prot_cache.load(protfile); // Backwards compatability
     ODINLOG(odinlog,infoLog) << "Loading protocol from " << protfile << STD_endl;
+    if(prot_cache.seqpars.get_EchoTime()<=0.0) {
+      JDXfloatArr tes;
+      tes.set_label("SliceOrder"); // separately instead of using constructor for GCC3.2
+      tes.load(protfile);
+      ODINLOG(odinlog,normalDebug) << "tes" << tes << STD_endl;
+      if(tes.total()>0 && tes[0]>0.0) {
+        prot_cache.seqpars.set_EchoTime(tes[0]);
+        ODINLOG(odinlog,infoLog) << "Using TE=" << tes[0] << " from old-style TE array" << STD_endl;
+      }
+    }
   } else {
     prot_cache=recoInfo.get_protocol(); // The new way: Assume protocol is contained in recoInfo
     ODINLOG(odinlog,infoLog) << "Using protocol from recoInfo" << STD_endl;
@@ -212,46 +263,6 @@ bool RecoReaderOdin::init(const STD_string& input_filename) {
   ODINLOG(odinlog,infoLog) << "Using seriesno=" << seriesno << " for file conversion" << STD_endl;
 
 
-
-  // get read-out shape arrays (for ramp-sampling EPI)
-  for(int j=0; j<MAX_NUMOF_READOUT_SHAPES; j++) {
-    fvector shape;
-    unsigned int dstsize;
-    recoInfo.get_ReadoutShape(j,shape,dstsize);
-    if(shape.size()) {
-      readoutShape_cache[j].first.reference(Data<float,1>(shape));
-      readoutShape_cache[j].second=dstsize;
-      ODINLOG(odinlog,normalDebug) << "shape/dstsize(" << j << ")=" << readoutShape_cache[j].first.size() << "/" << readoutShape_cache[j].second << STD_endl;
-    }
-  }
-
-
-  // get k-space trajectories
-  for(int itraj=0; itraj<MAX_NUMOF_KSPACE_TRAJS; itraj++) {
-    farray ktraj(recoInfo.get_kSpaceTraj(itraj));
-    if(ktraj.dim()==3) {
-
-      // fill trajectory values (kx,ky,kz)
-      int nseg=ktraj.size(0);
-      int npts=ktraj.size(1);
-
-      kspaceTraj_cache[itraj].resize(nseg,npts);
-
-      for(int iseg=0; iseg<nseg; iseg++) {
-        for(int ipt=0; ipt<npts; ipt++) {
-          kspaceTraj_cache[itraj](iseg,ipt).coord=TinyVector<float,3>(ktraj(iseg,ipt,2), ktraj(iseg,ipt,1), ktraj(iseg,ipt,0)); // reverse order of x,y,z
-          kspaceTraj_cache[itraj](iseg,ipt).weight=1.0;
-        }
-      }
-    }
-  }
-
-  // get weighting vectors
-  for(int iweight=0; iweight<MAX_NUMOF_ADC_WEIGHTING_VECTORS; iweight++) {
-    weightVec_cache[iweight].reference(Data<STD_complex,1>(recoInfo.get_AdcWeightVector(iweight)));
-  }
-
-
   index=0;
   ri_index=0;
   chancount=0;
@@ -272,6 +283,7 @@ bool RecoReaderOdin::read_block(T2 dummy, ComplexData<2>& block) {
       ODINLOG(odinlog,errorLog) << "fopen(" << rawdata_filename << "): " << lasterr() << STD_endl;
       return false;
     }
+//    rawdata_bytecount=0;
 
     int offset_bytes=recoInfo.get_RawHeaderSize();
     if(offset_bytes>0) { // Only if neccessary, to allow reading from a named pipe
@@ -279,6 +291,7 @@ bool RecoReaderOdin::read_block(T2 dummy, ComplexData<2>& block) {
         ODINLOG(odinlog,errorLog) << "fseek: " << lasterr() << STD_endl;
         return false;
       }
+//      rawdata_bytecount+=offset_bytes;
     }
   }
 
@@ -291,6 +304,7 @@ bool RecoReaderOdin::read_block(T2 dummy, ComplexData<2>& block) {
     int freadresult=fread(ptr+currpos, sizeof(T2), toberead, rawdata_fileptr);
     if(!freadresult) { // signals an error, even for a FIFO
       ODINLOG(odinlog,errorLog) << "fread() failed: " << lasterr() << STD_endl;
+      ODINLOG(odinlog,errorLog) << "ftell=" << FTELL(rawdata_fileptr) << STD_endl;
       result=false;
       break;
     }
@@ -298,6 +312,13 @@ bool RecoReaderOdin::read_block(T2 dummy, ComplexData<2>& block) {
     toberead=nitems-currpos;
   }
 
+//  rawdata_bytecount+=2*rawtypesize*block.size();
+//  LONGEST_INT ftellcount=FTELL(rawdata_fileptr);
+//  if(rawdata_bytecount!=ftellcount) {
+//    ODINLOG(odinlog,errorLog) << "file pointer out of sync: rawdata_bytecount/ftellcount=" << rawdata_bytecount << "/" << ftellcount << STD_endl;
+//    return false;
+//  }
+  
   if(result) convert_from_ptr(block, ptr, block.shape());
 
   delete[] ptr;
@@ -336,6 +357,7 @@ bool RecoReaderOdin::fetch(RecoCoord& coord, ComplexData<1>& adc) {
            ODINLOG(odinlog,errorLog) << "fseek: " << lasterr() << STD_endl;
           return false;
         }
+//        rawdata_bytecount+=skip_bytes;
       }
     }
 
