@@ -262,7 +262,7 @@ unsigned int SeqAcq::event(eventContext& context) const {
     SeqFreqChan::post_event(context,startelapsed+get_acquisition_start()+get_freqchan_duration());
   }
 
-  if(context.event_progmeter) context.event_progmeter->increase_counter();
+  context.increase_progmeter();
   return 1;
 }
 
