@@ -448,10 +448,13 @@ SeqAcqEPI::SeqAcqEPI(const STD_string& object_label, double sweepwidth,
   float gamma=systemInfo->get_gamma(nucleus);
 
   float resread=secureDivision( FOVread , read_size );
+  ODINLOG(odinlog,normalDebug) << "FOVread/read_size/resread=" << FOVread << "/" << read_size << "/" << resread << STD_endl;
   float resphase=secureDivision( FOVphase , phasesize_cache );
+  ODINLOG(odinlog,normalDebug) << "FOVphase/phasesize_cache/resphase=" << FOVphase << "/" << phasesize_cache << "/" << resphase << STD_endl;
 
   float k_indep_read=secureDivision( 2.0*PII , gamma * resread  );
   float k_indep_phase=secureDivision( 2.0*PII , gamma * resphase );
+  ODINLOG(odinlog,normalDebug) << "k_indep_read/k_indep_phase=" << k_indep_read << "/" << k_indep_phase << STD_endl;
 
   float k_indep_read_min=-0.5*k_indep_read;
   float k_indep_read_max=0.5*k_indep_read;
@@ -482,14 +485,25 @@ SeqAcqEPI::SeqAcqEPI(const STD_string& object_label, double sweepwidth,
   ODINLOG(odinlog,normalDebug) << "phase_increment/driver_phasenpts/driver_startindex=" << phase_increment << "/" << driver_phasenpts << "/" << driver_startindex << STD_endl;
 
 
+  // Use ADC of driver to adjust sweepwidth and use it in init_driver()
+  // do this here so we do not have to do it separately in each driver
+  // Thereby, add overampling at this point
+  driver->set_sweepwidth(os_factor*sweepwidth,1.0);
+
+  float maxgrad=systemInfo->get_max_grad();
+  float expected_gradstrength=secureDivision(2.0*PII*secureDivision(driver->get_sweepwidth(),os_factor), gamma*FOVread);
+  ODINLOG(odinlog,normalDebug) << "expected_gradstrength/maxgrad=" << expected_gradstrength << "/" << maxgrad << STD_endl;
+  if(expected_gradstrength>maxgrad) {
+    double strength_downscale=0.99*secureDivision(maxgrad, expected_gradstrength); // 1% Buffer
+    ODINLOG(odinlog,normalDebug) << "strength_downscale/sweepwidth=" << strength_downscale << "/" << sweepwidth << STD_endl;
+    sweepwidth*=strength_downscale;
+    ODINLOG(odinlog,warningLog) << "Gradient strength (" << expected_gradstrength << ") exceeds maximum (" << maxgrad << "), scaling sweepwidth down (factor=" << strength_downscale << ") to " << sweepwidth  << ODIN_FREQ_UNIT << STD_endl;
+    driver->set_sweepwidth(os_factor*sweepwidth,1.0); // let driver adjust sweepwidth
+  }
+
   for(int itry=0; itry<10; itry++) { // several attempts possible to get a valid setup, but avois infinite loop
 
-    // Use ADC of driver to adjust sweepwidth and use it in init_driver()
-    // do this here so we do not have to do it separately in each driver
-    // Thereby, add overampling at this point
-    driver->set_sweepwidth(os_factor*sweepwidth,1.0);
-
-    ODINLOG(odinlog,normalDebug) << "sweepwidth/os_factor/driver->get_sweepwidth()=" << sweepwidth << "/" << os_factor << "/" << driver->get_sweepwidth() << STD_endl;
+    ODINLOG(odinlog,normalDebug) << "[" << itry << "]sweepwidth/os_factor/driver->get_sweepwidth()=" << sweepwidth << "/" << os_factor << "/" << driver->get_sweepwidth() << STD_endl;
 
     // Initialize driver for only one segment (and/or GRAPPA interleave), different segments will be encoded by dephasing gradient
     driver->init_driver(object_label,driver->get_sweepwidth(),
@@ -501,13 +515,17 @@ SeqAcqEPI::SeqAcqEPI(const STD_string& object_label, double sweepwidth,
 
 
     double gradfreq=secureInv(2.0*driver->get_echoduration());
+    ODINLOG(odinlog,normalDebug) << "gradfreq[" << itry << "]=" << gradfreq << STD_endl;
+
     double low,upp;
     if(systemInfo->allowed_grad_freq(gradfreq, low, upp)) {
       break;
     } else {
       double downscale=STD_max(0.5,1.0-secureDivision(2.0*fabs(upp-low),gradfreq));
+      ODINLOG(odinlog,normalDebug) << "downscale/sweepwidth=" << downscale << "/" << sweepwidth << STD_endl;
       sweepwidth*=downscale;
       ODINLOG(odinlog,warningLog) << "Gradient switching frequency (" << gradfreq  << ODIN_FREQ_UNIT << ") not allowed, scaling sweepwidth down (factor=" << downscale << ") to " << sweepwidth  << ODIN_FREQ_UNIT << STD_endl;
+      driver->set_sweepwidth(os_factor*sweepwidth,1.0); // let driver adjust sweepwidth
     }
   }
 
