@@ -2,8 +2,8 @@
                           seqgradecho.h  -  description
                              -------------------
     begin                : Mon Feb 17 2003
-    copyright            : (C) 2001 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
