@@ -2,8 +2,8 @@
                           seqgradphase.h  -  description
                              -------------------
     begin                : Tue Mar 21 2006
-    copyright            : (C) 2001 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
