@@ -2,8 +2,8 @@
                           seqloop.h  -  description
                              -------------------
     begin                : Mon Aug 13 2001
-    copyright            : (C) 2001 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
