@@ -225,7 +225,7 @@ svector SeqMakefile::get_odin4idea_method_compile_chain(const STD_string& in_dir
 #ifdef USING_WIN32
   // add path for ppc-compiler binaries
   JDXfileName ppc_path(vxworks_path); // normalize file name
-  STD_string oldpath=secure_getenv("PATH");
+  STD_string oldpath=getenv_nonnull("PATH");
 
   // remove blanks which make ccppc fail
   while(oldpath.find("; ")!=STD_string::npos) oldpath=replaceStr(oldpath,"; ",";");
