@@ -447,9 +447,13 @@ void SeqMethod::create_protcache() const {
   Log<Seq> odinlog(this,"create_protcache");
   if(!protcache) protcache=new Protocol;
   (*protcache)=Protocol(PROTOCOL_BLOCK_LABEL); // start with a fresh protocol in order to avoid adding method pars multiple times, use same label as in recoInfo
+
   protcache->system=(*systemInfo);
-  geometryInfo.copy(protcache->geometry);
-  studyInfo.copy(protcache->study);
+  ODINLOG(odinlog,normalDebug) << "filemode(protcache->system)=" << protcache->system.grad_reson_center.get_filemode() << STD_endl;
+  ODINLOG(odinlog,normalDebug) << "filemode(*systemInfo)=" << systemInfo->grad_reson_center.get_filemode() << STD_endl;
+
+  geometryInfo.copy(protcache->geometry); // use custom copy function of SingletonHandler
+  studyInfo.copy(protcache->study); // use custom copy function of SingletonHandler
   if(commonPars) protcache->seqpars=(*commonPars);
   if(methodPars) protcache->methpars.create_copy(*methodPars);
   protcache->append_all_members(); // re-merge all parameters
@@ -565,17 +569,22 @@ int SeqMethod::load_systemInfo(const STD_string& filename) {
 unsigned int SeqMethod::event(eventContext& context) const {
   Log<Seq> odinlog(this,"event");
 
+  unsigned int result=0;
+
   if(context.action==seqRun) {
     ODINLOG(odinlog,normalDebug) << "calling pre_event of " << platform->get_label() << STD_endl;
     platform->pre_event(context);
+    if(context.abort) {ODINLOG(odinlog,errorLog) << "aborting" << STD_endl; return result;} // return immediately
   }
 
   ODINLOG(odinlog,normalDebug) << "------------------- action=" << context.action << "-------------------" << STD_endl;
-  unsigned int result=SeqObjList::event(context);
+  result=SeqObjList::event(context);
+  if(context.abort) {ODINLOG(odinlog,errorLog) << "aborting" << STD_endl; return result;} // return immediately
 
   if(context.action==seqRun) {
     ODINLOG(odinlog,normalDebug) << "calling post_event of " << platform->get_label() << STD_endl;
     platform->post_event(context);
+    if(context.abort) {ODINLOG(odinlog,errorLog) << "aborting" << STD_endl; return result;} // return immediately
   }
 
   return result;
