@@ -554,7 +554,7 @@ void SeqSimMagsi::prepare_simulation(const Sample& sample, CoilSensitivity* tran
 
   update_axes();
 
-  if(!ThreadedLoop<SeqSimInterval,cvector>::init(nthreads, oneframe_size_cache)) {
+  if(!ThreadedLoop<SeqSimInterval,cvector,int>::init(nthreads, oneframe_size_cache)) {
     ODINLOG(odinlog,errorLog) << "cannot init multithreading" << STD_endl;
   }
 
@@ -585,7 +585,7 @@ cvector SeqSimMagsi::simulate(const SeqSimInterval& simvals, double gamma) {
   }
 
   STD_vector<cvector> outvec;
-  if(!execute(simvals, outvec)) {
+  if(!ThreadedLoop<SeqSimInterval,cvector,int>::execute(simvals, outvec)) {
     ODINLOG(odinlog,errorLog) << "cannot start multithreading" << STD_endl;
     return result;
   }
@@ -602,7 +602,7 @@ cvector SeqSimMagsi::simulate(const SeqSimInterval& simvals, double gamma) {
 }
 
 
-bool SeqSimMagsi::kernel(const SeqSimInterval& simvals, cvector& signal, unsigned int begin, unsigned int end) {
+bool SeqSimMagsi::kernel(const SeqSimInterval& simvals, cvector& signal, int&, unsigned int begin, unsigned int end) {
   Log<Seq> odinlog(this,"kernel");
 
   if(simvals.dt<=0.0) return true;
@@ -982,7 +982,7 @@ bool SeqSimMagsi::kernel(const SeqSimInterval& simvals, cvector& signal, unsigne
 
 void SeqSimMagsi::finalize_simulation() {
   MxMy2MampMpha();
-  ThreadedLoop<SeqSimInterval,cvector>::destroy(); // Stop threads
+  ThreadedLoop<SeqSimInterval,cvector,int>::destroy(); // Stop threads
   outdate_simcache(); // delete old pointers
 }
 
@@ -1009,35 +1009,47 @@ void SeqSimMonteCarlo::clear_cache() {
 }
 
 
-SeqSimMonteCarlo::SeqSimMonteCarlo(const STD_string& label, unsigned int nparticles) {
+SeqSimMonteCarlo::SeqSimMonteCarlo(const STD_string& label, unsigned int nparticles, unsigned int nthreads) {
   common_init();
   SeqClass::set_label(label);
   particle.resize(nparticles);
+  numof_threads=nthreads;
 }
 
 
 SeqSimMonteCarlo& SeqSimMonteCarlo::operator = (const SeqSimMonteCarlo& ssmc) {
   SeqClass::set_label(ssmc.SeqClass::get_label());
   particle=ssmc.particle;
+  numof_threads=ssmc.numof_threads;
   return *this;
 }
 
+farray SeqSimMonteCarlo::get_spatial_dist() const {
+  farray result(size_cache[2],size_cache[1],size_cache[0]); // is already initialized to zero
+  for(unsigned int i=0; i<particle.size(); i++) {
+    const Particle& part=particle[i];
+    unsigned int j= linear_index(part.pos);
+    result[j]+=1.0;
+  }
+  return result;
+}
+
 
 void SeqSimMonteCarlo::prepare_simulation(const Sample& sample, CoilSensitivity* transmit_coil, CoilSensitivity* receive_coil, ProgressMeter* progmeter) {
   Log<Seq> odinlog(this,"prepare_simulation");
   clear_cache();
 
-  xsize=sample.get_extent()[xDim];
-  ysize=sample.get_extent()[yDim];
-  zsize=sample.get_extent()[zDim];
-  int ntotal=xsize*ysize*zsize;
+  size_cache[0]=sample.get_extent()[xDim];
+  size_cache[1]=sample.get_extent()[yDim];
+  size_cache[2]=sample.get_extent()[zDim];
+  unsigned int ntotal=size_cache[0]*size_cache[1]*size_cache[2];
 
   Dcoeff_cache=new float[ntotal];
   ppmMap_cache=new float[ntotal];
   R1map_cache=new float[ntotal];
   R2map_cache=new float[ntotal];
   spinDensity_cache=new float[ntotal];
-  for(int i=0; i<ntotal; i++) {
+  for(unsigned int i=0; i<ntotal; i++) {
     Dcoeff_cache[i]=sample.get_DcoeffMap()[i];
     ppmMap_cache[i]=sample.get_ppmMap()[i];
     R1map_cache[i]=secureInv(sample.get_T1map()[i]);
@@ -1045,40 +1057,42 @@ void SeqSimMonteCarlo::prepare_simulation(const Sample& sample, CoilSensitivity*
     spinDensity_cache[i]=sample.get_spinDensity()[i];
   }
 
-  xpixelspacing_cache=secureDivision(sample.get_FOV(xAxis),xsize);
-  ypixelspacing_cache=secureDivision(sample.get_FOV(yAxis),ysize);
-  zpixelspacing_cache=secureDivision(sample.get_FOV(zAxis),zsize);
-  ODINLOG(odinlog,normalDebug) << "pixelspacing=" << xpixelspacing_cache << "/" << ypixelspacing_cache << "/" << zpixelspacing_cache << STD_endl;
+  pixelspacing_cache[0]=secureDivision(sample.get_FOV(xAxis),size_cache[0]);
+  pixelspacing_cache[1]=secureDivision(sample.get_FOV(yAxis),size_cache[1]);
+  pixelspacing_cache[2]=secureDivision(sample.get_FOV(zAxis),size_cache[2]);
 
   for(unsigned int i=0; i<particle.size(); i++) {
     Particle& part=particle[i];
 
-    float dstxpos, dstypos, dstzpos;
+/*
+    float dstpos[3];
     float Ddst=0.0;
     while(Ddst<=0.0) { // Do not init to positions with zero diff coefficient to avoid particle traps
-      dstxpos=xsize*rng.uniform();
-      dstypos=ysize*rng.uniform();
-      dstzpos=zsize*rng.uniform();
-      Ddst=Dcoeff_cache[linear_index(dstxpos, dstypos, dstzpos)];
+      for(unsigned int k=0; k<3; k++) dstpos[k]=size_cache[k]*rng.uniform();
+      Ddst=Dcoeff_cache[linear_index(dstpos)];
     }
-    part.xpos=dstxpos;
-    part.ypos=dstypos;
-    part.zpos=dstzpos;
+    for(unsigned int k=0; k<3; k++) part.pos[k]=dstpos[k];
+*/
 
+    for(unsigned int k=0; k<3; k++) part.pos[k]=size_cache[k]*rng.uniform();
     part.Mx=0.0;
     part.My=0.0;
     part.Mz=1.0;
   }
 
   B0_ppm_cache=1.0e-6*systemInfo->get_B0();
+
+  if(!ThreadedLoop<SeqSimInterval,cvector,RandomDist>::init(numof_threads, particle.size())) {
+    ODINLOG(odinlog,errorLog) << "cannot init multithreading" << STD_endl;
+  }
+
 }
 
 
-unsigned int SeqSimMonteCarlo::linear_index(float xpos, float ypos, float zpos) const {
-  unsigned int ix=((unsigned int)xpos)%xsize;
-  unsigned int iy=((unsigned int)ypos)%ysize;
-  unsigned int iz=((unsigned int)zpos)%zsize;
-  unsigned int result= iz*xsize*ysize + iy*xsize + ix;
+unsigned int SeqSimMonteCarlo::linear_index(const float pos[3]) const {
+  unsigned int index[3];
+  for(unsigned int k=0; k<3; k++) index[k]=((unsigned int)pos[k])%size_cache[k]; // assuming periodic pattern of spatial maps
+  unsigned int result= index[2]*size_cache[0]*size_cache[1] + index[1]*size_cache[0] + index[0];
   return result;
 }
 
@@ -1087,10 +1101,35 @@ cvector SeqSimMonteCarlo::simulate(const SeqSimInterval& simvals, double gamma)
   Log<Seq> odinlog(this,"simulate");
 
   cvector result(1);
-  result[0]=0.0;
-
   if(simvals.dt<=0.0) return result;
 
+  gamma_cache=gamma;
+
+  STD_vector<cvector> outvec;
+  if(!ThreadedLoop<SeqSimInterval,cvector,RandomDist>::execute(simvals, outvec)) {
+    ODINLOG(odinlog,errorLog) << "cannot start multithreading" << STD_endl;
+    return result;
+  }
+
+  if(simvals.rec>0.0) {
+    for(unsigned int i=0; i<outvec.size(); i++) {
+      if(outvec[i].size()) { // zero-duration intervals have zero size
+        result+=outvec[i];
+      }
+    }
+  }
+  return result;
+}
+
+
+  
+  
+
+bool SeqSimMonteCarlo::kernel(const SeqSimInterval& simvals, cvector& signal, RandomDist& local_rng, unsigned int begin, unsigned int end) {
+  Log<Seq> odinlog(this,"kernel");
+
+  if(simvals.dt<=0.0) return true;
+
   float phase_rad=simvals.phase * PII / 180.0;
 
   float d_rf[3][3];
@@ -1100,8 +1139,8 @@ cvector SeqSimMonteCarlo::simulate(const SeqSimInterval& simvals, double gamma)
   float B1amp=cabs(simvals.B1);
   if(B1amp) {
 //    float B1phase=phase(simvals.B1);
-//    STD_complex b1_pulse= float(gamma) * B1amp * STD_complex( cos(B1phase+phase_rad), sin(B1phase+phase_rad));
-    STD_complex b1_pulse= float(gamma) * simvals.B1 * expc(STD_complex(0.0,phase_rad));
+//    STD_complex b1_pulse= float(gamma_cache) * B1amp * STD_complex( cos(B1phase+phase_rad), sin(B1phase+phase_rad));
+    STD_complex b1_pulse= float(gamma_cache) * simvals.B1 * expc(STD_complex(0.0,phase_rad));
     float bx=b1_pulse.real();
     float by=b1_pulse.imag();
     b = norm(bx,by);
@@ -1135,16 +1174,16 @@ cvector SeqSimMonteCarlo::simulate(const SeqSimInterval& simvals, double gamma)
   }
 
 
-  float w0_ppm=gamma*B0_ppm_cache;
+  float w0_ppm=gamma_cache*B0_ppm_cache;
 
    // Use double precision to avoid round-off error when summing up signal
   double reSig=0.0;
   double imSig=0.0;
 
-  for(unsigned int i=0; i<particle.size(); i++) {
+  for(unsigned int i=begin; i<end; i++) {
     Particle& part=particle[i];
 
-    unsigned int j= linear_index(part.xpos, part.ypos, part.zpos);
+    unsigned int j= linear_index(part.pos);
     ODINLOG(odinlog,normalDebug) << "linear_index[" << i << "]=" << j << STD_endl;
 
 
@@ -1155,10 +1194,9 @@ cvector SeqSimMonteCarlo::simulate(const SeqSimInterval& simvals, double gamma)
 
     // Calculate spatial position
     if(simvals.Gx || simvals.Gy || simvals.Gz) {
-      float xspat=(part.xpos-0.5*float(xsize))*xpixelspacing_cache;
-      float yspat=(part.ypos-0.5*float(ysize))*ypixelspacing_cache;
-      float zspat=(part.zpos-0.5*float(zsize))*zpixelspacing_cache;
-      bz += gamma * (simvals.Gx*xspat + simvals.Gy*yspat + simvals.Gz*zspat);  // imaging gradients
+      float spat[3];
+      for(unsigned int k=0; k<3; k++) spat[k]=(part.pos[k]-0.5*float(size_cache[k]))*pixelspacing_cache[k];
+      bz += gamma_cache * (simvals.Gx*spat[0] + simvals.Gy*spat[1] + simvals.Gz*spat[2]);  // imaging gradients
     }
 
     float ph_gr = bz*simvals.dt; // the precession angle around the effective field
@@ -1215,29 +1253,29 @@ cvector SeqSimMonteCarlo::simulate(const SeqSimInterval& simvals, double gamma)
 
     float Dfactor=sqrt(2.0*Dcoeff_cache[j]*simvals.dt);
     if(Dfactor) {
-      float newxpos, newypos, newzpos;
+      float newpos[3];
       float Dnew=0.0;
       while(Dnew<=0.0) { // Do not jump to positions with zero diff coefficient to avoid particle traps
-        newxpos=part.xpos+rng.gaussian(secureDivision(Dfactor,xpixelspacing_cache));
-        newypos=part.ypos+rng.gaussian(secureDivision(Dfactor,ypixelspacing_cache));
-        newzpos=part.zpos+rng.gaussian(secureDivision(Dfactor,zpixelspacing_cache));
-        Dnew=Dcoeff_cache[linear_index(newxpos, newypos, newzpos)];
+        for(unsigned int k=0; k<3; k++) newpos[k]=part.pos[k]+local_rng.gaussian(secureDivision(Dfactor,pixelspacing_cache[k]));
+        Dnew=Dcoeff_cache[linear_index(newpos)];
       }
-      part.xpos=newxpos;
-      part.ypos=newypos;
-      part.zpos=newzpos;
+      for(unsigned int k=0; k<3; k++) part.pos[k]=newpos[k];
     }
 
 
   } // end loop over particles
 
-  if(simvals.rec>0.0) result[0]=simvals.rec*STD_complex(reSig,imSig)*expc(STD_complex(0.0,phase_rad)); // consider receiver weighting/phase
+  if(simvals.rec>0.0) {
+    signal.resize(1);
+    signal[0]=simvals.rec*STD_complex(reSig,imSig)*expc(STD_complex(0.0,phase_rad)); // consider receiver weighting/phase
+  }
 
-  return result;
+  return true;
 }
 
 
 void SeqSimMonteCarlo::finalize_simulation() {
+  ThreadedLoop<SeqSimInterval,cvector,RandomDist>::destroy(); // Stop threads
   clear_cache();
 }
 
