@@ -2,8 +2,8 @@
                           seqtree.h  -  description
                              -------------------
     begin                : Fri Oct 17 2003
-    copyright            : (C) 2001 by Thies H. Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies H. Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -60,13 +60,16 @@ enum eventAction {seqRun=0, printEvent, countEvents};
   * Structure that holds the context in which the event of a sequence object is requested
   */
 struct eventContext {
-  eventContext() : action(seqRun), noflush(false), seqcheck(false),
+  eventContext() : action(seqRun), abort(false), noflush(false), seqcheck(false),
                    elapsed(0.0),
                    event_display(0), event_progmeter(0) {}
 
   // the action to be performed
   eventAction action;
 
+  // signal to abort execution of the sequence
+  bool abort;
+
   // do not flush eventblock
   bool noflush;
 
@@ -81,6 +84,10 @@ struct eventContext {
 
   // pointer for progess meter
   ProgressMeter* event_progmeter;
+
+  // helper function to update/increase progmeter and store status in 'abort'
+  void increase_progmeter();
+
 };
 
 ///////////////////////////////////////////////////////////////////////////
