@@ -21,6 +21,7 @@ private:
   JDXbool   fMRITrigger;
   JDXbool   UpDownBlade;
   JDXbool   FieldMap;
+  JDXbool   InvertPartialFourier;
 
 
   SeqPulsar  exc;
@@ -118,7 +119,7 @@ void method_pars_init() {
   ShortAxis=false;
   ShortAxis.set_description("Readout direction along short axis of blades");
 
-  BladeOversampling=1.0;
+  BladeOversampling=0.0;
   BladeOversampling.set_minmaxval(0.0,100.0);
   BladeOversampling.set_unit("%").set_description("Oversampling (overlap) in short direction of blade");
 
@@ -160,6 +161,9 @@ void method_pars_init() {
   fMRITrigger=true;
   fMRITrigger.set_description("External triggering");
 
+  InvertPartialFourier=false;
+  InvertPartialFourier.set_description("Invert position in phase encoding direction at which partial Fourier cut off is performed (i.e. beginning or end of readout)");
+
   UpDownBlade=false;
   UpDownBlade.set_description("Sample each blade twice with opposite phase-encoding direction");
 
@@ -192,6 +196,8 @@ void method_pars_init() {
 
   append_parameter(fMRITrigger,"fMRITrigger");
 
+  append_parameter(InvertPartialFourier,"InvertPartialFourier");
+
   if(systemInfo->get_platform()!=numaris_4) {
     append_parameter(BladeOversampling,"BladeOversampling");
     append_parameter(RampMode,"RampMode");
@@ -306,9 +312,7 @@ void method_seq_init() {
                    readpts_blade, fov,
                    pelines_blade, fov,
                    1, epi_reduction, os_read, "", 0, 0, rampType(int(RampMode)),
-                   RampSampling, RampSteepness, epi_partfour);
-
-
+                   RampSampling, RampSteepness, epi_partfour, 0, InvertPartialFourier);
 
   // display sampling extents in read/phase direction
   NumOfGradEchoes=epiacq.get_numof_gradechoes();
