@@ -677,7 +677,8 @@ void method_pars_set() {
 
   recoInfo->set_PostProc3D("usercoll | messer");
 
-  recoInfo->set_CmdLineOpts("-ff Hamming -fp 0.8");
+  int driftcorrte=NumOfEchoes-1;
+  recoInfo->set_CmdLineOpts("-ff Hamming -fp 0.8 -dcs userdef="+itos(driftcorrte)+" -dce "+ftos(TEs[driftcorrte]));
 
 }
 
