@@ -7,15 +7,20 @@
 
 #ifndef NO_THREADS
 
-#ifdef HAVE_PTHREAD
-#include <pthread.h>
-#define USE_PTHREADS
-#endif
 
 #ifdef USING_WIN32
 #include <windows.h>
 #define USE_WINTHREADS
+#else
+#ifdef HAVE_PTHREAD
+#include <pthread.h>
+#ifdef HAVE_UNISTD_H
+#include <unistd.h> // for sysconf
 #endif
+#define USE_PTHREADS
+#endif
+#endif
+
 
 #endif
 
