@@ -94,8 +94,8 @@ double secureDivision(double numerator, double denominator) {
 
 /////////////////////////////////////////////////////////////
 
-const char* secure_getenv(const char* variable_name) {
-  Log<TjTools> odinlog("","secure_getenv");
+const char* getenv_nonnull(const char* variable_name) {
+  Log<TjTools> odinlog("","getenv_nonnull");
   const char* result="";
   const char* env=getenv(variable_name);
   if(env) result=env;
@@ -526,7 +526,7 @@ STD_string tempfile() {
   const char* ptr=tmpnam(NULL);
   if(ptr) result=ptr;
 #ifdef USING_WIN32
-  result=STD_string(secure_getenv("TEMP"))+SEPARATOR_STR+result;
+  result=STD_string(getenv_nonnull("TEMP"))+SEPARATOR_STR+result;
 #endif
   return result;
 }
