@@ -2,8 +2,8 @@
                           tjtools.h  -  description
                              -------------------
     begin                : Thu Jul 13 2000
-    copyright            : (C) 2000 by Thies Jochimsen
-    email                : jochimse@cns.mpg.de
+    copyright            : (C) 2000-2014 by Thies Jochimsen
+    email                : thies@jochimsen.de
  ***************************************************************************/
 
 /***************************************************************************
@@ -271,9 +271,9 @@ inline double secureInv(double denominator) {return secureDivision(1.0, denomina
 
 /**
   *
-  * Same as getenv, but does return "" instead of 0 if variable is not found
+  * Same as getenv, but returns empty string instead of NULL if variable is not found
   */
-const char* secure_getenv(const char* variable_name);
+const char* getenv_nonnull(const char* variable_name);
 
 
 /**
