@@ -389,44 +389,49 @@ STD_complex* interpolate1D(const STD_complex* data, unsigned int oldsize, unsign
 }
 
 
-float* interpolate1D(const float* olddata,unsigned int oldsize,unsigned int newsize, float subpixel_shift) {
-  Log<VectorComp> odinlog("tjvector","interpolate1D(float)");
+template<class T, bool integer_rounding>
+T* interpolate1D_impl(const T* olddata, unsigned int oldsize, unsigned int newsize, float subpixel_shift) {
+  Log<VectorComp> odinlog("tjvector","interpolate1D_impl");
   STD_complex* oldcomplexdata=new STD_complex[oldsize];
   unsigned int i;
-  for(i=0;i<oldsize;i++) oldcomplexdata[i]=olddata[i];
+  T minval, maxval;
+  for(i=0;i<oldsize;i++) {
+    if(i) {
+      minval=STD_min(minval, olddata[i]);
+      maxval=STD_max(maxval, olddata[i]);
+    } else {
+      minval=maxval=olddata[i];
+    }
+    oldcomplexdata[i]=olddata[i];
+  }
+  ODINLOG(odinlog,normalDebug) << "minval/maxval=" << minval << "/" << maxval << STD_endl;
+
   STD_complex* newcomplexdata=interpolate1D(oldcomplexdata,oldsize,newsize,subpixel_shift);
-  float* newdata=new float[newsize];
-  for(i=0;i<newsize;i++) newdata[i]=newcomplexdata[i].real();
+  T* newdata=new T[newsize];
+  for(i=0;i<newsize;i++) {
+    if(integer_rounding)  newdata[i]=T(newcomplexdata[i].real()+0.5);
+    else                  newdata[i]=newcomplexdata[i].real();
+
+    // keeping values in old range
+    newdata[i]=STD_min(maxval, newdata[i]);
+    newdata[i]=STD_max(minval, newdata[i]);
+  }
   delete[] oldcomplexdata;
   delete[] newcomplexdata;
   return newdata;
 }
 
 
+float* interpolate1D(const float* olddata,unsigned int oldsize, unsigned int newsize, float subpixel_shift) {
+  return interpolate1D_impl<float,false>(olddata, oldsize, newsize, subpixel_shift);
+}
+
 double* interpolate1D(const double* olddata,unsigned int oldsize,unsigned int newsize, float subpixel_shift) {
-  Log<VectorComp> odinlog("tjvector","interpolate1D(double)");
-  STD_complex* oldcomplexdata=new STD_complex[oldsize];
-  unsigned int i;
-  for(i=0;i<oldsize;i++) oldcomplexdata[i]=olddata[i];
-  STD_complex* newcomplexdata=interpolate1D(oldcomplexdata,oldsize,newsize,subpixel_shift);
-  double* newdata=new double[newsize];
-  for(i=0;i<newsize;i++) newdata[i]=newcomplexdata[i].real();
-  delete[] oldcomplexdata;
-  delete[] newcomplexdata;
-  return newdata;
+  return interpolate1D_impl<double,false>(olddata, oldsize, newsize, subpixel_shift);
 }
 
 int* interpolate1D(const int* olddata,unsigned int oldsize,unsigned int newsize, float subpixel_shift) {
-  Log<VectorComp> odinlog("tjvector","interpolate1D(int)");
-  STD_complex* oldcomplexdata=new STD_complex[oldsize];
-  unsigned int i;
-  for(i=0;i<oldsize;i++) oldcomplexdata[i]=float(olddata[i]);
-  STD_complex* newcomplexdata=interpolate1D(oldcomplexdata,oldsize,newsize,subpixel_shift);
-  int* newdata=new int[newsize];
-  for(i=0;i<newsize;i++) newdata[i]=int(newcomplexdata[i].real());
-  delete[] oldcomplexdata;
-  delete[] newcomplexdata;
-  return newdata;
+  return interpolate1D_impl<int,true>(olddata, oldsize, newsize, subpixel_shift);
 }
 
 
